=== modified file 'NEWS'
--- NEWS	2008-06-22 23:47:59 +0000
+++ NEWS	2008-06-25 10:24:54 +0000
@@ -23,7 +23,9 @@
       memory consumption of rendering by a factor of around 3 for
       large pages over the old Kid templates.
 
-    - Loggerhead's poorly performing text index was disabled.
+    - Loggerhead's poorly performing text index was disabled. bzr-search
+      is now used if the plugin is installed and a text index is present
+      on the branch being viewed. (Martin Albisetti, Robert Collins).
 
     - Loggerhead no longer depends on bzrlib functions deprecated in
       Bazaar 1.5 and removed in 1.6 (Martin Albisetti).

=== modified file 'README.txt'
--- README.txt	2008-06-23 02:07:29 +0000
+++ README.txt	2008-07-22 00:40:03 +0000
@@ -7,6 +7,7 @@
 navigate a branch history, annotate files, perform searches... all the
 usual things.
 
+
 GETTING STARTED
 ---------------
 
@@ -15,12 +16,20 @@
 'python-simpletal' and 'python-paste' packages installed.  You need
 version 1.2 or newer of Paste.
 
-Then simply run the 'serve-branches.py' script of loggerhead from the
-directory containing the branches you want to serve.
-
-For example:
-
-    XXX
+Then simply run the 'serve-branches.py' with the branch you want to
+serve on the command line:
+
+    ./serve-branches.py ~/path/to/branch
+
+The script listens on port 8080 so head to http://localhost:8080/ in
+your browser to see the branch.  You can also pass a directory that
+contains branches to the script, and it will serve a very simple
+directory listing at other pages.
+
+You may update the Bazaar branches being viewed at any time.
+Loggerhead will notice and refresh, and Bazaar uses its own branch
+locking to prevent corruption.
+
 
 USING A CONFIG FILE
 -------------------
@@ -35,9 +44,8 @@
 
     $ ./start-loggerhead.py
 
-This will run loggerhead in the background.  It listens on port 8080
-by default, so go to http://localhost:8080/ in your browser to see the
-list of bublished branches.
+This will run loggerhead in the background, listening on port 8080 by
+default.
 
 To stop Loggerhead, run::
 
@@ -52,9 +60,6 @@
 A debug and access log are stored in the logs/ folder, relative to
 the location of the start-loggerhead.py script.
 
-You may update the Bazaar branch at any time (for example, from a cron).
-Loggerhead will notice and refresh, and Bazaar uses its own branch
-locking to prevent corruption.
 
 SERVING LOGGERHEAD FROM BEHIND APACHE
 -------------------------------------
@@ -69,6 +74,11 @@
         ProxyPassReverse http://127.0.0.1:8080/
     </Location>
 
+If Paste Deploy is installed, the 'serve-branches.py' script can be
+run behind a proxy at the root of a site, but if you're running it at
+some path into the site, you'll need to add a 'prefix' argument to the
+PrefixMiddleware call in the script.  More flexible configuration
+should be added soon...
 
 
 FILES CHANGED CACHE

=== modified file 'loggerhead/apps/__init__.py'
--- loggerhead/apps/__init__.py	2008-06-18 07:48:17 +0000
+++ loggerhead/apps/__init__.py	2008-07-01 04:01:31 +0000
@@ -1,4 +1,5 @@
-#
+"""WSGI applications for serving Bazaar branches."""
+
 import os
 
 from paste import urlparser, fileapp

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-06-19 19:28:16 +0000
+++ loggerhead/apps/branch.py	2008-07-09 08:39:59 +0000
@@ -1,43 +1,52 @@
+"""The WSGI application for serving a Bazaar branch."""
+
 import logging
 import urllib
 
+import bzrlib.branch
+import bzrlib.lru_cache
+
 from paste import request
 from paste import httpexceptions
-from paste.wsgiwrappers import WSGIRequest, WSGIResponse
 
 from loggerhead.apps import static_app
-from loggerhead.changecache import FileChangeCache
 from loggerhead.controllers.changelog_ui import ChangeLogUI
 from loggerhead.controllers.inventory_ui import InventoryUI
 from loggerhead.controllers.annotate_ui import AnnotateUI
 from loggerhead.controllers.revision_ui import RevisionUI
 from loggerhead.controllers.atom_ui import AtomUI
 from loggerhead.controllers.download_ui import DownloadUI
-from loggerhead.controllers.bundle_ui import BundleUI
+from loggerhead.controllers.search_ui import SearchUI
 from loggerhead.history import History
 from loggerhead import util
 
-logging.basicConfig()
-logging.getLogger().setLevel(logging.DEBUG)
 
 class BranchWSGIApp(object):
 
-    def __init__(self, branch_url, friendly_name=None, config={}):
-        self.branch_url = branch_url
-        self._history = None
+    def __init__(self, branch, friendly_name=None, config={}, graph_cache=None):
+        self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
-        self.log = logging.getLogger(friendly_name)
+        self.log = logging.getLogger('loggerhead.%s' % (friendly_name,))
+        if graph_cache is None:
+            graph_cache = bzrlib.lru_cache.LRUCache()
+        self.graph_cache = graph_cache
 
-    @property
-    def history(self):
-        if (self._history is None) or self._history.out_of_date():
-            self.log.debug('Reload branch history...')
-            _history = self._history = History.from_folder(self.branch_url)
-            cache_path = self._config.get('cachepath', None)
-            if cache_path is not None:
-                _history.use_file_cache(FileChangeCache(_history, cache_path))
-        return self._history
+    def get_history(self):
+        _history = History(self.branch, self.graph_cache)
+        cache_path = self._config.get('cachepath', None)
+        if cache_path is not None:
+            # Only import the cache if we're going to use it.
+            # This makes sqlite optional
+            try:
+                from loggerhead.changecache import FileChangeCache
+            except ImportError:
+                self.log.debug("Couldn't load python-sqlite,"
+                               " continuing without using a cache")
+            else:
+                _history.use_file_cache(
+                    FileChangeCache(_history, cache_path))
+        return _history
 
     def url(self, *args, **kw):
         if isinstance(args[0], list):
@@ -66,21 +75,18 @@
         'revision': RevisionUI,
         'download': DownloadUI,
         'atom': AtomUI,
-        'bundle': BundleUI,
+        'search': SearchUI,
         }
 
     def last_updated(self):
-        h = self.history
+        h = self.get_history()
         change = h.get_changes([ h.last_revid ])[0]
         return change.date
 
     def branch_url(self):
-        return self.history.get_config().get_user_option('public_branch')
+        return self.branch.get_config().get_user_option('public_branch')
 
     def app(self, environ, start_response):
-        req = WSGIRequest(environ)
-        response = WSGIResponse()
-        response.headers['Content-Type'] = 'text/plain'
         self._url_base = environ['SCRIPT_NAME']
         self._static_url_base = environ.get('loggerhead.static.url')
         if self._static_url_base is None:
@@ -95,6 +101,9 @@
         cls = self.controllers_dict.get(path)
         if cls is None:
             raise httpexceptions.HTTPNotFound()
-        c = cls(self)
-        c.default(req, response)
-        return response(environ, start_response)
+        self.branch.lock_read()
+        try:
+            c = cls(self, self.get_history())
+            return c(environ, start_response)
+        finally:
+            self.branch.unlock()

=== modified file 'loggerhead/apps/config.py'
--- loggerhead/apps/config.py	2008-06-23 01:03:34 +0000
+++ loggerhead/apps/config.py	2008-07-01 04:01:31 +0000
@@ -1,12 +1,15 @@
-# A server that recreates (modulo cherrypy bugs :) the url parsing
-# from the old, loggerhead.conf approach.
+"""A server that uses a loggerhead.conf file.
 
-# It's all a bit horrible really.
+We recreate the branch discovery and url scheme of the old branchview
+code.  It's all a bit horrible really.
+"""
 
 import logging
 import os
 import posixpath
 
+import bzrlib.lru_cache
+
 from configobj import ConfigObj
 
 from paste.request import path_info_pop
@@ -23,17 +26,23 @@
 
 from loggerhead.history import is_branch
 
-class Project (object):
-    def __init__(self, name, config, root_config):
+class Project(object):
+    """A project contains the branches.
+
+    There is some complication because we don't want to hold on to the
+    branches when they are not being browsed."""
+
+    def __init__(self, name, config, root_config, graph_cache):
         self.name = name
         self.friendly_name = config.get('name', name)
         self.description = config.get('description', '')
         self.long_description = config.get('long_description', '')
         self._config = config
         self._root_config = root_config
+        self.graph_cache = graph_cache
 
-        self.views = []
-        self.views_by_name = {}
+        self.view_names = []
+        self.view_data_by_name = {}
         for view_name in config.sections:
             log.debug('Configuring (project %s) branch %s...', name, view_name)
             self._add_view(
@@ -60,8 +69,8 @@
             return
 
         # rebuild views:
+        self.view_names = []
         log.debug('Rescanning auto-folder for project %s ...', self.name)
-        self._views = []
         for folder in auto_list:
             view_name = os.path.basename(folder)
             log.debug('Auto-configuring (project %s) branch %s...', self.name, view_name)
@@ -77,74 +86,120 @@
             return posixpath.join(url, folder) + '/'
         return None
 
-    def _get_description(self, view, view_config):
+    def _get_description(self, view, view_config, history):
         description = view_config.get('description', None)
         if description is not None:
             return description
-        description = view.history._branch.get_config().get_user_option('description')
+        description = history._branch.get_config().get_user_option('description')
         return description
 
     def _add_view(self, view_name, view_config, folder):
-        view = BranchWSGIApp(folder, view_name, view_config)
-        friendly_name = view_config.get('branch_name', None)
-        if friendly_name is None:
-            friendly_name = view.history.get_config().get_nickname()
+        b = bzrlib.branch.Branch.open(folder)
+        view = BranchWSGIApp(b, view_name, view_config, self.graph_cache)
+        b.lock_read()
+        try:
+            history = view.get_history()
+            friendly_name = view_config.get('branch_name', None)
             if friendly_name is None:
-                friendly_name = view_name
-        view.friendly_name = friendly_name
-        view.name = view_name
-        branch_url = self._get_branch_url(view, view_config, view_name)
-        if branch_url is not None:
-            view.branch_url = branch_url
-        view.description = self._get_description(view, view_config)
-        view._src_folder = folder
-        view._view_config = view_config
-        self.views.append(view)
-        self.views_by_name[view_name] = view
+                friendly_name = history.get_config().get_nickname()
+                if friendly_name is None:
+                    friendly_name = view_name
+            self.view_data_by_name[view_name] = {
+                'branch_path': folder,
+                'args': (view_name, view_config, self.graph_cache),
+                'description': self._get_description(view, view_config, history),
+                '_src_folder': folder,
+                '_view_config': view_config,
+                'friendly_name': friendly_name,
+                'name': view_name,
+                }
+            branch_url = self._get_branch_url(view, view_config, view_name)
+            if branch_url is not None:
+                self.view_data_by_name[view_name]['branch_url'] = branch_url
+            self.view_names.append(view_name)
+        finally:
+            b.unlock()
+
+    def view_named(self, name):
+        view_data = self.view_data_by_name.get(name)
+        if view_data is None:
+            return None
+        view_data = view_data.copy()
+        branch_path = view_data.pop('branch_path')
+        args = view_data.pop('args')
+        b = bzrlib.branch.Branch.open(branch_path)
+        b.lock_read()
+        view = BranchWSGIApp(b, *args)
+        for k in view_data:
+            setattr(view, k, view_data[k])
+        return view
 
     def call(self, environ, start_response):
         segment = path_info_pop(environ)
         if not segment:
             raise httpexceptions.HTTPNotFound()
         else:
-            view = self.views_by_name.get(segment)
+            view = self.view_named(segment)
             if view is None:
                 raise httpexceptions.HTTPNotFound()
-            return view.app(environ, start_response)
+            try:
+                return view.app(environ, start_response)
+            finally:
+                view.branch.unlock()
 
 
 class Root(object):
+    """The root of the server -- renders as the browse view,
+    dispatches to Project above for each 'project'."""
 
     def __init__(self, config):
         self.projects = []
         self.config = config
         self.projects_by_name = {}
+        graph_cache = bzrlib.lru_cache.LRUCache()
         for project_name in self.config.sections:
             project = Project(
-                project_name, self.config[project_name], self.config)
+                project_name, self.config[project_name], self.config, graph_cache)
             self.projects.append(project)
             self.projects_by_name[project_name] = project
 
     def browse(self, response):
+        # This is insanely complicated because we want to open and
+        # lock all the branches, render the view and then unlock the
+        # branches again.
         for p in self.projects:
             p._recheck_auto_folders()
-        class branch:
+        class branch(object):
             @staticmethod
             def static_url(path):
                 return self._static_url_base + path
-        vals = {
-            'projects': self.projects,
-            'util': util,
-            'title': self.config.get('title', None),
-            'branch': branch,
-        }
-        vals.update(templatefunctions)
-        response.headers['Content-Type'] = 'text/html'
-        template = load_template('loggerhead.templates.browse')
-        template.expand_into(response, **vals)
+        views_by_project = {}
+        all_views = []
+        try:
+            for p in self.projects:
+                views_by_project[p] = []
+                for vn in p.view_names:
+                    v = p.view_named(vn)
+                    all_views.append(v)
+                    views_by_project[p].append(v)
+            vals = {
+                'projects': self.projects,
+                'util': util,
+                'title': self.config.get('title', None),
+                'branch': branch,
+                'views_by_project': views_by_project,
+            }
+            vals.update(templatefunctions)
+            response.headers['Content-Type'] = 'text/html'
+            template = load_template('loggerhead.templates.browse')
+            template.expand_into(response, **vals)
+        finally:
+            for v in all_views:
+                v.branch.unlock()
 
     def __call__(self, environ, start_response):
-        self._static_url_base = environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
+        self._static_url_base = environ['loggerhead.static.url'] = \
+                                environ['SCRIPT_NAME']
         segment = path_info_pop(environ)
         if segment is None:
             raise httpexceptions.HTTPMovedPermanently(

=== modified file 'loggerhead/apps/filesystem.py'
--- loggerhead/apps/filesystem.py	2008-06-18 12:27:04 +0000
+++ loggerhead/apps/filesystem.py	2008-07-01 04:01:31 +0000
@@ -1,8 +1,10 @@
+"""Serve branches at urls that mimic the file system layout."""
+
 import cgi
 import os
 import tempfile
 
-from bzrlib import branch, errors
+from bzrlib import branch, errors, lru_cache
 
 from paste.request import path_info_pop
 from paste.wsgiwrappers import WSGIRequest, WSGIResponse
@@ -11,64 +13,71 @@
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.apps import favicon_app, static_app
 
-
 sql_dir = tempfile.mkdtemp()
 
-class BranchesFromFileSystemServer(object):
-    def __init__(self, folder, root):
-        self.folder = folder
-        self.root = root
-
-    def directory_listing(self, path, environ, start_response):
+
+class DirectoryListing(object):
+
+    def __init__(self, path):
+        self.path = path
+
+    def __call__(self, environ, start_response):
         request = WSGIRequest(environ)
         response = WSGIResponse()
-        listing = [d for d in os.listdir(path) if not d.startswith('.')]
+        listing = [d for d in os.listdir(self.path) if not d.startswith('.')]
         response.headers['Content-Type'] = 'text/html'
         print >> response, '<html><body>'
         for d in sorted(listing):
-            if os.path.isdir(os.path.join(path, d)):
+            if os.path.isdir(os.path.join(self.path, d)):
                 d = cgi.escape(d)
                 print >> response, '<li><a href="%s/">%s</a></li>' % (d, d)
         print >> response, '</body></html>'
         return response(environ, start_response)
 
-    def app_for_branch(self, b, path):
+
+class BranchesFromFileSystemServer(object):
+    def __init__(self, folder, root):
+        self.folder = folder
+        self.root = root
+
+    def app_for_branch(self, branch):
         if not self.folder:
-            name = os.path.basename(os.path.abspath(path))
+            name = os.path.basename(os.path.abspath(self.root.folder))
         else:
             name = self.folder
-        h = BranchWSGIApp(path, name, {'cachepath': sql_dir})
-        self.root.cache[path] = h
-        return h.app
+        branch_app = BranchWSGIApp(
+            branch, name, {'cachepath': sql_dir}, self.root.graph_cache)
+        return branch_app.app
+
+    def app_for_non_branch(self, environ):
+        segment = path_info_pop(environ)
+        if segment is None:
+            raise httpexceptions.HTTPMovedPermanently(
+                environ['SCRIPT_NAME'] + '/')
+        elif segment == '':
+            return DirectoryListing(os.path.join(self.root.folder, self.folder))
+        else:
+            relpath = os.path.join(self.folder, segment)
+            return BranchesFromFileSystemServer(relpath, self.root)
 
     def __call__(self, environ, start_response):
         path = os.path.join(self.root.folder, self.folder)
         if not os.path.isdir(path):
             raise httpexceptions.HTTPNotFound()
-        cached = self.root.cache.get(path)
-        if cached is not None:
-            return cached.app(environ, start_response)
         try:
             b = branch.Branch.open(path)
         except errors.NotBranchError:
-            segment = path_info_pop(environ)
-            if segment is None:
-                raise httpexceptions.HTTPMovedPermanently(
-                    environ['SCRIPT_NAME'] + '/')
-            elif segment == '':
-                return self.directory_listing(path, environ, start_response)
-            else:
-                relpath = os.path.join(self.folder, segment)
-                return BranchesFromFileSystemServer(relpath, self.root)(
-                    environ, start_response)
+            return self.app_for_non_branch(environ)(environ, start_response)
         else:
-            return self.app_for_branch(b, path)(environ, start_response)
+            return self.app_for_branch(b)(environ, start_response)
 
 
 class BranchesFromFileSystemRoot(object):
+
     def __init__(self, folder):
-        self.cache = {}
+        self.graph_cache = lru_cache.LRUCache()
         self.folder = folder
+
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
         if environ['PATH_INFO'].startswith('/static/'):

=== removed file 'loggerhead/branchview.py'
--- loggerhead/branchview.py	2008-06-16 09:26:05 +0000
+++ loggerhead/branchview.py	1970-01-01 00:00:00 +0000
@@ -1,161 +0,0 @@
-#
-# Copyright (C) 2006  Robey Pointer <robey@lag.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-"""
-collection of configuration and objects related to a bazaar branch.
-"""
-
-import logging
-import posixpath
-import threading
-import urllib
-
-import turbogears
-from cherrypy import HTTPRedirect
-
-from loggerhead import util
-from loggerhead.changecache import FileChangeCache
-from loggerhead.history import History
-from loggerhead.controllers.changelog_ui import ChangeLogUI
-from loggerhead.controllers.atom_ui import AtomUI
-from loggerhead.controllers.revision_ui import RevisionUI
-from loggerhead.controllers.inventory_ui import InventoryUI
-from loggerhead.controllers.annotate_ui import AnnotateUI
-from loggerhead.controllers.download_ui import DownloadUI
-from loggerhead.controllers.bundle_ui import BundleUI
-
-
-with_history_lock = util.with_lock('_history_lock', 'History')
-
-
-class BranchView (object):
-    def __init__(self, group_name, name, subfolder, absfolder, config,
-                 project_config, root_config):
-        self._group_name = group_name
-        self._name = name
-        self._folder = subfolder
-        self._absfolder = absfolder
-        self._config = config
-        self._project_config = project_config
-        self._root_config = root_config
-        self.log = logging.getLogger('loggerhead.%s' % (name,))
-
-        # branch history
-        self._history_lock = threading.RLock()
-        self._history = None
-
-        self.changes = ChangeLogUI(self)
-        self.revision = RevisionUI(self)
-        self.files = InventoryUI(self)
-        self.annotate = AnnotateUI(self)
-        self.download = DownloadUI(self)
-        self.atom = AtomUI(self)
-        self.bundle = BundleUI(self)
-
-        # force history object to be loaded:
-        self.get_history()
-
-    config = property(lambda self: self._config)
-
-    name = property(lambda self: self._name)
-
-    group_name = property(lambda self: self._group_name)
-
-    def _get_friendly_name(self):
-        name = self._config.get('branch_name', None)
-        if name is not None:
-            return name
-        # try branch-specific config?
-        name = self.get_history().get_config().get_nickname()
-        if name is not None:
-            return name
-        return self._name
-
-    friendly_name = property(_get_friendly_name)
-
-    def _get_description(self):
-        description = self._config.get('description', None)
-        if description is not None:
-            return description
-        # try branch-specific config?
-        description = self.get_history().get_config().get_user_option('description')
-        return description
-
-    description = property(_get_description)
-
-    def _get_branch_url(self):
-        url = self._config.get('url', None)
-        if url is not None:
-            return url
-        # try to assemble one from the project, if an url_prefix was defined.
-        url = self._project_config.get('url_prefix', None)
-        if url is not None:
-            return posixpath.join(url, self._folder) + '/'
-        # try branch-specific config?
-        url = self.get_history().get_config().get_user_option('public_branch')
-        return url
-
-    branch_url = property(_get_branch_url)
-
-    @turbogears.expose()
-    def index(self):
-        raise HTTPRedirect(self.url('/changes'))
-
-    def get_config_item(self, item, default=None):
-        for conf in self._config, self._project_config, self._root_config:
-            if item in conf:
-                return conf[item]
-        return default
-
-    @with_history_lock
-    def get_history(self):
-        """
-        get an up-to-date History object, safely.  each page-view calls this
-        method, and normally it will get the same History object as on previous
-        calls.  but if the bazaar branch on-disk has been updated since this
-        History was created, a new object will be created and returned.
-        """
-        if (self._history is None) or self._history.out_of_date():
-            self.log.debug('Reload branch history...')
-            _history = self._history = History.from_folder(
-                self._absfolder, self._name)
-            cache_path = self._config.get('cachepath', None)
-            if cache_path is None:
-                # try the project config
-                cache_path = self._project_config.get('cachepath', None)
-            if cache_path is not None:
-                _history.use_file_cache(FileChangeCache(_history, cache_path))
-        return self._history
-
-    def url(self, elements, **kw):
-        "build an url relative to this branch"
-        if not isinstance(elements, list):
-            elements = [elements]
-        if elements[0].startswith('/'):
-            elements[0] = elements[0][1:]
-        elements = [urllib.quote(x) for x in elements]
-        return turbogears.url([ '/' + self.group_name, self.name ] + elements, **kw)
-
-    def context_url(self, elements, **kw):
-        "build an url relative to this branch, bringing along browsing context"
-        return self.url(elements, **util.get_context(**kw))
-
-    def last_updated(self):
-        h = self.get_history()
-        change = h.get_changes([ h.last_revid ])[0]
-        return change.date

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2008-06-16 09:51:29 +0000
+++ loggerhead/changecache.py	2008-07-22 00:40:03 +0000
@@ -31,7 +31,6 @@
 from loggerhead import util
 from loggerhead.lockfile import LockFile
 
-
 with_lock = util.with_lock('_lock', 'ChangeCache')
 
 SQLITE_INTERFACE = os.environ.get('SQLITE_INTERFACE', 'sqlite')
@@ -42,8 +41,7 @@
 elif SQLITE_INTERFACE == 'sqlite':
     import sqlite as dbapi2
     _param_marker = '%s'
-else:
-    raise AssertionError("bad sqlite interface %r!?"%SQLITE_INTERFACE)
+
 
 _select_stmt = ("select data from revisiondata where revid = ?"
                 ).replace('?', _param_marker)

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2008-06-19 01:18:01 +0000
+++ loggerhead/controllers/__init__.py	2008-07-22 00:40:03 +0000
@@ -16,53 +16,82 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import re
 import time
 
-from paste.request import path_info_pop
+from paste.request import path_info_pop, parse_querystring
 
 from loggerhead import util
 from loggerhead.templatefunctions import templatefunctions
 from loggerhead.zptsupport import load_template
 
+class BufferingWriter(object):
+
+    def __init__(self, writefunc, buf_limit):
+        self.bytes = 0
+        self.buf = []
+        self.buflen = 0
+        self.writefunc = writefunc
+        self.bytes_saved = 0
+        self.buf_limit = buf_limit
+
+    def flush(self):
+        chunk = ''.join(self.buf)
+        chunk = re.sub(r'\s*\n\s*', '\n', chunk)
+        chunk = re.sub(r'[ \t]+', ' ', chunk)
+        self.bytes_saved += self.buflen - len(chunk)
+        self.writefunc(chunk)
+        self.buf = []
+        self.buflen = 0
+
+    def write(self, data):
+        self.buf.append(data)
+        self.buflen += len(data)
+        self.bytes += len(data)
+        if self.buflen > self.buf_limit:
+            self.flush()
+
 class TemplatedBranchView(object):
 
     template_path = None
 
-    def __init__(self, branch):
+    def __init__(self, branch, history):
         self._branch = branch
+        self._history = history
         self.log = branch.log
 
-    def default(self, request, response):
+    def __call__(self, environ, start_response):
         z = time.time()
-        h = self._branch.history
-        kw = request.GET
+        h = self._history
+        kw = dict(parse_querystring(environ))
         util.set_context(kw)
-
-        h._branch.lock_read()
-        try:
-            args = []
-            while 1:
-                arg = path_info_pop(request.environ)
-                if arg is None:
-                    break
-                args.append(arg)
-
-            vals = {
-                'branch': self._branch,
-                'util': util,
-                'history': h,
-                'url': self._branch.context_url,
-            }
-            vals.update(templatefunctions)
-            del response.headers['Content-Type']
-            vals.update(self.get_values(h, args, kw, response))
-
-            self.log.info('/%s: %r secs' % (
-                self.__class__.__name__, time.time() - z,))
-            if 'Content-Type' not in response.headers:
-                response.headers['Content-Type'] = 'text/html'
-            template = load_template(self.template_path)
-            template.expand_into(response, **vals)
-        finally:
-            h._branch.unlock()
-
+        args = []
+        while 1:
+            arg = path_info_pop(environ)
+            if arg is None:
+                break
+            args.append(arg)
+
+        vals = {
+            'branch': self._branch,
+            'util': util,
+            'history': h,
+            'url': self._branch.context_url,
+        }
+        vals.update(templatefunctions)
+        headers = {}
+        vals.update(self.get_values(h, args, kw, headers))
+
+        self.log.info('Getting information for %s: %r secs' % (
+            self.__class__.__name__, time.time() - z,))
+        if 'Content-Type' not in headers:
+            headers['Content-Type'] = 'text/html'
+        writer = start_response("200 OK", headers.items())
+        template = load_template(self.template_path)
+        z = time.time()
+        w = BufferingWriter(writer, 8192)
+        template.expand_into(w, **vals)
+        w.flush()
+        self.log.info('Rendering %s: %r secs, %s bytes, %s (%2.1f%%) bytes saved' % (
+            self.__class__.__name__, time.time() - z, w.bytes, w.bytes_saved, 100.0*w.bytes_saved/w.bytes))
+        return []

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2008-06-18 12:27:04 +0000
+++ loggerhead/controllers/annotate_ui.py	2008-07-22 00:40:03 +0000
@@ -32,12 +32,11 @@
     path = posixpath.dirname(path)
     return path
 
-
 class AnnotateUI (TemplatedBranchView):
 
     template_path = 'loggerhead.templates.annotate'
 
-    def get_values(self, h, args, kw, response):
+    def get_values(self, h, args, kw, headers):
         if len(args) > 0:
             revid = h.fix_revid(args[0])
         else:

=== modified file 'loggerhead/controllers/atom_ui.py'
--- loggerhead/controllers/atom_ui.py	2008-06-19 19:28:10 +0000
+++ loggerhead/controllers/atom_ui.py	2008-07-22 00:40:03 +0000
@@ -24,15 +24,13 @@
 
     template_path = 'loggerhead.templates.atom'
 
-    def get_values(self, h, args, kw, response):
-        h = self._branch.history
-
+    def get_values(self, h, args, kw, headers):
         pagesize = int(20)#self._branch.config.get('pagesize', '20'))
 
         revid_list = h.get_file_view(h.last_revid, None)
         entries = list(h.get_changes(list(revid_list)[:pagesize]))
 
-        response.headers['Content-Type'] = 'application/atom+xml'
+        headers['Content-Type'] = 'application/atom+xml'
         return {
             'changes': entries,
             'updated': entries[0].date.isoformat() + 'Z',

=== removed file 'loggerhead/controllers/bundle_ui.py'
--- loggerhead/controllers/bundle_ui.py	2008-06-18 06:34:10 +0000
+++ loggerhead/controllers/bundle_ui.py	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-#
-# Copyright (C) 2006  Robey Pointer <robey@lag.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-import time
-
-from paste import httpexceptions
-from paste.request import path_info_pop
-
-
-class BundleUI (object):
-
-    def __init__(self, branch):
-        # BranchView object
-        self._branch = branch
-        self.log = branch.log
-
-    def default(self, request, response):
-        # /bundle/<rev_id>/[<compare_rev_id>/]filename
-        z = time.time()
-        h = self._branch.history
-
-        h._branch.lock_read()
-        try:
-            args = []
-            while 1:
-                arg = path_info_pop(request.environ)
-                if arg is None:
-                    break
-                args.append(arg)
-            if len(args) < 1:
-                raise httpexceptions.HTTPMovedPermanently('../changes')
-            revid = h.fix_revid(args[0])
-            if len(args) >= 3:
-                compare_revid = h.fix_revid(args[1])
-            else:
-                compare_revid = None
-
-            try:
-                bundle_data = h.get_bundle(revid, compare_revid)
-            except:
-                self.log.exception('Exception fetching bundle')
-                raise httpexceptions.HTTPServerError('Could not fetch bundle')
-
-            response.headers['Content-Type'] = 'application/octet-stream'
-            response.headers['Content-Length'] = len(bundle_data)
-            response.write(bundle_data)
-            self.log.info('/bundle: %r seconds' % (time.time() - z,))
-        finally:
-            h._branch.unlock()

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2008-06-18 12:27:04 +0000
+++ loggerhead/controllers/changelog_ui.py	2008-07-22 00:40:03 +0000
@@ -27,7 +27,7 @@
 
     template_path = 'loggerhead.templates.changelog'
 
-    def get_values(self, h, args, kw, response):
+    def get_values(self, h, args, kw, headers):
         if args:
             revid = h.fix_revid(args[0])
         else:
@@ -66,7 +66,7 @@
         navigation = util.Container(
             pagesize=pagesize, revid=revid, start_revid=start_revid,
             revid_list=revid_list, filter_file_id=filter_file_id,
-            scan_url='/changes', branch=self._branch, feed=True)
+            scan_url='/changes', branch=self._branch, feed=True, history=h)
         if query is not None:
             navigation.query = query
         util.fill_in_navigation(navigation)

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2008-06-16 08:08:33 +0000
+++ loggerhead/controllers/download_ui.py	2008-07-01 02:38:56 +0000
@@ -29,39 +29,39 @@
 
 class DownloadUI (object):
 
-    def __init__(self, branch):
-        # BranchView object
+    def __init__(self, branch, history):
         self._branch = branch
+        self._history = history
         self.log = branch.log
 
-    def default(self, request, response):
+    def __call__(self, environ, start_response):
         # /download/<rev_id>/<file_id>/[filename]
         z = time.time()
-        h = self._branch.history
-
-        h._branch.lock_read()
-        try:
-            args = []
-            while 1:
-                arg = path_info_pop(request.environ)
-                if arg is None:
-                    break
-                args.append(arg)
-
-            if len(args) < 2:
-                raise httpexceptions.HTTPMovedPermanently(self._branch.url('../changes'))
-
-            revid = h.fix_revid(args[0])
-            file_id = args[1]
-            path, filename, content = h.get_file(file_id, revid)
-            mime_type, encoding = mimetypes.guess_type(filename)
-            if mime_type is None:
-                mime_type = 'application/octet-stream'
-
-            self.log.info('/download %s @ %s (%d bytes)', path, h.get_revno(revid), len(content))
-            response.headers['Content-Type'] = mime_type
-            response.headers['Content-Length'] = len(content)
-            response.headers['Content-Disposition'] = 'attachment; filename=%s'%(filename,)
-            response.write(content)
-        finally:
-            h._branch.unlock()
+
+        h = self._history
+
+        args = []
+        while 1:
+            arg = path_info_pop(environ)
+            if arg is None:
+                break
+            args.append(arg)
+
+        if len(args) < 2:
+            raise httpexceptions.HTTPMovedPermanently(self._branch.url('../changes'))
+
+        revid = h.fix_revid(args[0])
+        file_id = args[1]
+        path, filename, content = h.get_file(file_id, revid)
+        mime_type, encoding = mimetypes.guess_type(filename)
+        if mime_type is None:
+            mime_type = 'application/octet-stream'
+
+        self.log.info('/download %s @ %s (%d bytes)', path, h.get_revno(revid), len(content))
+        headers = [
+            ('Content-Type', mime_type),
+            ('Content-Length', len(content)),
+            ('Content-Disposition', 'attachment; filename=%s'%(filename,)),
+            ]
+        start_response('200 OK', headers)
+        return [content]

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2008-06-18 12:27:04 +0000
+++ loggerhead/controllers/inventory_ui.py	2008-07-22 00:40:03 +0000
@@ -39,7 +39,7 @@
 
     template_path = 'loggerhead.templates.inventory'
 
-    def get_values(self, h, args, kw, response):
+    def get_values(self, h, args, kw, headers):
         if len(args) > 0:
             revid = h.fix_revid(args[0])
         else:

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-06-18 12:27:04 +0000
+++ loggerhead/controllers/revision_ui.py	2008-07-22 00:40:03 +0000
@@ -30,7 +30,7 @@
 
     template_path = 'loggerhead.templates.revision'
 
-    def get_values(self, h, args, kw, response):
+    def get_values(self, h, args, kw, headers):
 
         if len(args) > 0:
             revid = h.fix_revid(args[0])
@@ -52,7 +52,7 @@
         navigation = util.Container(
             revid_list=revid_list, revid=revid, start_revid=start_revid,
             filter_file_id=filter_file_id, pagesize=1,
-            scan_url='/revision', branch=self._branch, feed=True)
+            scan_url='/revision', branch=self._branch, feed=True, history=h)
         if query is not None:
             navigation.query = query
         util.fill_in_navigation(navigation)

=== added file 'loggerhead/controllers/search_ui.py'
--- loggerhead/controllers/search_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/search_ui.py	2008-07-09 13:41:07 +0000
@@ -0,0 +1,51 @@
+# Copyright (C) 2008  Canonical Ltd
+# Authored by Martin Albisetti <argentina@gmail.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+from paste.httpexceptions import HTTPServerError
+from loggerhead import history
+from loggerhead import util
+from loggerhead.controllers import TemplatedBranchView
+from loggerhead import search
+
+
+class SearchUI(TemplatedBranchView):
+    """
+    
+    Class to output progressive search result terms.
+    """
+
+    template_path = 'loggerhead.templates.search'
+
+    def get_values(self, h, args, kwargs, response):
+        """
+        Default method called from the search box as /search URL
+
+        Returns a list of suggested search terms parsed through the
+        templating engine.
+        """
+        terms = []
+        query = kwargs['query']
+        if len(query) > 0:
+            terms = search.search_revisions(h._branch, query, True)
+            if terms is not None:
+                terms = [term[0] for term in terms]
+            else:
+                # Should show a 'search is not available' etc box.
+                terms = []
+
+        return {'terms':terms}

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2008-06-20 02:20:05 +0000
+++ loggerhead/history.py	2008-07-22 00:40:03 +0000
@@ -35,12 +35,12 @@
 import time
 from StringIO import StringIO
 
+from loggerhead import search
 from loggerhead import util
-from loggerhead.util import decorator
+from loggerhead.wholehistory import compute_whole_history_data
 
 import bzrlib
 import bzrlib.branch
-import bzrlib.bundle.serializer
 import bzrlib.diff
 import bzrlib.errors
 import bzrlib.progress
@@ -48,23 +48,6 @@
 import bzrlib.tsort
 import bzrlib.ui
 
-
-with_branch_lock = util.with_lock('_lock', 'branch')
-
-
-@decorator
-def with_bzrlib_read_lock(unbound):
-    def bzrlib_read_locked(self, *args, **kw):
-        #self.log.debug('-> %r bzr lock', id(threading.currentThread()))
-        self._branch.repository.lock_read()
-        try:
-            return unbound(self, *args, **kw)
-        finally:
-            self._branch.repository.unlock()
-            #self.log.debug('<- %r bzr lock', id(threading.currentThread()))
-    return bzrlib_read_locked
-
-
 # bzrlib's UIFactory is not thread-safe
 uihack = threading.local()
 
@@ -189,88 +172,33 @@
 
 
 class History (object):
-
-    def __init__(self):
+    """Decorate a branch to provide information for rendering.
+
+    History objects are expected to be short lived -- when serving a request
+    for a particular branch, open it, read-lock it, wrap a History object
+    around it, serve the request, throw the History object away, unlock the
+    branch and throw it away.
+
+    :ivar _file_change_cache: xx
+    """
+
+    def __init__(self, branch, whole_history_data_cache):
+        assert branch.is_locked(), (
+            "Can only construct a History object with a read-locked branch.")
         self._file_change_cache = None
-        self._lock = threading.RLock()
-
-    @classmethod
-    def from_branch(cls, branch):
-        z = time.time()
-        self = cls()
         self._branch = branch
-        self._last_revid = self._branch.last_revision()
-
-        self.log = logging.getLogger('loggerhead.%s' % (self._branch.nick,))
-
-        graph = branch.repository.get_graph()
-        parent_map = dict(((key, value) for key, value in
-             graph.iter_ancestry([self._last_revid]) if value is not None))
-
-        self._revision_graph = self._strip_NULL_ghosts(parent_map)
-        self._full_history = []
-        self._revision_info = {}
-        self._revno_revid = {}
-        if bzrlib.revision.is_null(self._last_revid):
-            self._merge_sort = []
-        else:
-            self._merge_sort = bzrlib.tsort.merge_sort(
-                self._revision_graph, self._last_revid, generate_revno=True)
-
-        for (seq, revid, merge_depth, revno, end_of_merge) in self._merge_sort:
-            self._full_history.append(revid)
-            revno_str = '.'.join(str(n) for n in revno)
-            self._revno_revid[revno_str] = revid
-            self._revision_info[revid] = (
-                seq, revid, merge_depth, revno_str, end_of_merge)
-
-        # cache merge info
-        self._where_merged = {}
-
-        for revid in self._revision_graph.keys():
-            if self._revision_info[revid][2] == 0:
-                continue
-            for parent in self._revision_graph[revid]:
-                self._where_merged.setdefault(parent, set()).add(revid)
-
-        self.log.info('built revision graph cache: %r secs' % (time.time() - z,))
-        return self
-
-    @staticmethod
-    def _strip_NULL_ghosts(revision_graph):
-        """
-        Copied over from bzrlib meant as a temporary workaround deprecated 
-        methods.
-        """
-
-        # Filter ghosts, and null:
-        if bzrlib.revision.NULL_REVISION in revision_graph:
-            del revision_graph[bzrlib.revision.NULL_REVISION]
-        for key, parents in revision_graph.items():
-            revision_graph[key] = tuple(parent for parent in parents if parent
-                in revision_graph)
-        return revision_graph
-
-    @classmethod
-    def from_folder(cls, path):
-        b = bzrlib.branch.Branch.open(path)
-        b.lock_read()
-        try:
-            return cls.from_branch(b)
-        finally:
-            b.unlock()
-
-    @with_branch_lock
-    def out_of_date(self):
-        # the branch may have been upgraded on disk, in which case we're stale.
-        newly_opened = bzrlib.branch.Branch.open(self._branch.base)
-        if self._branch.__class__ is not \
-               newly_opened.__class__:
-            return True
-        if self._branch.repository.__class__ is not \
-               newly_opened.repository.__class__:
-            return True
-        return self._branch.last_revision() != self._last_revid
+        self.log = logging.getLogger('loggerhead.%s' % (branch.nick,))
+
+        self.last_revid = branch.last_revision()
+
+        whole_history_data = whole_history_data_cache.get(self.last_revid)
+        if whole_history_data is None:
+            whole_history_data = compute_whole_history_data(branch)
+            whole_history_data_cache[self.last_revid] = whole_history_data
+
+        (self._revision_graph, self._full_history, self._revision_info,
+         self._revno_revid, self._merge_sort, self._where_merged
+         ) = whole_history_data
 
     def use_file_cache(self, cache):
         self._file_change_cache = cache
@@ -279,9 +207,6 @@
     def has_revisions(self):
         return not bzrlib.revision.is_null(self.last_revid)
 
-    last_revid = property(lambda self: self._last_revid, None, None)
-
-    @with_branch_lock
     def get_config(self):
         return self._branch.get_config()
 
@@ -292,9 +217,6 @@
         seq, revid, merge_depth, revno_str, end_of_merge = self._revision_info[revid]
         return revno_str
 
-    def get_revision_history(self):
-        return self._full_history
-
     def get_revids_from(self, revid_list, start_revid):
         """
         Yield the mainline (wrt start_revid) revisions that merged each
@@ -322,18 +244,15 @@
                 return
             revid = parents[0]
 
-    @with_branch_lock
     def get_short_revision_history_by_fileid(self, file_id):
         # wow.  is this really the only way we can get this list?  by
         # man-handling the weave store directly? :-0
         # FIXME: would be awesome if we could get, for a folder, the list of
         # revisions where items within that folder changed.
-        w = self._branch.repository.weave_store.get_weave(file_id, self._branch.repository.get_transaction())
-        w_revids = w.versions()
-        revids = [r for r in self._full_history if r in w_revids]
-        return revids
+        possible_keys = [(file_id, revid) for revid in self._full_history]
+        existing_keys = self._branch.repository.texts.get_parent_map(possible_keys)
+        return [revid for _, revid in existing_keys.iterkeys()]
 
-    @with_branch_lock
     def get_revision_history_since(self, revid_list, date):
         # if a user asks for revisions starting at 01-sep, they mean inclusive,
         # so start at midnight on 02-sep.
@@ -347,7 +266,6 @@
         index = -index
         return revid_list[index:]
 
-    @with_branch_lock
     def get_search_revid_list(self, query, revid_list):
         """
         given a "quick-search" query, try a few obvious possible meanings:
@@ -386,7 +304,7 @@
         if date is not None:
             if revid_list is None:
                 # if no limit to the query was given, search only the direct-parent path.
-                revid_list = list(self.get_revids_from(None, self._last_revid))
+                revid_list = list(self.get_revids_from(None, self.last_revid))
             return self.get_revision_history_since(revid_list, date)
 
     revno_re = re.compile(r'^[\d\.]+$')
@@ -402,12 +320,11 @@
         if revid is None:
             return revid
         if revid == 'head:':
-            return self._last_revid
+            return self.last_revid
         if self.revno_re.match(revid):
             revid = self._revno_revid[revid]
         return revid
 
-    @with_branch_lock
     def get_file_view(self, revid, file_id):
         """
         Given a revid and optional path, return a (revlist, revid) for
@@ -417,7 +334,7 @@
         If file_id is None, the entire revision history is the list scope.
         """
         if revid is None:
-            revid = self._last_revid
+            revid = self.last_revid
         if file_id is not None:
             # since revid is 'start_revid', possibly should start the path
             # tracing from revid... FIXME
@@ -427,7 +344,6 @@
             revlist = list(self.get_revids_from(None, revid))
         return revlist
 
-    @with_branch_lock
     def get_view(self, revid, start_revid, file_id, query=None):
         """
         use the URL parameters (revid, start_revid, file_id, and query) to
@@ -453,7 +369,7 @@
         contain vital context for future url navigation.
         """
         if start_revid is None:
-            start_revid = self._last_revid
+            start_revid = self.last_revid
 
         if query is None:
             revid_list = self.get_file_view(start_revid, file_id)
@@ -471,20 +387,20 @@
             revid_list = self.get_file_view(start_revid, file_id)
         else:
             revid_list = None
-
-        revid_list = self.get_search_revid_list(query, revid_list)
+        revid_list = search.search_revisions(self._branch, query)
         if revid_list and len(revid_list) > 0:
             if revid not in revid_list:
                 revid = revid_list[0]
             return revid, start_revid, revid_list
         else:
+            # XXX: This should return a message saying that the search could
+            # not be completed due to either missing the plugin or missing a
+            # search index.
             return None, None, []
 
-    @with_branch_lock
     def get_inventory(self, revid):
         return self._branch.repository.get_revision_inventory(revid)
 
-    @with_branch_lock
     def get_path(self, revid, file_id):
         if (file_id is None) or (file_id == ''):
             return ''
@@ -493,7 +409,6 @@
             path = '/' + path
         return path
 
-    @with_branch_lock
     def get_file_id(self, revid, path):
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
@@ -572,7 +487,6 @@
                 else:
                     p.branch_nick = '(missing)'
 
-    @with_branch_lock
     def get_changes(self, revid_list):
         """Return a list of changes objects for the given revids.
 
@@ -599,8 +513,6 @@
 
         return changes
 
-    @with_branch_lock
-    @with_bzrlib_read_lock
     def get_changes_uncached(self, revid_list):
         # FIXME: deprecated method in getting a null revision
         revid_list = filter(lambda revid: not bzrlib.revision.is_null(revid),
@@ -657,7 +569,7 @@
         entry = {
             'revid': revision.revision_id,
             'date': commit_time,
-            'author': revision.committer,
+            'author': revision.get_apparent_author(),
             'branch_nick': revision.properties.get('branch-nick', None),
             'short_comment': short_message,
             'comment': revision.message,
@@ -671,7 +583,6 @@
 
         return [self.parse_delta(delta) for delta in delta_list]
 
-    @with_branch_lock
     def get_file_changes(self, entries):
         if self._file_change_cache is None:
             return self.get_file_changes_uncached(entries)
@@ -684,7 +595,6 @@
         for entry, changes in zip(entries, changes_list):
             entry.changes = changes
 
-    @with_branch_lock
     def get_change_with_diff(self, revid, compare_revid=None):
         change = self.get_changes([revid])[0]
 
@@ -703,7 +613,6 @@
 
         return change
 
-    @with_branch_lock
     def get_file(self, file_id, revid):
         "returns (path, filename, data)"
         inv = self.get_inventory(revid)
@@ -836,7 +745,6 @@
             for m in change.changes.modified:
                 m.sbs_chunks = _make_side_by_side(m.chunks)
 
-    @with_branch_lock
     def get_filelist(self, inv, file_id, sort_type=None):
         """
         return the list of all files (and their attributes) within a given
@@ -870,11 +778,14 @@
             file_list.append(file)
 
         if sort_type == 'filename' or sort_type is None:
-            file_list.sort(key=lambda x: x.filename)
+            file_list.sort(key=lambda x: x.filename.lower()) # case-insensitive
         elif sort_type == 'size':
             file_list.sort(key=lambda x: x.size)
         elif sort_type == 'date':
             file_list.sort(key=lambda x: x.change.date)
+        
+        # Always sort by kind to get directories first
+        file_list.sort(key=lambda x: x.kind != 'directory')
 
         parity = 0
         for file in file_list:
@@ -886,7 +797,6 @@
 
     _BADCHARS_RE = re.compile(ur'[\x00-\x08\x0b\x0e-\x1f]')
 
-    @with_branch_lock
     def annotate_file(self, file_id, revid):
         z = time.time()
         lineno = 1
@@ -927,15 +837,3 @@
             lineno += 1
 
         self.log.debug('annotate: %r secs' % (time.time() - z,))
-
-    @with_branch_lock
-    def get_bundle(self, revid, compare_revid=None):
-        if compare_revid is None:
-            parents = self._revision_graph[revid]
-            if len(parents) > 0:
-                compare_revid = parents[0]
-            else:
-                compare_revid = None
-        s = StringIO()
-        bzrlib.bundle.serializer.write_bundle(self._branch.repository, revid, compare_revid, s)
-        return s.getvalue()

=== added file 'loggerhead/search.py'
--- loggerhead/search.py	1970-01-01 00:00:00 +0000
+++ loggerhead/search.py	2008-07-09 13:41:07 +0000
@@ -0,0 +1,64 @@
+# Copyright (C) 2008  Canonical Ltd
+# Authored by Martin Albisetti <argentina@gmail.com>
+#
+# Copyright (C) 2008  Robert Collins
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+import sets
+import os
+try:
+    from bzrlib.plugins.search import errors
+    from bzrlib.plugins.search import index as _mod_index
+    from bzrlib.plugins.search.index import FileTextHit, RevisionHit
+except ImportError:
+    _mod_index = None
+
+def search_revisions(branch, query_list, suggest=False):
+    """
+    Search using bzr-search plugin to find revisions matching the query.
+    This can either suggest query terms, or revision ids.
+    
+    param branch: branch object to search in
+    param query_list: string to search
+    param suggest: Optional flag to request suggestions instead of results
+    return: A list for results, either revision ids or terms
+    """
+    if _mod_index is None:
+        return None # None indicates could-not-search
+    try:
+        index = _mod_index.open_index_branch(branch)
+    except errors.NoSearchIndex:
+        return None # None indicates could-not-search
+    query = query_list.split(' ')
+    query = [(term,) for term in query]
+    revid_list = []
+    index._branch.lock_read()
+
+    try:
+        if suggest:
+            terms = index.suggest(query)
+            terms = list(terms)
+            terms.sort()
+            return terms
+        else:
+            for result in index.search(query):
+                if isinstance(result, FileTextHit):
+                    revid_list.append(result.text_key[1])
+                elif isinstance(result, RevisionHit):
+                    revid_list.append(result.revision_key[0])
+            return list(sets.Set(revid_list))
+    finally:
+        index._branch.unlock()

=== added file 'loggerhead/static/css/annotate.css'
--- loggerhead/static/css/annotate.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/annotate.css	2008-06-23 19:27:37 +0000
@@ -0,0 +1,71 @@
+/*Sub menu tabs*/
+ul#submenuTabs {
+	width:100%;
+	height:24px;
+	list-style:none;
+	color:#fff;
+	background:#fff;
+	margin:0px;
+	padding:10px 0%;
+}
+ul#submenuTabs li a:link, ul#submenuTabs li a:visited {
+	float:left;
+	display:inline;
+	height:22px;
+	padding:2px 15px 0px 15px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#d18b39;
+}
+ul#submenuTabs li {
+	float:left;
+	display:inline;
+	margin-left:1px;
+	color:#fff;
+	background:#d18b39;
+}
+ul#submenuTabs li a:hover {
+	float:left;
+	display:inline;
+	color:#fff;
+	background:#d18b39;
+	text-decoration:underline;
+}
+ul#submenuTabs li#inicio a, ul#submenuTabs li#inicio a:link, ul#submenuTabs li#inicio a:visited, ul#submenuTabs li#inicio a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) top left no-repeat;
+}
+ul#submenuTabs li#final a, ul#submenuTabs li#final a:link, ul#submenuTabs li#final a:visited, ul#submenuTabs li#final a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
+}
+/*table*/
+.annoLineTit, .annoLine, .annoRevTit, .annoRev, .annoComm, .annoCommTit, .annoContTit, .annoCont {
+	padding:4px;
+	width:45px;
+	border:1px solid #d2d2d2;
+}
+.annoLine, .annoRev, .annoComm, .annoCont {
+	padding:5px 0px;
+	border:none;	
+}
+.annoLine {
+	width:37px;
+	padding:5px 4px;
+}
+.annoContTit, .annoCont {
+	width:auto;
+}
+.annoRevTit, .annoRev {
+	width:70px;
+	text-align:center;
+}
+.annoComm, .annoCommTit {
+	width:200px;
+}
+.annoLine, .annoCont {
+	font:normal 12px/normal 'monospace';
+}
+.annoLine {
+	text-align:right;
+}

=== added file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/diff.css	2008-06-27 00:55:39 +0000
@@ -0,0 +1,165 @@
+/*Sub menu tabs*/
+ul#submenuTabs {
+	width:100%;
+	height:24px;
+	list-style:none;
+	color:#fff;
+	background:#fff;
+	margin:0px;
+	padding:10px 0%;
+}
+ul#submenuTabs li a:link, ul#submenuTabs li a:visited {
+	float:left;
+	display:inline;
+	height:22px;
+	padding:2px 15px 0px 15px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#d18b39;
+}
+ul#submenuTabs li {
+	float:left;
+	display:inline;
+	margin-left:1px;
+	color:#fff;
+	background:#d18b39;
+}
+ul#submenuTabs li a:hover {
+	float:left;
+	display:inline;
+	color:#fff;
+	background:#d18b39;
+	text-decoration:underline;
+}
+ul#submenuTabs li#inicio a, ul#submenuTabs li#inicio a:link, ul#submenuTabs li#inicio a:visited, ul#submenuTabs li#inicio a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) top left no-repeat;
+}
+ul#submenuTabs li#final a, ul#submenuTabs li#final a:link, ul#submenuTabs li#final a:visited, ul#submenuTabs li#final a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
+}
+/*Info Box*/
+#infoContainer {
+	width:970px;
+	padding:10px 10px 0px 10px;
+	margin:0px 0px 10px 0px;
+	color:#666;
+	background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
+	border:1px solid #b7b7b7;
+}
+ul#list-files {
+	float:right;
+	width:460px;
+	list-style:none;
+	margin:0px;
+	padding:0px;
+	font:normal 11px/normal sans-serif;
+	color:#000;
+}
+ul#list-files li {
+	width:440px;
+	padding:2px 0px 2px 20px;
+	margin:0px 0px 2px 0px;
+	background:url(../images/ico_file.gif) 2px 0px no-repeat;
+}
+#infTxt {
+	float:left;
+	width:493px;
+	margin:0px 0px 5px 0px;
+}
+.information, .comiter, .timer, .mfrom, .revid {
+	clear:both;
+	margin:0px;
+	padding:0px 0px 2px 18px;
+	font:normal 11px/1.3 sans-serif;
+	color:#666;
+	background:url(../images/ico_description.gif) no-repeat top left;
+}
+.revid {
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+}
+.comiter, .mfrom {
+	clear:none;
+	color:#000;
+	padding:1px 0px 0px 18px;
+	margin:0px 10px 5px 0px;
+	float:left;
+	display:inline;
+	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+}
+.timer {
+	margin:0px 10px 5px 0px;
+	padding:1px 0px 0px 18px;
+	float:left;
+	clear:none;
+	display:inline;
+	background:url(../images/ico_time.gif) no-repeat top left;
+}
+.mfrom {
+	background:url(../images/ico_mergefrom.gif) no-repeat top left;
+}
+/**/
+#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
+	color:#0f6b97;
+	text-decoration:none;
+	margin-right:10px;
+	float:left;	
+}
+#loggerheadCont p.codin, #loggerheadCont p.codin a, #loggerheadCont p.codin a:link, #loggerheadCont p.codin a:visited, #loggerheadCont p.codin a:hover {
+	color:#000;
+	font-size:12px;
+	text-decoration:none;
+	margin-right:10px;
+	float:left;	
+}
+/*Diff Boxes*/
+.diffBox {
+	width:100%;
+	padding:6px 0%;
+	background:#eef6fa;
+	border:1px solid #d2d2d2;
+	margin:10px 0px 0px 0px;
+}
+.diffBox img {
+	vertical-align:middle;
+}
+.diffBox a, .diffBox a:link, .diffBox a:visited, .diffBox a:hover {
+	text-decoration:none;
+}
+.lineNumber {
+	float:left;
+	width:2%;
+	padding:0px 1%; 
+	border-right:1px solid #d5d5d5;
+	border-left:1px solid #d5d5d5;
+	color:#000;
+	background:#f8fbfd;
+	font:normal 12px/1.8 'monospace';	
+	text-align:right;
+}
+.lineCode, .removecode, .addcode {
+	float:left;
+	width:43%;
+	padding:0px 1%; 
+	color:#000;
+	background:#fff;
+	font:normal 12px/1.8 'monospace';
+}
+.delete, .insert {
+	display:block;
+	background:#ff7f7f;
+}
+.insert {
+	background:#92ed92;
+}
+ul#pages {
+	margin-top:10px;
+}
+/*Foot Links*/
+#loggerheadCont p.lpandbzr {
+	float:left;
+	padding:3px 0px 0px 0px;
+	margin-top:10px;
+}

=== added file 'loggerhead/static/css/files.css'
--- loggerhead/static/css/files.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/files.css	2008-07-22 00:22:49 +0000
@@ -0,0 +1,88 @@
+/*Sub menu tabs*/
+ul#submenuTabs {
+	width:100%;
+	height:24px;
+	list-style:none;
+	color:#fff;
+	background:#fff;
+	margin:0px0px10px0px;
+	padding:10px 0%;
+}
+ul#submenuTabs li a:link, ul#submenuTabs li a:visited {
+	float:left;
+	display:inline;
+	height:22px;
+	padding:2px 15px 0px 15px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#d18b39;
+}
+ul#submenuTabs li {
+	float:left;
+	display:inline;
+	margin-left:1px;
+	color:#fff;
+	background:#d18b39;
+}
+ul#submenuTabs li a:hover {
+	float:left;
+	display:inline;
+	color:#fff;
+	background:#d18b39;
+	text-decoration:underline;
+}
+ul#submenuTabs li#inicio a, ul#submenuTabs li#inicio a:link, ul#submenuTabs li#inicio a:visited, ul#submenuTabs li#inicio a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) top left no-repeat;
+}
+ul#submenuTabs li#final a, ul#submenuTabs li#final a:link, ul#submenuTabs li#final a:visited, ul#submenuTabs li#final a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
+}
+/*Info Box*/
+#infoContainer {
+	width:900px;
+	padding:10px 10px 0px 10px;
+	margin:0px 0px 10px 0px;
+	color:#666;
+	background:#fcfcfc;
+	border:1px solid #b7b7b7;
+}
+.information, .comiter, .timer, .mfrom, .revid {
+	float:left;
+	margin:0px 10px 5px 0px;
+	padding:0px 0px 2px 18px;
+	font:normal 11px/1.3 sans-serif;
+	color:#666;
+	background:url(../images/ico_description.gif) no-repeat top left;
+}
+.revid {
+    float:left;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+}
+.comiter, .mfrom {
+	clear:none;
+	color:#000;
+	padding:1px 0px 0px 18px;
+	margin:0px 10px 5px 0px;
+	float:left;
+	display:inline;
+	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+}
+.timer {
+	margin:0px 10px 5px 0px;
+	padding:1px 0px 0px 18px;
+	float:left;
+	clear:none;
+	display:inline;
+	background:url(../images/ico_time.gif) no-repeat top left;
+}
+.mfrom {
+	background:url(../images/ico_mergefrom.gif) no-repeat top left;
+}
+.information {
+    clear:both;
+    width:100%;
+    position:relative;
+}

=== added file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/global.css	2008-06-30 14:28:38 +0000
@@ -0,0 +1,267 @@
+body {
+	padding:0px;
+	margin:0px;
+	font:normal 12px/normal sans-serif;
+	color:#666;
+	background:#fff;
+}
+a, a:link, a:visited, a:hover {
+	color:#0f597f;
+	text-decoration:none;
+	font-weight:normal;
+	outline:none;
+}
+img {
+	padding:0px;
+	margin:0px;
+	border:0px;
+	outline:none;
+}
+form {
+	margin:0;
+	padding:0;
+}
+.clear {
+	clear:both;
+	font-size:0px;
+	height:0px;
+}
+.fr {float:right;}
+.fl {float:left;}
+
+ul {
+    list-style:none;
+}
+
+/* Loggerhead Menu tabs */
+ul#menuTabs {
+	width:98%;
+	height:33px;
+	list-style:none;
+	color:#fff;
+	background:#fff url(../images/bg_menuTabs.gif) bottom repeat-x;
+	margin:0px;
+	padding:12px 0px 0px 2%;
+}
+ul#menuTabs li a:link, ul#menuTabs li a:visited {
+	float:left;
+	width:93px;
+	padding:10px 0px 0px 0px;
+	height:23px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#ad2001 url(../images/bg_Tabs.gif) bottom center;
+}
+ul#menuTabs li {
+	float:left;
+	color:#fff;
+	background:#f00 url(../images/bg_Tabs.gif) bottom center;
+}
+ul#menuTabs li a:hover {
+	float:left;
+	color:#000;
+	background:#666 url(../images/bg_Tabs.gif) top center;
+	text-decoration:none;
+}
+ul#menuTabs li a#on:link, ul#menuTabs li a#on:visited, ul#menuTabs a#on:hover {
+	float:left;
+	color:#000;
+	background:#666 url(../images/bg_Tabs.gif) top center;
+	text-decoration:none;
+}
+
+/* Search & RSS */
+#finderBox {
+	width:300px;
+	float:right;
+	padding:0px;
+}
+#finderBox label {
+	float:left;
+	display:inline;
+	width:100px;
+	font:normal 12px/normal sans-serif;
+	text-align:right;
+	color:#000;
+	padding:5px 5px 0px 0px;
+}
+#finderBox input {
+	float:left;
+	font:normal 12px/normal sans-serif;
+	color:#666;
+	display:inline;
+	width:130px;
+	padding:3px;
+	background:#fff url(../images/bg_search_input.gif) 118px 3px no-repeat;
+	border:1px solid #e9e9e9;
+}
+.rssfeed {
+	float:left;
+	display:inline;
+	padding:0px 0px 0px 10px;
+}
+
+/* General Content */
+#loggerheadCont {
+	width:98%;
+	padding:10px 1%;
+	color:#242424;
+	background:#fff;
+}
+#loggerheadCont h1 {
+	font-size:18px;
+	color:#666;
+	margin:0px;
+	padding:10px 0px 5px 0px;
+}
+#loggerheadCont h1 span {
+    color:#889ea9;
+}
+#loggerheadCont p {
+	color:#000;
+	margin:0px;
+	padding:5px 0px;
+}
+#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
+	color:#000;
+	text-decoration:none;	
+}
+#loggerheadCont p img {
+	vertical-align:middle;
+}
+.link {
+	padding:0px 11px 0px 0px;
+	margin:0px 2px 0px 0px;
+	font-weight:bold;
+	background:url(../images/ico_link.gif) right top no-repeat;
+}
+.revnolink a, .revnolink a:visited, .revnolink a:link, .revnolink a:hover {
+	color:#CC6600;
+	text-decoration:none;		
+}
+
+/*Log Table*/
+#logentries {
+	caption-side:top;
+	width:99%;
+	margin:0px auto 10px auto;
+	padding:0px;
+	background:#fff;
+	border:none;
+	border-spacing:0px;
+	border-collapse:collapse;
+}
+.logheader {
+	background:#fff;
+	font:bold 14px/normal sans-serif;
+	padding:0px;
+	margin:0px;
+}
+.blueRow0, .blueRow1 {
+	background:#eef6fa;
+	font:normal 14px/normal sans-serif;	
+	padding:0px;
+	margin:0px;
+}
+.blueRow1 {
+	background:#f8fbfd;
+}
+.revisionnumber, .expandcell, .diffcell, .downloadcell, .revnro, .expcell, .diffr, .downr, .allicones {
+	padding:4px 0px;
+	width:42px;
+	text-align:center;
+	border:1px solid #d2d2d2;
+}
+.expandcell, .expcell {
+	width:28px;	
+}
+.summarycell, .authorcell, .datecell, .summcell, .autcell, .date, .timedate, .timedate2 {
+	padding:4px 8px;
+	border:1px solid #d2d2d2;
+}
+.authorcell, .autcell {
+	width:202px;
+}
+.datecell, .date {
+	width:110px;
+}
+.timedate, .timedate2 {
+	width:80px;
+}
+.downloadcell, .downr {
+	width:47px;
+}
+.revnro, .expcell, .diffr, .summcell, .autcell, .date, .downr, .allicones, .timedate2 {
+	border:none;
+	border-bottom:1px solid #d2d2d2;
+}
+.revisioninfo {
+    margin-top:4px;
+}
+ul.expandrev {
+	list-style:none;
+	font:normal 11px/normal sans-serif;
+	color:#000;
+}
+ul.expandrev li {
+	padding:2px 0px 2px 20px;
+	margin:0px 0px 2px 0px;
+}
+ul.expandrev li.mergefrom {
+	background:url(../images/ico_mergefrom.gif) 0px 0px no-repeat;
+}
+ul.expandrev li.committerli {
+	background:url(../images/ico_committer.gif) 2px 0px no-repeat;
+}
+ul.expandrev li.desc {
+	background:url(../images/ico_description.gif) 0px 0px no-repeat;
+	color:#666;
+}
+ul.expandrev li.files {
+	background:url(../images/ico_file.gif) 2px 0px no-repeat;
+    margin-left: 8px;
+}
+
+/* Navigation */
+ul {border:0; margin:0; padding:0;}
+
+ul#pages {
+	float:right;
+}
+#pages li {
+	border:0; margin:0; padding:0;
+	font-size:12px;
+	list-style:none;
+	float:left;
+	display:inline;
+}
+#pages a {
+	border:solid 1px #DDDDDD;
+	margin-right:2px;
+}
+#pages .next a, #pages .previous a {
+	font-weight:bold;
+	border:solid 1px #fff;
+}
+#pages .active {
+	color:#f37b06;
+	font-weight:bold;
+	display:block;
+	float:left;
+	padding:4px 6px;
+}
+#pages a:link, #pages a:visited {
+	color:#f37b06;
+	display:block;
+	float:left;
+	padding:3px 6px;
+	text-decoration:none;
+}
+#pages .next a {
+	color:#0f6b97;
+}
+#pages a:hover {
+	border:solid 1px #666666;
+}		

=== added file 'loggerhead/static/css/launchpad_slimmer.css'
--- loggerhead/static/css/launchpad_slimmer.css	1970-01-01 00:00:00 +0000
+++ loggerhead/static/css/launchpad_slimmer.css	2008-06-17 23:17:20 +0000
@@ -0,0 +1,4 @@
+.demo{background-color:#fee}.clearfix:after{content:".";display:block;height:0;clear:both;visibility:hidden}.clearfix{display:inline-table}/* Work around float bug in MSIE for Windows,while hiding from MSIE for Mac \*/
+* html .clearfix{height:1%}.clearfix{display:block}/* End hiding from MSIE for Mac */
+.visualClear{display:block;clear:both}abbr[title],acronym[title]{border-bottom:1px dotted black;cursor:help}address{font-style:inherit}* html body{word-wrap:break-word}caption{caption-side:bottom;text-align:left}dt dfn{font-style:normal;font-weight:bold}dd{margin-bottom:1em}input{visibility:inherit}kbd{background-color:#ddd;border:1px solid;border-color:white gray gray white;color:black;margin:1px;min-width:1em;outline:1px #666}label{white-space:nowrap;font-weight:bold}legend{font-weight:bold}legend legend{font-weight:normal}.listbox{border:1px solid #8cacbb;display:inline-block;max-height:12em;overflow:auto;overflow:-moz-scrollbars-vertical}.listbox label{background-color:#f6f6f6;border:solid white;border-width:0 0 1px 0;display:block}table{border-collapse:collapse}textarea{display:block}thead{vertical-align:bottom}tr{vertical-align:top}th{text-align:right}thead th,tr.thead th{text-align:center}table.radio-button-widget tr td{vertical-align:top}html{position:static;font-family:sans-serif;font-size:10pt;color:#333;background-color:#fff}body{margin:0;padding:0;min-width:529px}:link{color:#039;text-decoration:none}:link:hover,:visited:hover{text-decoration:underline}:link:active,:visited:active{color:#36c}:visited{color:#324c7f;text-decoration:none}h1,h2,h3,h4,h5,h6{background:none;padding:0;margin:0;color:#83ad23;font-weight:normal}h1{font-size:2.2em}h2{font-size:1.5em}h3{font-size:1.1em}h4,h5,h6{font-size:1em}h1,h2,h3,h4,h5,h6{margin-bottom:0.5em}h2,h3,h4,h5,h6{margin-top:1em}.exception{color:#c00}.discreet,.lesser{font-size:80%}.offline{text-align:center;width:100%;margin:2em auto !important}.unavailable{color:#999;background:none}.error,.warning,.informational{padding:0.5em}.message{background:5px 0.5em no-repeat;font-weight:bold;margin:1em 0 0.5em;padding:0.5em 1em 0.5em 30px}.error .message,.warning .message,.informational .message{margin:0.25em 0 0;padding:0 0 0 25px;background:0 0 no-repeat}.error{color:#db1f22}.error.message,.error .message{background-image:url(/@@/error)}td.error{border:1px solid #db1f22;background-color:#fff}.warning{background-color:#fcdd99;color:black}.warning.message,.warning .message{background-image:url(/@@/warning)}.helpwanted{background-color:#fafca9;color:black;border:1px solid black;padding:0.5em;font-size:smaller;padding-left:3em}.helpwanted.message,.helpwanted .message{background-image:url(/@@/helpwanted)}.informational{background-color:#fcfc99;color:black}.informational.message,.informational .message{background-image:url(/@@/info)}.debugging{background-color:#666;color:white}.debugging.message,.debugging .message{background-image:url(/@@/info)}.whiteboard{color:#666}dd .whiteboard{padding-left:1em}form{border:0;margin:0;padding:0}input[type="text"],input[type="password"],textarea{font-family:sans-serif;margin:0}input[type="text"],input[type="submit"],input[type="reset"],textarea{font-size:1em}button,input[type="button"],input[type="file"],input[type="password"],input[type="submit"],input[type="text"],select,textarea{margin-right:0.5em}input.urlTextType{width:100%}.fieldRequired,.fieldOptional{color:#999;font-weight:normal}.formHelp{margin-top:0.2em;margin-bottom:0.5em;color:#777}table.listing div.field>table{margin-top:0.5em}table.listing div.field>label,table.listing div.field>div>label,table.listing div.actions{display:block;margin-top:1em}textarea{width:100%}table.form{margin-top:1em;margin-bottom:1em;width:100%}table.slimpadding td,table.slimpadding th{padding:0;padding-right:3px}a img{border:none}img{border:none}.collapsible legend a,.collapsible legend a:visited{text-decoration:none;color:#008}img.collapseIcon{text-decoration:none;margin-bottom:-3px}.collapsible legend a span{text-decoration:underline}.collapsible{padding:0;margin:0}.collapsed{border:none;margin-bottom:0}fieldset .collapsed{display:none}fieldset .expanded{display:block}form.primary.search{margin-bottom:2em}@media print{.notforprint{display:none}}@media screen{.notforscreen{display:none}}.highlighted,tr.highlight{background:#ddd;border:1px solid #ddd}.highlighted{padding:0.5em}.highlighted h3{margin-top:0}.unhighlighted{padding:0 0.5em}hr{border:0;margin:8px 0px 0px 0px;padding:6px 0px 0px 0px;width:100%;height:2px;border-top:2px solid #000;overflow:hidden;display:none}h1 em,h2 em,h3 em,h4 em,h5 em{font-style:normal;color:#353535}h1 span,h2 span,h3 span,h4 span,h5 span{color:#656565}strong em{font-style:normal;color:#353535}strong span{color:#656565}.link_img{border:0}.debug{background:none;color:#f09}.anchor{height:1px;overflow:hidden;display:none}hr{display:none}#globalheader{position:relative;width:100%;height:21px;overflow:hidden;margin:0;background-color:#EEE;background-image:url(globalheader_bg.gif);background-repeat:repeat-x;background-position:top center}#globalheader a.home{display:block;margin:0;padding:0}#globalheader .sitemessage a{color:#FFF;text-decoration:underline}#globalheader .sitemessage{position:absolute;top:2px;left:10px;display:inline;color:#FFF;font-size:13px}#globalheader img.launchpad{position:absolute;top:0;right:0}#topline{position:relative;width:100%;height:1px;overflow:hidden;margin:0;background-color:#6D6D6D}#locationbar{width:100%;height:26px;margin:0;padding:0;list-style:none;background-color:#AFDB1F;font-size:11px;font-weight:bold;color:#FFF}ul#menuroot a#homebreadcrumb span{background:url(home-low-high.gif) left top no-repeat;padding-left:16px}ul#menuroot li a#homebreadcrumb:hover span,ul#menuroot li.selected a#homebreadcrumb span{background:url(home-low-high.gif) left -20px no-repeat;padding-left:16px}ul#menuroot{display:inline;float:left;margin:0;padding:0 16px 0 0;margin:0;height:26px}ul#menuroot li{display:inline}ul#menuroot a.breadcrumb{position:relative;background-image:url(locationbar_a_bg.gif);background-repeat:no-repeat;background-position:-1000px 0px;display:block;float:left;margin-right:-16px}#yourlocation{float:left;display:block;background-image:url(locationbar_a_bg.gif);background-repeat:no-repeat;background-position:-1100px 0px;padding:6px 0 6px 10px;margin-right:-1px;height:14px}* html #yourlocation{padding-bottom:4px}#locationbar li a,#locationbar li span{display:block;color:#000}#locationbar li .unlinked{color:#83AD23}ul#menuroot a.breadcrumb em{font-style:normal;float:left;display:block;background-image:url(locationbar_nodrop_em_bg.gif);background-repeat:no-repeat;background-position:right top;padding:6px 26px 6px 20px;cursor:pointer}* html ul#menuroot a.breadcrumb em{padding-bottom:4px}ul#menuroot a.container.breadcrumb em{background-image:url(locationbar_em_bg.gif)}#locationbar ul.menu li a,#locationbar ul.menu li .unlinked{background-image:none;background-color:#AFDB1F;float:none;padding-left:16px;padding-right:16px;padding-top:3px;padding-bottom:3px;height:auto}#locationbar ul.menu li{margin-bottom:0px;padding-bottom:0px}#locationbar ul.menu{background-color:#AFDB1F;position:absolute;z-index:2000;margin-left:0px;border-right:1px solid #90B51A;border-bottom:1px solid #90B51A;border-top:1px solid #DCF58B;border-left:1px solid #DCF58B;padding-left:0px;padding-right:0px}* html ul#menuroot a.container.breadcrumb em{background-image:url(locationbar_nodrop_em_bg.gif)}* html #locationbar ul.menu{display:none}#locationbar li a:hover{text-decoration:none}#locationbar ul#rootmenu ul.menu li a:hover{}#locationbar ul.menu li a{background-color:#AFDB1F;color:#000}#locationbar ul.menu li.selected>a{background-color:#C8EF48;color:#000}ul#menuroot li a.breadcrumb:hover{background-position:0px 0px;color:#000}ul#menuroot li.selected a.breadcrumb{background-position:0px 0px;color:#000}#locationbar ul.menu a.container{background-image:url(/@@/arrowRight);background-repeat:no-repeat;background-position:center right}#locationbar{overflow:visible}#locationbar li a,#locationbar li .unlinked{left:auto;margin:0px 0px 0px 0px;white-space:pre}#logincontrol{float:right;height:100%;background-color:#AFDB1F;margin:0}#logincontrol td{color:#FFF;font-size:11px;font-weight:bold;vertical-align:middle;padding-top:0;padding-bottom:0;padding-left:10px;padding-right:10px}#logincontrol input[type='submit']{margin-right:0}#logincontrol a{color:#000}#help{clear:both;position:absolute;top:27px;left:0;width:300px;z-index:100}#help-tab{background:url(help-tab.gif);float:right;width:32px;height:62px;padding:0;color:#f7f7f7;font-size:1px;margin:0}#help-panel{float:left;width:268px}#help-content{background:#fff url(help_bg.gif) top right repeat-y;margin:0;padding:0;min-height:70px}* html #help-content{height:70px}#help-text{padding:1px 14px 6px 10px}#help-bottom{clear:both;font-size:1px;height:6px;background:url(help-bottom.gif) bottom right no-repeat}#help.open #help-tab{background:url(help-tab-open.gif)}#help.closed{width:32px}#help.closed #help-panel{display:none}#help{visibility:hidden}#nonhelp{margin:0 20px 0 38px;padding-top:10px}#globalfooter{clear:both;margin-left:-20px}body.freeform #globalfooter{border-top:1px solid #cbcbcb;padding-top:0.5em}#colophon{float:left;width:49%}#applications-footer{float:right;text-align:right;width:49%}#copyright{float:right;text-align:right;width:48%}table#applications{margin-bottom:-0.5em}table#applications th,table#applications td{vertical-align:bottom}table#applications th{padding-left:60px;text-align:left}table#applications th h1{margin:0;padding:0}table#applications td{text-align:right}body.tab-branches #applications,body.tab-bugs #applications,body.tab-specifications #applications,body.tab-answers #applications,body.tab-translations #applications{background-position:left bottom !important}body.pillarindex table#applications th{padding-left:0}#globalsearch{float:right;font-size:10px;margin-top:15px;margin-bottom:8px}#globalsearch #searchbutton{position:relative;top:6px;border:0;width:20px;height:20px;cursor:pointer}#globalsearchscope{padding:4px 0 0}#globalsearchscope label{display:block;padding:0 0 2px}.clear{clear:both;height:0px;overflow:hidden}#structuralobject,#applications{position:relative;z-index:1}#structuralobjectheading img{z-index:2}#structuralobjectheading{background:none;color:black;float:left;width:70%}#structuralobjectheading img{float:left;margin:0;margin-right:3px;margin-bottom:-32px}#structuralobjectheading .intro{margin:2px 0 0 70px;font-size:12px}#structuralobjectheading .main{font-weight:bold;margin:1px 0 0 70px;font-size:24px}#mainarea{clear:both;background-image:url(mainarea_bottom.gif);background-repeat:repeat-x;background-position:bottom left;margin:0 -20px 0 -38px;position:relative}#mainarea div.v{position:relative;width:100%;background:url(mainarea_bottomleft.gif) bottom left no-repeat}#mainarea div.w{position:relative;width:100%;background:url(mainarea_bottomright.gif) bottom right no-repeat}#mainarea div.x{position:relative;width:100%;background:url(mainarea_top.gif) top left repeat-x}#mainarea div.y{position:relative;width:100%;background:url(mainarea_topleft.gif) top left no-repeat}#mainarea div.z{position:relative;width:100%;background:url(mainarea_topright.gif) 100% top no-repeat}#container{margin-top:30px;padding:48px 20px 40px 240px;position:relative}* html #container{margin-top:0;position:static}body.onecolumn #container{padding-left:20px}#container.private{background:url(/@@/private-bg) left 28px repeat-x}body.applicationhome #container{padding-left:20px}#maincontent{width:100%;padding:0 0 20px 0;display:inline;float:left;position:relative}#portlets .portlet{width:200px}ul#applicationchooser{position:absolute;right:0;width:510px;height:32px;overflow:hidden;margin:0px 0px 18px 0px;padding:0;list-style:none;font-size:11px;background-image:url(mainarea_topright.gif);background-repeat:no-repeat;background-position:top right}div#noapplicationchooser{clear:both;margin-bottom:-28px}ul#applicationchooser li{float:left;display:block;width:82px;height:40px;background-image:url(appchoose_a.gif);background-repeat:no-repeat;background-position:-100px 0px;overflow:hidden;text-align:center;font-weight:bold;color:#000}ul#applicationchooser li a{display:block;padding:7px 0px 0px 0px;height:40px}ul#applicationchooser li span.selected,ul#applicationchooser li span.disabled,ul#applicationchooser li.unavailable{display:block;padding:8px 0px 0px 0px;cursor:default}ul#applicationchooser li span.disabled:hover,ul#applicationchooser li.unavailable:hover{background-position:-100px 0px}ul#applicationchooser li span.disabled,ul#applicationchooser li.unavailable{color:lightgrey}ul#applicationchooser li:hover{background-position:0px 0px}ul#applicationchooser a:hover{text-decoration:none}ul#applicationchooser li#applicationchooser_selected{background-position:-200px 0px}#portlets{position:relative;display:inline;float:left;width:200px;overflow:hidden;margin:0 0 20px -100%;padding:0 20px;list-style:none;right:240px}* html #portlets{left:20px}#portlets .portlet{clear:both;float:left}#portlets .portlet h2{display:block;width:180px;height:17px;background-color:#8F8F8F;background-image:url(leftnav_bg.gif);background-repeat:no-repeat;background-position:left top;overflow:hidden;padding:3px 10px 0px 10px;margin:0px 0px 1px 0px;color:#FFF;font-weight:bold}#portlets .portlet h2 a,#portlets .portlet h2 a:hover{display:block;color:inherit;text-decoration:inherit}#portlets .portlet.expanded h2{background-image:url(leftnav_bg_expanded.gif)}#portlets #actions h2{background-image:url(leftnav_bg_uncollapsible.gif)}#portlets .portlet h2:hover{background-color:#A3A3A3;text-decoration:none}#portlets .portletBody{border-left:2px solid #ebebeb;border-right:2px solid #ebebeb;background-color:#EBEBEB;padding:3px 12px 3px 8px !important;color:#717171}#portlets .portlet{overflow:hidden;margin:0 0 0.5em 0;list-style:none;font-size:11px}#portlets .portlet.expanded .portletBody{display:block}#portlets .portlet.collapsed .portletBody{display:none}#portlets .portlet,#portlets .portlet h2,#portlets .portlet li{font-size:12px !important}#portlets .portlet h2{margin-top:0 !important;margin-bottom:0 !important;padding-top:0 !important;padding-bottom:0 !important}#portlets .portlet ul li a:hover{background-color:#fff;text-decoration:underline}#portlets .portlet.active h2 a{background-color:#9BC11B}#portlets .portlet.active h2 a:hover{background-color:#AFDB1F}#portlets .portlet.active div,#portlets .portlet.active ul,#portlets .portlet.active ul li a,#portlets .portlet.active ul li a:hover{background-color:#EBF6C7}#portlets li.active ul,#portlets li.active ul li a,#portlets li.active ul li a:hover{background-color:#EBF6C7}#actions ul{list-style-type:none;margin:0;padding:4px;width:192px}#actions li{margin:0;padding:1px 0}#actions a,#actions strong{background:url(action.png) 4px center no-repeat;display:block;padding:2px 2px 2px 14px}#actions a:hover{background-color:#fff;text-decoration:underline}.check,.radio{background:transparent;width:auto !important;border:0 !important}#structural-children{clear:both;font-size:0.75em;margin-top:2em;padding:2em 0 0;border-top:1px dotted #cbcbcb}#applicationchooser{clear:both;position:relative;z-index:10}.related{margin-top:4em;border-top:1px solid #cbcbcb;padding-top:1em}.related ul{list-style:none;margin-left:0 !important;padding-left:0 !important;text-indent:0.5em}.related ul li:before{content:"\00BB \0020"}#maincontent ol,#maincontent ul{margin-left:24px;padding-left:0}ul.add,li.add{list-style-image:url(/@@/add)}ul.architecture,li.architecture{list-style-image:url(/@@/architecture)}ul.build-success,li.build-success{list-style-image:url(/@@/build-success)}ul.blueprint,li.blueprint{list-style-image:url(/@@/blueprint)}ul.branch,li.branch{list-style-image:url(/@@/branch)}ul.bug,li.bug{list-style-image:url(/@@/bug)}ul.bug.remote,li.bug.remote{list-style-image:url(/@@/bug-remote)}ul.cve,li.cve{list-style-image:url(/@@/cve)}ul.distro,li.distro{list-style-image:url(/@@/distribution)}ul.distroseries,li.distroseries{list-style-image:url(/@@/distribution)}ul.download,li.download{list-style-image:url(/@@/download)}ul.edit,li.edit{list-style-image:url(/@@/edit)}ul.faq,li.faq{list-style-image:url(/@@/faq)}ul.info,li.info{list-style-image:url(/@@/info)}ul.language,li.language{list-style-image:url(/@@/language)}ul.mail,li.mail{list-style-image:url(/@@/mail)}ul.meeting,li.meeting{list-style-image:url(/@@/meeting)}ul.milestone,li.milestone{list-style-image:url(/@@/milestone)}ul.news,li.news{list-style-image:url(/@@/news);margin-bottom:1em}ul.package.binary,li.package.binary{list-style-image:url(/@@/package-binary)}ul.package.source,li.package.source{list-style-image:url(/@@/package-source)}ul.person,li.person{list-style-image:url(/@@/person)}ul.product,li.product{list-style-image:url(/@@/product)}dl.products>dt:before{content:url(/@@/product)}ul.question,li.question{list-style-image:url(/@@/question)}ul.rss,li.rss{list-style-image:url(/@@/rss)}ul.search,li.search{list-style-image:url(/@@/search)}ul.team,li.team{list-style-image:url(/@@/team)}ul.translation,li.translation{list-style-image:url(/@@/translation)}ul.link,li.link{list-style-image:url(/@@/link)}ul.webref,li.webref{list-style-image:url(/@@/link)}#application-footer strong{font-weight:normal}.description{font-size:1.125em}.report h2{font-size:1.4em}.boardComment,.boardCommentSummary{border:1px solid #ddd}.boardComment{margin:1em 0 1.5em}.boardCommentSummary{margin:0.3em 0 0.3em 0}.remoteBugComment{background-color:#f6f6f6}* html .boardComment{float:left;clear:both;width:99%}.boardCommentDetails{background-color:#eee;padding:0.5em 12px}.boardCommentBody{padding:0.5em 12px 0}.boardCommentContent{line-height:1.5em}.boardCommentFooter{background-color:#eee;padding:0.5em 12px}dl.faq dt{font-weight:bold}dl.faq dd{margin:1em 0 2em 4em}body.tab-overview #mainarea div.x{background-image:url(mainarea_top.gif)}body.tab-overview #mainarea div.y{background-image:url(mainarea_topleft.gif)}body.tab-overview #mainarea div.z{background-image:url(mainarea_topright.gif)}body.tab-overview #mainarea ul#applicationchooser li{background-image:url(appchoose_a.gif)}body.tab-overview #mainarea ul#applicationchooser li.tab-overview{background-position:-200px 0px !important}body.tab-overview #mainarea #portlets .portlet.active h2 a,body.tab-overview #mainarea div#portlets div.portlet.active a{background-color:#F0CB00}body.tab-overview #mainarea #portlets .portlet.active h2 a:hover,body.tab-overview #mainarea div#portlets div.portlet.active a:hover{background-color:#FFE40F}body.tab-overview #mainarea #portlets .portlet.active div,body.tab-overview #mainarea #portlets .portlet.active ul,body.tab-overview #mainarea #portlets .portlet.active ul li a,body.tab-overview #mainarea #portlets .portlet.active ul li a:hover,body.tab-overview #mainarea div#portlets div.portlet.active ul,body.tab-overview #mainarea div#portlets div.portlet.active ul li a,body.tab-overview #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#FEFCF0}body.tab-overview #mainarea #portlets .portlet.active div{border-left:4px solid #FEFCF0;border-right:4px solid #FEFCF0}body.tab-overview #actions,body.tab-overview .results{background:#e6eed3}body.tab-overview #actions h2,body.tab-overview #actions h2:hover{background-color:#83ad23}.tab-overview #application-footer strong{background:none;color:#83ad23}.product.series,.project{margin-bottom:1em}body.tab-branches #applications{background:url(app-code-wm.gif) no-repeat}body.tab-branches #mainarea div.x{background-image:url(mainarea_tab1_top.gif)}body.tab-branches #mainarea div.y{background-image:url(mainarea_tab1_topleft.gif)}body.tab-branches #mainarea div.z,body.tab-branches #mainarea ul#applicationchooser{background-image:url(mainarea_tab1_topright.gif)}body.tab-branches #mainarea ul#applicationchooser li{background-image:url(appchoose_tab1_a.gif)}body.tab-branches #mainarea ul#applicationchooser li.tab-branches{background-position:-200px 0px !important}body.tab-branches #mainarea #portlets .portlet.active h2 a,body.tab-branches #mainarea div#portlets div.portlet.active a{background-color:#CE4227}body.tab-branches #mainarea #portlets .portlet.active h2 a:hover,body.tab-branches #mainarea div#portlets div.portlet.active a:hover{background-color:#E2563B}body.tab-branches #mainarea #portlets .portlet.active div,body.tab-branches #mainarea #portlets .portlet.active ul,body.tab-branches #mainarea #portlets .portlet.active ul li a,body.tab-branches #mainarea #portlets .portlet.active ul li a:hover,body.tab-branches #mainarea div#portlets div.portlet.active ul,body.tab-branches #mainarea div#portlets div.portlet.active ul li a,body.tab-branches #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#FCF4F2}body.tab-branches #mainarea #portlets .portlet.active div{border-left:4px solid #FCF4F2;border-right:4px solid #FCF4F2}body.tab-branches #actions,body.tab-branches .results{background-color:#ffc}body.tab-branches #actions h2,body.tab-branches #actions h2:hover{background-color:#d18b39}.tab-branches h1,.tab-branches h2,.tab-branches h3,.tab-branches #application-footer strong,.tab-branches #application-summary strong,.tab-branches #page-summary strong.count{background:none;color:#d18b39}.branchstatusMATURE{color:#090}.branchstatusDEVELOPMENT{color:#900}.branchstatusEXPERIMENTAL{color:#930}.branchstatusMERGED{color:#666}.branchstatusABANDONED{color:#666}.branchstatusNEW{color:black}.mergeproposal p{margin:0.5em 0}.vcsimportSUCCESS{}.vcsimportFAILURE{color:Red}body.tab-bugs #applications{background:url(app-bugs-wm.gif) no-repeat}body.tab-bugs #mainarea div.x{background-image:url(mainarea_tab2_top.gif)}body.tab-bugs #mainarea div.y{background-image:url(mainarea_tab2_topleft.gif)}body.tab-bugs #mainarea div.z,body.tab-bugs #mainarea ul#applicationchooser{background-image:url(mainarea_tab2_topright.gif)}body.tab-bugs #mainarea ul#applicationchooser li{background-image:url(appchoose_tab2_a.gif)}body.tab-bugs #mainarea ul#applicationchooser li.tab-bugs{background-position:-200px 0px !important}body.tab-bugs #mainarea #portlets .portlet.active h2 a,body.tab-bugs #mainarea div#portlets div.portlet.active a{background-color:#F0CB00}body.tab-bugs #mainarea #portlets .portlet.active h2 a:hover,body.tab-bugs #mainarea div#portlets div.portlet.active a:hover{background-color:#FFE40F}body.tab-bugs #mainarea #portlets .portlet.active div,body.tab-bugs #mainarea #portlets .portlet.active ul,body.tab-bugs #mainarea #portlets .portlet.active ul li a,body.tab-bugs #mainarea #portlets .portlet.active ul li a:hover,body.tab-bugs #mainarea div#portlets div.portlet.active ul,body.tab-bugs #mainarea div#portlets div.portlet.active ul li a,body.tab-bugs #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#FEFCF0}body.tab-bugs #mainarea #portlets .portlet.active div{border-left:4px solid #FEFCF0;border-right:4px solid #FEFCF0}body.tab-bugs #actions,body.tab-bugs .results{background-color:#fee}body.tab-bugs #actions h2,body.tab-bugs #actions h2:hover{background-color:#9f2b33}.tab-bugs h1,.tab-bugs h2,.tab-bugs h3,.tab-bugs #application-footer strong,.tab-bugs table.listing thead{background:none;color:#9f2b33}.statusNEW,.statusNEW a{color:#930}.statusINCOMPLETE,.statusINCOMPLETE a{color:red}.statusCONFIRMED,.statusCONFIRMED a{color:red}.statusTRIAGED,.statusTRIAGED a{color:#f60}.statusINPROGRESS,.statusINPROGRESS a{color:black}.statusFIXCOMMITTED,.statusFIXCOMMITTED a{color:#050}.statusFIXRELEASED,.statusFIXRELEASED a{color:green}.statusINVALID,.statusINVALID a{color:gray}.statusWONTFIX,.statusWONTFIX a{color:gray}.importanceCRITICAL,.importanceCRITICAL a{color:red}.importanceHIGH,.importanceHIGH a{color:#f60}.importanceMEDIUM,.importanceMEDIUM a{color:green}.importanceLOW,.importanceLOW a{color:black}.importanceWISHLIST,.importanceWISHLIST a{color:blue}.importanceUNDECIDED,.importanceUNDECIDED a{color:#999}.status:link,.importance:link{text-decoration:none}#bug-description{font-family:monospace}body.tab-specifications #applications{background:url(app-blueprints-wm.gif) no-repeat}body.tab-specifications #mainarea div.x{background-image:url(mainarea_tab4_top.gif)}body.tab-specifications #mainarea div.y{background-image:url(mainarea_tab4_topleft.gif)}body.tab-specifications #mainarea div.z,body.tab-specifications #mainarea ul#applicationchooser{background-image:url(mainarea_tab4_topright.gif)}body.tab-specifications #mainarea ul#applicationchooser li{background-image:url(appchoose_tab4_a.gif)}body.tab-specifications #mainarea ul#applicationchooser li.tab-specifications{background-position:-200px 0px !important}body.tab-specifications #mainarea #portlets .portlet.active h2 a,body.tab-specifications #mainarea div#portlets div.portlet.active a{background-color:#F0CB00}body.tab-specifications #mainarea #portlets .portlet.active h2 a:hover,body.tab-specifications #mainarea div#portlets div.portlet.active a:hover{background-color:#FFE40F}body.tab-specifications #mainarea #portlets .portlet.active div,body.tab-specifications #mainarea #portlets .portlet.active ul,body.tab-specifications #mainarea #portlets .portlet.active ul li a,body.tab-specifications #mainarea #portlets .portlet.active ul li a:hover,body.tab-specifications #mainarea div#portlets div.portlet.active ul,body.tab-specifications #mainarea div#portlets div.portlet.active ul li a,body.tab-specifications #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#FEFCF0}body.tab-specifications #actions,body.tab-specifications .results{background-color:#eff}body.tab-specifications #actions h2,body.tab-specifications #actions h2:hover{background-color:#3594bb}.tab-specifications h1,.tab-specifications h2,.tab-specifications h3,.tab-specifications #application-footer strong,.tab-specifications table.listing thead{background:none;color:#3594bb}.specstatusAPPROVED{color:green}.specstatusPENDINGAPPROVAL{color:#f09}.specstatusPENDINGREVIEW{color:#f09}.specstatusDRAFT{color:#930}.specstatusDISCUSSION{color:#930}.specstatusNEW{color:red}.specstatusSUPERSEDED{color:gray}.specstatusOBSOLETE{color:gray}.specpriorityNOTFORUS{color:gray}.specpriorityUNDEFINED{color:gray}.specpriorityLOW{color:black}.specpriorityMEDIUM{color:#f60}.specpriorityHIGH{color:red}.specpriorityESSENTIAL{color:red}.specdeliveryUNKNOWN{color:gray}.specdeliveryNOTSTARTED{color:gray}.specdeliveryDEFERRED{color:red}.specdeliveryNEEDSINFRASTUCTURE{color:red}.specdeliveryBLOCKED{color:red}.specdeliverySTARTED{color:blue}.specdeliverySLOW{color:red}.specdeliveryGOOD{color:blue}.specdeliveryBETA{color:#f60}.specdeliveryNEEDSREVIEW{color:purple}.specdeliveryAWAITINGDEPLOYMENT{color:red}.specdeliveryIMPLEMENTED{color:green}.specdeliveryINFORMATIONAL{color:green}body.tab-translations #applications{background:url(app-translations-wm.gif) no-repeat}body.tab-translations #mainarea div.x{background-image:url(mainarea_tab5_top.gif)}body.tab-translations #mainarea div.y{background-image:url(mainarea_tab5_topleft.gif)}body.tab-translations #mainarea div.z,body.tab-translations #mainarea ul#applicationchooser{background-image:url(mainarea_tab5_topright.gif)}body.tab-translations #mainarea ul#applicationchooser li{background-image:url(appchoose_tab5_a.gif)}body.tab-translations #mainarea ul#applicationchooser li.tab-translations{background-position:-200px 0px !important}body.tab-translations #mainarea #portlets .portlet.active h2 a,body.tab-translations #mainarea div#portlets div.portlet.active a{background-color:#3594bb}body.tab-translations #mainarea #portlets .portlet.active h2 a:hover,body.tab-translations #mainarea div#portlets div.portlet.active a:hover{background-color:#29B0DC}body.tab-translations #mainarea #portlets .portlet.active div,body.tab-translations #mainarea #portlets .portlet.active ul,body.tab-translations #mainarea #portlets .portlet.active ul li a,body.tab-translations #mainarea #portlets .portlet.active ul li a:hover,body.tab-translations #mainarea div#portlets div.portlet.active ul,body.tab-translations #mainarea div#portlets div.portlet.active ul li a,body.tab-translations #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#F1F9FC}body.tab-translations #mainarea #portlets .portlet.active div{border-left:4px solid #f1f9fc;border-right:4px solid #f1f9fc}body.tab-translations #actions,body.tab-translations .results{background-color:#f1d7e6}body.tab-translations #actions h2,body.tab-translations #actions h2:hover{background-color:#bb3a84}.tab-translations h1,.tab-translations h2,.tab-translations h3,.tab-translations #application-footer strong,.tab-translations table.listing thead{background:none;color:#bb3a84}.translation code{font-weight:bold}.translation samp{background:url(/@@/translation-space) center center no-repeat;padding:0 4px;white-space:pre}body.tab-answers #applications{background:url(app-answers-wm.gif) no-repeat}body.tab-answers #mainarea div.x{background-image:url(mainarea_tab6_top.gif)}body.tab-answers #mainarea div.y{background-image:url(mainarea_tab6_topleft.gif)}body.tab-answers #mainarea div.z,body.tab-answers #mainarea ul#applicationchooser{background-image:url(mainarea_tab6_topright.gif)}body.tab-answers #mainarea ul#applicationchooser li{background-image:url(appchoose_tab6_a.gif)}body.tab-answers #mainarea ul#applicationchooser li.tab-answers{background-position:-200px 0px !important}body.tab-answers #mainarea #portlets .portlet.active h2 a,body.tab-answers #mainarea div#portlets div.portlet.active a{background-color:#3840be}body.tab-answers #mainarea #portlets .portlet.active h2 a:hover,body.tab-answers #mainarea div#portlets div.portlet.active a:hover{background-color:#5350E0}body.tab-answers #mainarea #portlets .portlet.active div,body.tab-answers #mainarea #portlets .portlet.active ul,body.tab-answers #mainarea #portlets .portlet.active ul li a,body.tab-answers #mainarea #portlets .portlet.active ul li a:hover,body.tab-answers #mainarea div#portlets div.portlet.active ul,body.tab-answers #mainarea div#portlets div.portlet.active ul li a,body.tab-answers #mainarea div#portlets div.portlet.active ul li a:hover{background-color:#F4F4FC}body.tab-answers #mainarea #portlets .portlet.active div{border-left:4px solid #F4F4FC;border-right:4px solid #F4F4FC}body.tab-answers #actions,body.tab-answers .results{background-color:#eef}body.tab-answers #actions h2,body.tab-answers #actions h2:hover{background-color:#3840be}.tab-answers h1,.tab-answers h2,.tab-answers h3,.tab-answers #application-footer strong,.tab-answers table.listing thead{background:none;color:#3840be}.questionstatusOPEN{color:#000}.questionstatusNEEDSINFO{color:#930}.questionstatusANSWERED{color:#363}.questionstatusSOLVED{color:#090}.questionstatusEXPIRED{color:#666}.questionstatusINVALID{color:#c00}ul#applicationchooser a,ul#applicationchooser a:hover{color:#000}#applications{clear:both;width:100%}div#applications{padding:1em 0;text-align:center}#applications span{display:inline-block;float:right}#applications a img{margin:0 auto}.central{clear:left;font-size:1.125em;margin:0 auto 1em;padding:0.5em 0;width:auto}.central input{font-size:1em}.front_page label{color:#303030;font-size:1.2em}#application-summary,#application-footer,#page-summary{font-size:1.2em;line-height:1.4em;margin-top:0}#application-footer{border-top:1px dotted #999;clear:both;margin-top:2em;padding-top:1em}img.mugshot{float:right;margin-left:20px}img.mugshot:after{content:".";display:block;height:0;clear:both;visibility:hidden}img.mugshot{display:inline-table}/* Work around float bug in MSIE for Windows,while hiding from MSIE for Mac \*/
+* html img.mugshot{height:1%}img.mugshot{display:block}/* End hiding from MSIE for Mac */ div.columns{clear:both}div.left,div.right{width:50%}div.left{clear:both;float:left}div.right{clear:right;float:right}div.left div.portlet,div.right div.portlet{border:dotted #cbcbcb;border-width:1px 0 0 0;margin-top:1em;padding-top:1em}div.left div.portlet{border-width:1px 1px 0 0;padding:0.75em 0.75em 0.75em 0}div.right div.portlet{border-width:1px 0 0 1px;padding:0.75em 0 0.75em 0.75em}div.columns div.right div.portlet{border:none;padding:0}div.three.column{width:30%;margin-right:3%}div.three.column.left,div.three.column.middle,div.three.column.right{clear:none;float:left}.title{font-weight:bold}ul.buttons{margin:0.5em 0 0.5em 0 !important;padding:0 !important}ul.buttons li{display:inline;margin:0 0 0 0}body.applicationhome ul.buttons{float:right;margin:0 0 0 1em !important}body.applicationhome ul.buttons li{display:block;margin-right:0}ul.cross-reference{font-size:1.25em}.bug-summary,.summary{font-weight:bold}fieldset{border:none;margin:0.5em 0 1em;padding:0}table.latest th,table.latest td{padding-bottom:2em}table.summary{float:right;margin:0 0 1em 1em}table.listing table.summary{margin-top:0.5em}table.summary caption{font-style:italic;margin-left:1em}div.right table.summary{float:none;margin:1em auto}table.summary tr{border:dotted #cbcbcb;border-width:1px 0}table.summary td{padding-left:0.5em}table.summary ul,table.summary ul li{list-style-position:inside;margin:0;padding:0}th,td{padding:0.25em}th.icon,td.icon{vertical-align:top;white-space:nowrap;width:1px}th.icon.left,td.icon.left{padding-right:0}th.icon.right,td.icon.right{padding-left:0}th.nowrap,td.nowrap{white-space:nowrap}tfoot th,table.contributions th{text-align:left}table.contributions,table.contributions th,table.contributions td{border:1px solid #e6e6e6}table.contributions th{font-weight:normal}table.contributions tr.odd{background-color:#fff;color:inherit}table.contributions tr.even{background-color:#f6f6f6;color:inherit}table.contributions th,table.contributions td{padding:0.5em 0.75em}table.contributions td{vertical-align:middle;width:16px}table.listing{margin:0;width:100%;font-size:8.5pt}table.listing,table.listing tbody{border-bottom:1px solid #d2d2d2}table.listing thead,table.listing thead th,table.listing tfoot tr{border:1px solid #d2d2d2;background-color:#fff}table.listing tr.category{border-bottom:1px solid #d2d2d2}table.listing tr.category th,table.listing tr.category td{padding-top:1em}table.listing tfoot td{border:1px solid #d2d2d2}table.listing thead td{border:none}tr.highlight{background-color:#ff9}table.listing tr.note{font-size:smaller}.amount{text-align:right}table.listing th,table.listing td{padding:0.25em}table.listing table th,table.listing table td{padding:0}table.listing th{font-size:1.125em;white-space:nowrap}table.listing td{border:1px #d2d2d2;border-style:dotted none none none}table.listing tr.note td{border-style:none}table.listing img{vertical-align:middle}table.listing tr.secondary th,table.listing tr.secondary td{border-top:none}table.listing table tbody,table.listing table thead,table.listing table thead th,table.listing tfoot tr,table.listing table tfoot td,table.listing table td{border:none}table.duplicate.listing *{color:#999}table.listing table.simple{margin-left:2em}table.listing table.simple td{padding:0.25em}table.sortable a.sortheader{color:#666;font-weight:bold;text-decoration:none;display:block}table.sortable img.sortarrow{padding-left:2px}th.ascending{background-image:url(/@@/arrowDown);background-position:center right;background-repeat:no-repeat}th.descending{background-image:url(/@@/arrowUp);background-position:center right;background-repeat:no-repeat}.sortkey,.revsortkey{display:none}.cloud-size-small{font-size:1em}.cloud-size-medium{font-size:1.35em}.cloud-size-large{font-size:1.7em}.cloud-shade-dark{color:#00f}.cloud-shade-medium{color:#7878ff}.cloud-shade-light{color:#b8b8ff}.cloud-highlight-dark{color:#00c500}.cloud-highlight-medium{color:#90e090}.cloud-highlight-light{color:#b8ffb8}.lowerCaseText{text-transform:lowercase}div.popupTitle{background:#ffffdc;padding:0 1em;border:1px black solid;position:absolute;display:none}.inlineLinkIcon{margin-right:0.5em;margin-left:0.5em}#search-results{margin-top:1em}#search-results ul{margin:.5em 0 .5em 0;padding:0;list-style-type:none}#search-results ul li{margin-bottom:1em}#search-results ul li div.summary{margin-left:17px;font-weight:normal}#search-results ul.exact-matches{margin-top:2em;margin-bottom:1em}#search-results,#no-search{width:40em}#search-results div.upper-batch-nav{border-top:1px solid #d2d2d2;margin-top:1.5em;margin-bottom:1.5em}#search-results div.lower-batch-nav{margin-top:1.5em;border-top:1px solid #d2d2d2}#no-results{margin-top:2em}#no-results span.search_text{font-weight:bold}
\ No newline at end of file

=== removed file 'loggerhead/static/css/zptstyle.css'
--- loggerhead/static/css/zptstyle.css	2008-06-11 03:53:53 +0000
+++ loggerhead/static/css/zptstyle.css	1970-01-01 00:00:00 +0000
@@ -1,670 +0,0 @@
-
-/* from launchpad */
-body {
-    background-color: #fcfcfc;
-    color: black;
-    font-family: "Lucida Grande", "Trebuchet MS", sans-serif;
-    font-size: 12pt;
-    padding: 0px;
-    text-align: left;
-}
-
-a {
-    text-decoration: none;
-    color: #000088;
-}
-a:hover {
-    color: black;
-}
-
-img {
-    border: none;
-}
-
-h1 {
-    color: #708a96;
-    font-weight: normal;
-    font-size: 1.6em;
-    margin-bottom: 0em;
-}
-h1 .filename {
-    font-family: monospace;
-}
-
-.branch-name {
-    color: #47626e;
-}
-
-.footer {
-    margin-top: 1em;
-    margin-bottom: 1em;
-}
-.footer .banner {
-    margin-right: 5px;
-}
-.footer .banner img {
-    border: 1px solid #8cacbb;
-}
-
-.collapse-triangle {
-    padding-right: 0.5em;
-}
-
-.hide-all {
-    font-size: smaller;
-    padding: 0.25em 0.75em 0.25em 0.75em;
-}
-
-
-
-/* ----- navigation bar at the top ----- */
-
-.navbar {
-}
-
-.bar table {
-    width: 100%;
-    border-collapse: collapse;
-}
-
-/* safari gives forms a big default margin, to vex me */
-.bar form {
-    margin: 0px;
-}
-
-.bar {
-    background-color: #dee7ec;
-    border: 1px solid #8cacbb;
-    font-size: smaller;
-    padding-top: 0px;
-    padding-bottom: 0px;
-}
-
-/* revision navigation buttons (the ones at the top right) */
-.navbuttons {
-    padding: 2px;
-    bottom: 0px;
-    text-align: right;
-    width: auto;
-    border-left: 1px dotted #8cacbb;
-    padding-left: 0.5em;
-    padding-right: 0.5em;
-}
-
-.navbuttons a {
-    font-weight: normal;
-    margin-left: 2px;
-    margin-right: 2px;
-}
-
-.navbuttons a:hover {
-    padding: 0;
-    color: blue;
-}
-
-/* navigation button in the pages (the ones at the top left, and bottom) */
-.buttons {
-}
-
-.buttons a,.buttons .search {
-    font-weight: normal;
-    color: #000088;
-    font-size: 12pt;
-    padding-left: 10px;
-    padding-right: 7px;
-    border-right: 1px dotted #8cacbb;
-}
-
-.buttons a:hover,.rbuttons a:hover {
-    font-weight: normal;
-    color: blue;
-}
-
-.feed img {
-    vertical-align: text-top;
-}
-
-.rbuttons a {
-    font-weight: normal;
-    color: #000088;
-    font-size: 12pt;
-    padding-right: 7px;
-    padding-left: 10px;
-    border-left: 1px dotted #8cacbb;
-    text-align: right;
-    width: auto;
-}
-
-
-/* ----- revision display in various places ----- */
-
-.revision .revno {
-    font-weight: bold;
-}
-
-.revision .revid {
-    font-family: monospace;
-    font-size: smaller;
-    padding-left: 1em;
-}
-
-.revision .log {
-    font-size: smaller;
-}
-
-
-/* ---- sub-links underneath the headline on some pages ----- */
-
-div.links {
-    color: #708a96;
-    padding-top: 0.5em;
-    padding-left: 3em;
-    font-size: 0.8em;
-    margin-bottom: 2em;
-}
-
-div.links div {
-    margin-bottom: 3px;
-}
-
-
-/* ----- list of merge points for a revision ----- */
-
-.info-entry {
-    font-size: smaller;
-    margin-bottom: 2em;
-    padding: 0px;
-    background-color: #f4f5f8;
-    border: 1px solid #8cacbb;
-    width: 60%;
-}
-
-.info-entry th {
-    background-color: #dee7ec;
-    font-weight: normal;
-    color: black;
-    text-align: right;
-    vertical-align: top;
-
-    padding-left: 0.5em;
-    padding-right: 0.5em;
-    padding-top: 2px;
-    padding-bottom: 2px;
-}
-
-.info-entry td {
-    font-weight: normal;
-    padding-left: 0.5em;
-    padding-top: 2px;
-    padding-bottom: 2px;
-}
-
-
-/* ----- changelog page ----- */
-
-/* secret css-jutsu to make hidden margins vanish on a table */
-.log-entries {
-    border-collapse: collapse;
-    width: 98%;
-    margin-top: 0.5em;
-    margin-left: 1em;
-    font-size: 1em;
-}
-
-.log-entries .log-header {
-    background-color: #8cacbb;
-    padding-top: 3px;
-    padding-bottom: 3px;
-    text-align: left;
-}
-
-.log-entries .revision-header {
-    font-size: normal;
-}
-
-.log-entries .revision-header td {
-    padding-top: 2px;
-    padding-bottom: 2px;
-}
-
-.log-entries .revision-header td.expand-button {
-    width: 20px;
-}
-
-.log-entries .revision-number {
-    padding-left: 0.5em;
-}
-
-.log-entries .revision-header td.date {
-    font-size: smaller;
-}
-
-.log-entries .revision-header td.author {
-    font-size: smaller;
-    padding-right: 0.5em;
-}
-
-.log-entries .revision-header .inventory-link {
-    font-size: smaller;
-    vertical-align: middle;
-    text-align: left;
-    padding-right: 0.5em;
-}
-
-.log-entries table.revision-details {
-    font-size: smaller;
-    margin-bottom: 1.0em;
-}
-
-.log-entries table.revision-details th {
-    text-align: right;
-    padding-right: 0.5em;
-    vertical-align: top;
-}
-
-.log-entries table.revision-details td.files .filename {
-    font-family: monospace;
-}
-
-td.files {
-    padding-top: 0em;
-    padding-bottom: 0em;
-}
-th.files {
-    padding-top: 0em;
-    padding-bottom: 0em;
-}
-
-.log-entries .revision-details td.files .jump {
-    font-size: smaller;
-}
-
-.log-entries .revision-details td.description {
-    font-family: monospace;
-}
-
-/* default state: hide all */
-.revision-header .hide-button { display: none; }
-.hidden-details { display: none; }
-.changelog .collapse-cl-hideall { display: none; }
-
-
-/* ----- revision page ----- */
-
-.revision-info {
-    border: none;
-    margin-bottom: 1em;
-    padding: 0;
-    background-color: #f4f5f8;
-    border: 1px solid #8cacbb;
-    width: 80%;
-}
-
-/* secret css-jutsu to make hidden margins vanish on a table */
-.revision-info table {
-    border-collapse: collapse;
-    width: 100%;
-}
-
-.revision-info th {
-    background-color: #dee7ec;
-    color: black;
-    font-weight: normal;
-    text-align: right;
-    vertical-align: top;
-    font-size: 0.8em;
-    padding-left: 0.5em;
-    padding-right: 0.5em;
-    padding-top: 2px;
-    padding-bottom: 2px;
-}
-
-.revision-info td {
-    font-weight: normal;
-    font-size: 0.8em;
-    padding-left: 0.5em;
-    padding-top: 2px;
-    padding-bottom: 2px;
-}
-
-.revision-info table td.date {
-    font-family: monospace;
-    font-size: 1em;
-}
-
-.revision-info table td.description {
-    font-family: monospace;
-    font-size: 1em;
-}
-
-.revision-info table td.files {
-    font-family: monospace;
-    font-size: 1em;
-}
-
-.revision-info table td.files a.jump {
-    font-size: smaller;
-}
-    
-.revision-info table tr.divider {
-    border-top: 1px solid #8cacbb;
-}
-
-
-/* ----- overly complex diff display ----- */
-
-.diff {
-    margin-bottom: 1em;
-    padding-top: 10px;
-    width: 100%;
-    background-color: #fcfcfc;
-    font-family: monospace;
-}
-
-
-.diff-block {
-    border-collapse: collapse;
-    width: 100%;
-    margin-bottom: 1em;
-}
-
-.diff-block th.filename {
-    font-family: monospace;
-    font-weight: normal;
-    font-size: 1em;
-    padding-left: 1em;
-    padding-top: 1em;
-    padding-bottom: 1em;
-    text-align: left;
-    background-color: #dee7ec;
-}
-
-.diff-block .diff-chunk {
-    font-size: 0.9em;
-    margin-top: 0px;
-    margin-bottom: 2em;
-}
-
-.diff-block th.lineno {
-    font-weight: bold;
-    border-bottom: 1px solid #8cacbb;
-    border-top: 1px solid #dee7ec;
-}
-
-.diff-block .diff-spacing {
-    line-height: 1em;
-}
-
-.diff-option-buttons {
-    margin-top: 1.0em;
-    margin-bottom: 1.0em;
-    border-collapse: collapse;
-}
-.diff-option-buttons td {
-    line-height: 1em;
-    height: 1em;
-    vertical-align: middle;
-    padding: 0px;
-}
-.diff-option-buttons .label {
-    font-size: smaller;
-    padding-left: 0.75em;
-    padding-right: 2em;
-    line-height: 1em;
-}
-.diff-option-buttons .spacey {
-    padding-right: 5em;
-}
-
-.diff-option-buttons .collapse-file-showall { display: none; }
-
-.diff-block .show-button { display: none; }
-.collapse-style-unified-content { display: none; }
-.collapse-style-sbs-show { display: none; }
-
-.diff-insert {
-    background-color: #9cc8ff;
-}
-.diff-delete {
-    background-color: #ffa0a0;
-}
-.diff-chunk td.text {
-    padding-left: 1em;
-}
-
-.diff-key {
-    display: inline;
-    font-size: smaller;
-}
-
-.diff-key-block {
-    width: 1em;
-    height: 1em;
-    border: 1px solid #8cacbb;
-}
-
-.diff-key .label {
-    padding-right: 2em;
-}
-
-.diff .lineno {
-    color: purple;
-    background-color: #dee7ec; 
-    width: 4em;
-    text-align: right;
-    padding-right: 3px;
-    border-bottom: 1px solid #8cacbb;
-}
-.diff .lineno-skip {
-    width: 4em;
-    background-color: #dee7ec;
-}
-.diff .info {
-    color: blue;
-    background-color: #dee7ec;
-    margin-top: 15px;
-}
-/*
-.diff-context-skip {
-    background-color: #dee7ec;
-}*/
-
-
-/* ----- file inventory ----- */
-
-.inventory-path {
-    margin-top: 2em;
-}
-
-table.inventory {
-    border-collapse: collapse;
-    width: 100%;
-    font-size: smaller;
-    margin-top: 1em;
-    border: 1px solid #8cacbb;
-}
-
-table.inventory td {
-    padding-top: 3px;
-    padding-bottom: 3px;
-    vertical-align: middle;
-}
-
-table.inventory th {
-    background-color: #8cacbb;
-    padding-top: 3px;
-    padding-bottom: 3px;
-    text-align: left;
-}
-
-table.inventory th.permissions {
-    padding-left: 0.5em;
-}
-
-.parity0 { background-color: #dee7ec; }
-.parity1 { background-color: #eff8fd; }
-
-.inventory td.permissions {
-    font-family: monospace;
-    padding-left: 0.5em;
-    width: 9em;
-}
-
-.inventory td.filename {
-    font-family: monospace;
-}
-
-.inventory td.size {
-    font-family: monospace;
-    font-size: smaller;
-    width: 5em;
-}
-
-.inventory td.revision {
-    padding-right: 1em;
-    text-align: left;
-    width: 8em;
-}
-
-.inventory td.date {
-    padding-right: 1em;
-    width: 11em;
-}
-
-.inventory td.changes-link {
-    font-size: smaller;
-    width: 6em;
-}
-
-.inventory td.download-link {
-    font-size: smaller;
-    width: 8em;
-}
-
-span.folder {
-    font-family: monospace;
-}
-
-
-/* ----- file annotation ----- */
-
-.annotate-path {
-    font-family: monospace;
-}
-
-.annotate table {
-    border-collapse: collapse;
-    width: 100%;
-    font-size: 66%;
-}
-
-.annotate td {
-    padding-top: 2px;
-    padding-bottom: 2px;
-    vertical-align: bottom;
-}
-
-.annotate td.lineno {
-    font-family: monospace;
-    text-align: right;
-    width: 4em;
-    padding-right: 5px;
-    font-weight: bold;
-    border-bottom: 1px solid #8cacbb;
-}
-
-.annotate td.revno {
-    font-family: monospace;
-    text-align: right;
-    width: 8em;
-    padding-right: 5px;
-    border-right: 1px solid #8cacbb;
-}
-
-.annotate td.text {
-    font-family: monospace;
-    padding-left: 1em;
-}
-
-.annotate th {
-    background-color: #8cacbb;
-    padding-top: 3px;
-    padding-bottom: 3px;
-    text-align: left;
-}
-
-.annotate th.lineno {
-    text-align: right;
-}
-
-.annotate th.revision {
-    text-align: right;
-    padding-right: 5px;
-}
-
-.annotate th.text {
-    padding-left: 1em;
-}
-
-
-/* ----- top-level browse page ----- */
-
-.browse-project-name {
-    background-color: #dee7ec;
-    padding-top: 5px;
-    padding-bottom: 5px;
-    margin-left: 1em;
-    margin-right: 1em;
-    padding-left: 1em;
-    width: 90%;
-    font-weight: bold;
-}
-
-.browse-project-description {
-	padding-top: 1em;
-	padding-bottom: 1em;
-	margin-left: 2em;
-    width: 90%;
-}
-	
-.browse-view {
-	margin-top: 1em;
-	margin-bottom: 1em;
-	margin-left: 2em;
-}
-
-.browse-view table {
-    border-collapse: collapse;
-    width: 90%;
-    margin-bottom: 2em;
-}
-
-.browse-view table tr.heading {
-    background-color: #8cacbb;
-    border-bottom: solid 1px #8cacbb;
-    font-size: smaller;
-}
-
-.browse-view td,.browse-view th {
-    padding: 0.25em 0.5em 0.25em 0.5em;
-}
-
-.browse-view td.name {
-    width: 20%;
-}
-
-.browse-view td.last-update {
-    font-size: smaller;
-    width: 20em;
-}
-
-.browse-view td.url {
-    font-family: monospace;
-    font-size: smaller;
-    padding-left: 3em;
-    padding-top: 0px;
-}
-
-.browse-view td.feed {
-	width: 16px;
-}

=== removed file 'loggerhead/static/images/bazaar-banner.png'
Binary files loggerhead/static/images/bazaar-banner.png and loggerhead/static/images/bazaar-banner.png differ
=== added file 'loggerhead/static/images/bg_Tabs.gif'
Binary files loggerhead/static/images/bg_Tabs.gif and loggerhead/static/images/bg_Tabs.gif differ
=== added file 'loggerhead/static/images/bg_infobox.gif'
Binary files loggerhead/static/images/bg_infobox.gif and loggerhead/static/images/bg_infobox.gif differ
=== added file 'loggerhead/static/images/bg_menuTabs.gif'
Binary files loggerhead/static/images/bg_menuTabs.gif and loggerhead/static/images/bg_menuTabs.gif differ
=== added file 'loggerhead/static/images/bg_search_input.gif'
Binary files loggerhead/static/images/bg_search_input.gif and loggerhead/static/images/bg_search_input.gif differ
=== added file 'loggerhead/static/images/bg_submenuTabs.gif'
Binary files loggerhead/static/images/bg_submenuTabs.gif and loggerhead/static/images/bg_submenuTabs.gif differ
=== added file 'loggerhead/static/images/deleteCode.gif'
Binary files loggerhead/static/images/deleteCode.gif and loggerhead/static/images/deleteCode.gif differ
=== removed file 'loggerhead/static/images/favicon.ico'
Binary files loggerhead/static/images/favicon.ico and loggerhead/static/images/favicon.ico differ
=== removed file 'loggerhead/static/images/feed-icon-16x16.gif'
Binary files loggerhead/static/images/feed-icon-16x16.gif and loggerhead/static/images/feed-icon-16x16.gif differ
=== removed file 'loggerhead/static/images/header_inner.png'
Binary files loggerhead/static/images/header_inner.png and loggerhead/static/images/header_inner.png differ
=== added file 'loggerhead/static/images/ico_committer.gif'
Binary files loggerhead/static/images/ico_committer.gif and loggerhead/static/images/ico_committer.gif differ
=== added file 'loggerhead/static/images/ico_description.gif'
Binary files loggerhead/static/images/ico_description.gif and loggerhead/static/images/ico_description.gif differ
=== added file 'loggerhead/static/images/ico_diff.gif'
Binary files loggerhead/static/images/ico_diff.gif and loggerhead/static/images/ico_diff.gif differ
=== added file 'loggerhead/static/images/ico_file.gif'
Binary files loggerhead/static/images/ico_file.gif and loggerhead/static/images/ico_file.gif differ
=== added file 'loggerhead/static/images/ico_file_download.gif'
Binary files loggerhead/static/images/ico_file_download.gif and loggerhead/static/images/ico_file_download.gif differ
=== added file 'loggerhead/static/images/ico_file_flecha.gif'
Binary files loggerhead/static/images/ico_file_flecha.gif and loggerhead/static/images/ico_file_flecha.gif differ
=== added file 'loggerhead/static/images/ico_file_modify.gif'
Binary files loggerhead/static/images/ico_file_modify.gif and loggerhead/static/images/ico_file_modify.gif differ
=== added file 'loggerhead/static/images/ico_folder.gif'
Binary files loggerhead/static/images/ico_folder.gif and loggerhead/static/images/ico_folder.gif differ
=== added file 'loggerhead/static/images/ico_link.gif'
Binary files loggerhead/static/images/ico_link.gif and loggerhead/static/images/ico_link.gif differ
=== added file 'loggerhead/static/images/ico_mergefrom.gif'
Binary files loggerhead/static/images/ico_mergefrom.gif and loggerhead/static/images/ico_mergefrom.gif differ
=== added file 'loggerhead/static/images/ico_planilla.gif'
Binary files loggerhead/static/images/ico_planilla.gif and loggerhead/static/images/ico_planilla.gif differ
=== added file 'loggerhead/static/images/ico_rss.gif'
Binary files loggerhead/static/images/ico_rss.gif and loggerhead/static/images/ico_rss.gif differ
=== added file 'loggerhead/static/images/ico_time.gif'
Binary files loggerhead/static/images/ico_time.gif and loggerhead/static/images/ico_time.gif differ
=== removed file 'loggerhead/static/images/info.png'
Binary files loggerhead/static/images/info.png and loggerhead/static/images/info.png differ
=== removed file 'loggerhead/static/images/loggerhead-banner.png'
Binary files loggerhead/static/images/loggerhead-banner.png and loggerhead/static/images/loggerhead-banner.png differ
=== removed file 'loggerhead/static/images/nav-small-down.gif'
Binary files loggerhead/static/images/nav-small-down.gif and loggerhead/static/images/nav-small-down.gif differ
=== removed file 'loggerhead/static/images/nav-small-in.gif'
Binary files loggerhead/static/images/nav-small-in.gif and loggerhead/static/images/nav-small-in.gif differ
=== removed file 'loggerhead/static/images/nav-small-out.gif'
Binary files loggerhead/static/images/nav-small-out.gif and loggerhead/static/images/nav-small-out.gif differ
=== removed file 'loggerhead/static/images/nav-small-right.gif'
Binary files loggerhead/static/images/nav-small-right.gif and loggerhead/static/images/nav-small-right.gif differ
=== added file 'loggerhead/static/images/newCode.gif'
Binary files loggerhead/static/images/newCode.gif and loggerhead/static/images/newCode.gif differ
=== removed file 'loggerhead/static/images/ok.png'
Binary files loggerhead/static/images/ok.png and loggerhead/static/images/ok.png differ
=== removed file 'loggerhead/static/images/tg_under_the_hood.png'
Binary files loggerhead/static/images/tg_under_the_hood.png and loggerhead/static/images/tg_under_the_hood.png differ
=== added file 'loggerhead/static/images/treeCollapsed.png'
Binary files loggerhead/static/images/treeCollapsed.png and loggerhead/static/images/treeCollapsed.png differ
=== added file 'loggerhead/static/images/treeDiff.png'
Binary files loggerhead/static/images/treeDiff.png and loggerhead/static/images/treeDiff.png differ
=== added file 'loggerhead/static/images/treeExpanded.png'
Binary files loggerhead/static/images/treeExpanded.png and loggerhead/static/images/treeExpanded.png differ
=== removed file 'loggerhead/static/images/under_the_hood_blue.png'
Binary files loggerhead/static/images/under_the_hood_blue.png and loggerhead/static/images/under_the_hood_blue.png differ
=== removed file 'loggerhead/static/javascript/collapse.js'
--- loggerhead/static/javascript/collapse.js	2008-06-11 02:26:38 +0000
+++ loggerhead/static/javascript/collapse.js	1970-01-01 00:00:00 +0000
@@ -1,126 +0,0 @@
-
-/* reusable implementation of expand/collapse buttons, used to show/hide
- * "more detailed" sections of the page.
- */
-
-
-var collapse_cache = new Object();
-var collapse_all_cache = new Object();
-
-function cacheElement(group, name, remainder, element) {
-    var g = collapse_cache[group];
-    if (typeof(g) == "undefined") {
-        g = new Object();
-        collapse_cache[group] = g;
-    }
-    var n = g[name];
-    if (typeof(n) == "undefined") {
-        n = new Array();
-        g[name] = n;
-    }
-    n.push(new Array(remainder, element));
-}
-
-function cacheAllElement(group, name, element) {
-    var g = collapse_all_cache[group];
-    if (typeof(g) == "undefined") {
-        g = new Array();
-        collapse_all_cache[group] = g;
-    }
-    g.push(new Array(name, element));
-}
-
-/*
- * cache all the elements that have a collapse-<group>-<name>-* class on them.
- * javascript can be very slow so this should make the UI more responsive.
- */
-function sortCollapseElements() {
-    var elements = document.getElementsByTagName("*");
-    for (var i = 0; i < elements.length; i++) {
-        var classes = elements[i].className.split(' ');
-        for (var j = 0; j < classes.length; j++) {
-            if (classes[j].indexOf("collapse-") == 0) {
-                var segments = classes[j].split('-');
-                if (segments.length == 4) {
-                    cacheElement(segments[1], segments[2], segments[3], elements[i]);
-                }
-                if (segments.length == 3) {
-                    cacheAllElement(segments[1], segments[2], elements[i]);
-                }
-            }
-        }
-    }
-}
-
-
-function collapseContent(group, name) {
-    return 'collapse-' + group + '-' + name + '-content';
-}
-
-function collapseDisplay(group, name, display) {
-    // display mode for the disclosure triangles:
-    var dthide = 'inline', dtshow = 'none';
-    if (display == 'none') { dthide = 'none'; dtshow = 'inline'; }
-
-    var elements = collapse_cache[group][name];
-    for (var i in elements) {
-        var kind = elements[i][0], node = elements[i][1];
-        if (kind == "show") {
-            node.style.display = dtshow;
-        } else if (kind == "hide") {
-            node.style.display = dthide;
-        } else if (kind == "content") {
-            node.style.display = display;
-        }
-    }
-}
-
-function collapseAllDisplay(group, display) {
-    for (var name in collapse_cache[group]) {
-        collapseDisplay(group, name, display);
-    }
-    
-    var dthide = 'inline', dtshow = 'none';
-    if (display == 'none') { dthide = 'none'; dtshow = 'inline'; }
-    for (var element in collapse_all_cache[group]) {
-        var x = collapse_all_cache[group][element];
-        var name = x[0], node = x[1];
-        if (name == "showall") {
-            node.style.display = dtshow;
-        } else if (name == "hideall") {
-            node.style.display = dthide;
-        }
-    }
-}
-
-
-// for debugging
-function debug(s) {
-    var d = new Date();
-    var hh = d.getHours(), mm = d.getMinutes(), ss = d.getSeconds(), ms = d.getMilliseconds();
-    var ds = ((hh < 10) ? "0" + hh : hh) + ":" + ((mm < 10) ? "0" + mm : mm) + ":" + ((ss < 10) ? "0" + ss : ss) + "." + ((ms < 10) ? "00" + ms : ((ms < 100) ? "0" + ms : ms));
-    console.log("[" + ds + "] " + s);
-}
-
-function diff_url(url) {
-    if (document.cookie.indexOf('diff=unified') >= 0) {
-        this.location.href = url + "-u";
-    } else {
-        this.location.href = url + "-s";
-    }
-}
-
-function show_sbs() {
-	collapseDisplay('style', 'sbs', 'table');
-	collapseDisplay('style', 'unified', 'none');
-	document.cookie='diff=sbs';
-}
-function show_unified() {
-	collapseDisplay('style', 'unified', 'table');
-	collapseDisplay('style', 'sbs', 'none');
-	document.cookie='diff=unified';
-}
-function load() {
-	sortCollapseElements();
-	if (document.cookie.indexOf('diff=unified') >= 0) { show_unified(); }
-}

=== added file 'loggerhead/static/javascript/custom.js'
--- loggerhead/static/javascript/custom.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/custom.js	2008-07-22 00:40:03 +0000
@@ -0,0 +1,236 @@
+var global_timeout_id = null;
+var global_search_request = null;
+
+window.addEvent('domready', function() 
+{
+    var search_box = $('q');
+    search_box.addEvents(
+    {
+        keyup: function()
+        {
+            if($('q').value == '')
+            {
+                $('search_terms').setStyle('display','none');
+            }
+            else
+            {
+	            if (null != global_timeout_id)
+	            {
+	                clearTimeout(global_timeout_id);
+	            }
+                    global_timeout_id = setTimeout('$("q").fireEvent("search",$("q").value)',200);
+            }
+        },
+
+        search: function(query)
+        {
+            url = global_path + 'search?query=' + query;
+	
+            if ($defined(global_search_request))
+            {
+                global_search_request.cancel();
+            }
+            global_search_request = new Request({'url':url,'method':'get','onComplete':cool_search});
+            global_search_request.send('');
+	        var posicion = search_box.getPosition();
+	        var size     = search_box.getSize();
+
+	        $('search_terms').setStyle('position','absolute');
+	        $('search_terms').setStyle('left',posicion.x);
+	        $('search_terms').setStyle('top',posicion.y + size.y);
+	        $('search_terms').setStyle('display','block');
+	        $('search_terms').set('html','Loading...');
+
+            new Request({'url':url,'method':'get','onComplete':cool_search}).send('');
+
+
+        }
+    });
+});
+
+function cool_search(response)
+{
+	var posicion = $('q').getPosition();
+	var size     = $('q').getSize();
+	$('search_terms').set('html',response);
+	$('search_terms').setStyle('display','block');
+	$('search_terms').setStyle('position','absolute');
+	$('search_terms').setStyle('left',posicion.x);
+	$('search_terms').setStyle('top',posicion.y + size.y);
+}
+
+function hide_search()
+{
+    hide_div = setTimeout("$('search_terms').setStyle('display','none')", 300);
+}
+var Colapsable = new Class({
+    initialize: function(item,expand_icon,open_content,close_content,is_open)
+    {
+        this.is_open = false;
+        if ($defined(is_open))
+        {
+            this.is_open = is_open;
+        }
+        this.item = item;
+        item.set('colapsable',this);
+        this.open_content  = open_content;
+        this.close_content = close_content;
+        this.expand_icon   = expand_icon;
+
+        var expander = new Fx.Slide(this.item, { duration: 200 } );
+        if (!this.is_open)
+        {
+            expander.hide();
+            if ($defined(this.expand_icon))
+            {
+                this.expand_icon.set('src',this.expand_icon.title);
+            }
+        }
+        else
+        {
+            if ($defined(this.expand_icon))
+            {
+                this.expand_icon.set('src',this.expand_icon.alt);
+            }
+        }
+    },
+
+    open: function()
+    {
+        this.item.setStyle('display', 'block');
+        var expander = this.item.get('slide');
+        expander.slideIn();
+        if ($defined(this.open_content))
+        {
+            for (var i=0;i<this.open_content.length;++i)
+            {
+                this.open_content[i].setStyle('display','block');
+            }
+		}
+		
+        if ($defined(this.close_content))
+        {
+            for (var i=0;i<this.close_content.length;++i)
+            {
+                this.close_content[i].setStyle('display','none');
+            }
+        }
+
+        if ($defined(this.expand_icon))
+        {
+            this.expand_icon.set('src',this.expand_icon.alt);
+        }
+        this.is_open = true;
+    },
+
+    close: function()
+    {
+        var expander = this.item.get('slide');
+        expander.slideOut();
+        if ($defined(this.open_content))
+        {
+            for (var i=0;i<this.open_content.length;++i)
+            {
+                this.open_content[i].setStyle('display','none');
+            }
+        }
+
+        if ($defined(this.close_content))
+        {
+            for (var i=0;i<this.close_content.length;++i)
+            {
+                this.close_content[i].setStyle('display','block');
+            }
+        }
+        if ($defined(this.expand_icon))
+        {
+            this.expand_icon.set('src',this.expand_icon.title);
+        }
+        this.is_open = false;
+    },
+
+    isOpen : function()
+    {
+        return this.is_open;
+    },
+
+    toggle: function()
+    {
+        if (this.isOpen())
+        {
+            this.close();
+        }
+        else
+        {
+            this.open();
+        }
+    }
+    });
+
+
+window.addEvent('domready', function()
+{
+    $$('.revision_log').each(function(item, i)
+    {
+        var item_slide = item.getElement('.revisioninfo');
+        var open_content  = new Array();
+        var close_content = new Array();
+        open_content.push(item.getElement('.long_description'));
+        close_content.push(item.getElement('.short_description'));
+        var expand_icon = item.getElement('.expand_icon');
+        var colapsable = new Colapsable(item_slide,expand_icon,open_content,close_content);
+        
+        item.getElement('.expand_revisioninfo').addEvent('click',function(){colapsable.toggle();});
+        item.colapsable = colapsable;
+    });
+
+    $$('.diffBox').each(function(item, i)
+    {
+        var item_slide = item.getNext('.diffinfo');
+        var expand_icon = item.getElement( '.expand_diff' );
+        var colapsable = new Colapsable(item_slide,expand_icon,null,null,true);
+        item.getElement( '.expand_diff' ).addEvent( 'click', function(){colapsable.toggle();});
+        item.colapsable=colapsable;
+    });
+});
+
+function toggle_expand_all(action)
+{
+    $$('.revision_log').each(function(item, i)
+    {
+    	var colapsable = item.colapsable;
+        if(action == 'close')
+        {
+            $('expand_all').setStyle('display','block');
+            $('collapse_all').setStyle('display','none');
+            colapsable.close();
+        }
+        else if(action == 'open')
+        {
+            $('expand_all').setStyle('display','none');
+            $('collapse_all').setStyle('display','block');
+            colapsable.open();
+        }
+    });
+}
+
+function toggle_expand_all_revisionview(action)
+{
+    $$('.diffBox').each(function(item, i)
+    {
+    	var colapsable = item.colapsable;
+        if(action == 'close')
+        {
+            $('expand_all').setStyle('display','block');
+            $('collapse_all').setStyle('display','none');
+            colapsable.close();
+        }
+        else if(action == 'open')
+        {
+            $('expand_all').setStyle('display','none');
+            $('collapse_all').setStyle('display','block');
+            colapsable.open();
+        }
+    });
+}
+

=== added file 'loggerhead/static/javascript/mootools-1.2-core.js'
--- loggerhead/static/javascript/mootools-1.2-core.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/mootools-1.2-core.js	2008-06-13 23:50:23 +0000
@@ -0,0 +1,333 @@
+//MooTools, <http://mootools.net>, My Object Oriented (JavaScript) Tools. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
+
+var MooTools={version:"1.2.0",build:""};var Native=function(J){J=J||{};var F=J.afterImplement||function(){};var G=J.generics;G=(G!==false);var H=J.legacy;
+var E=J.initialize;var B=J.protect;var A=J.name;var C=E||H;C.constructor=Native;C.$family={name:"native"};if(H&&E){C.prototype=H.prototype;}C.prototype.constructor=C;
+if(A){var D=A.toLowerCase();C.prototype.$family={name:D};Native.typize(C,D);}var I=function(M,K,N,L){if(!B||L||!M.prototype[K]){M.prototype[K]=N;}if(G){Native.genericize(M,K,B);
+}F.call(M,K,N);return M;};C.implement=function(L,K,N){if(typeof L=="string"){return I(this,L,K,N);}for(var M in L){I(this,M,L[M],K);}return this;};C.alias=function(M,K,N){if(typeof M=="string"){M=this.prototype[M];
+if(M){I(this,K,M,N);}}else{for(var L in M){this.alias(L,M[L],K);}}return this;};return C;};Native.implement=function(D,C){for(var B=0,A=D.length;B<A;B++){D[B].implement(C);
+}};Native.genericize=function(B,C,A){if((!A||!B[C])&&typeof B.prototype[C]=="function"){B[C]=function(){var D=Array.prototype.slice.call(arguments);return B.prototype[C].apply(D.shift(),D);
+};}};Native.typize=function(A,B){if(!A.type){A.type=function(C){return($type(C)===B);};}};Native.alias=function(E,B,A,F){for(var D=0,C=E.length;D<C;D++){E[D].alias(B,A,F);
+}};(function(B){for(var A in B){Native.typize(B[A],A);}})({"boolean":Boolean,"native":Native,object:Object});(function(B){for(var A in B){new Native({name:A,initialize:B[A],protect:true});
+}})({String:String,Function:Function,Number:Number,Array:Array,RegExp:RegExp,Date:Date});(function(B,A){for(var C=A.length;C--;C){Native.genericize(B,A[C],true);
+}return arguments.callee;})(Array,["pop","push","reverse","shift","sort","splice","unshift","concat","join","slice","toString","valueOf","indexOf","lastIndexOf"])(String,["charAt","charCodeAt","concat","indexOf","lastIndexOf","match","replace","search","slice","split","substr","substring","toLowerCase","toUpperCase","valueOf"]);
+function $chk(A){return !!(A||A===0);}function $clear(A){clearTimeout(A);clearInterval(A);return null;}function $defined(A){return(A!=undefined);}function $empty(){}function $arguments(A){return function(){return arguments[A];
+};}function $lambda(A){return(typeof A=="function")?A:function(){return A;};}function $extend(C,A){for(var B in (A||{})){C[B]=A[B];}return C;}function $unlink(C){var B;
+switch($type(C)){case"object":B={};for(var E in C){B[E]=$unlink(C[E]);}break;case"hash":B=$unlink(C.getClean());break;case"array":B=[];for(var D=0,A=C.length;
+D<A;D++){B[D]=$unlink(C[D]);}break;default:return C;}return B;}function $merge(){var E={};for(var D=0,A=arguments.length;D<A;D++){var B=arguments[D];if($type(B)!="object"){continue;
+}for(var C in B){var G=B[C],F=E[C];E[C]=(F&&$type(G)=="object"&&$type(F)=="object")?$merge(F,G):$unlink(G);}}return E;}function $pick(){for(var B=0,A=arguments.length;
+B<A;B++){if(arguments[B]!=undefined){return arguments[B];}}return null;}function $random(B,A){return Math.floor(Math.random()*(A-B+1)+B);}function $splat(B){var A=$type(B);
+return(A)?((A!="array"&&A!="arguments")?[B]:B):[];}var $time=Date.now||function(){return new Date().getTime();};function $try(){for(var B=0,A=arguments.length;
+B<A;B++){try{return arguments[B]();}catch(C){}}return null;}function $type(A){if(A==undefined){return false;}if(A.$family){return(A.$family.name=="number"&&!isFinite(A))?false:A.$family.name;
+}if(A.nodeName){switch(A.nodeType){case 1:return"element";case 3:return(/\S/).test(A.nodeValue)?"textnode":"whitespace";}}else{if(typeof A.length=="number"){if(A.callee){return"arguments";
+}else{if(A.item){return"collection";}}}}return typeof A;}var Hash=new Native({name:"Hash",initialize:function(A){if($type(A)=="hash"){A=$unlink(A.getClean());
+}for(var B in A){this[B]=A[B];}return this;}});Hash.implement({getLength:function(){var B=0;for(var A in this){if(this.hasOwnProperty(A)){B++;}}return B;
+},forEach:function(B,C){for(var A in this){if(this.hasOwnProperty(A)){B.call(C,this[A],A,this);}}},getClean:function(){var B={};for(var A in this){if(this.hasOwnProperty(A)){B[A]=this[A];
+}}return B;}});Hash.alias("forEach","each");function $H(A){return new Hash(A);}Array.implement({forEach:function(C,D){for(var B=0,A=this.length;B<A;B++){C.call(D,this[B],B,this);
+}}});Array.alias("forEach","each");function $A(C){if(C.item){var D=[];for(var B=0,A=C.length;B<A;B++){D[B]=C[B];}return D;}return Array.prototype.slice.call(C);
+}function $each(C,B,D){var A=$type(C);((A=="arguments"||A=="collection"||A=="array")?Array:Hash).each(C,B,D);}var Browser=new Hash({Engine:{name:"unknown",version:""},Platform:{name:(navigator.platform.match(/mac|win|linux/i)||["other"])[0].toLowerCase()},Features:{xpath:!!(document.evaluate),air:!!(window.runtime)},Plugins:{}});
+if(window.opera){Browser.Engine={name:"presto",version:(document.getElementsByClassName)?950:925};}else{if(window.ActiveXObject){Browser.Engine={name:"trident",version:(window.XMLHttpRequest)?5:4};
+}else{if(!navigator.taintEnabled){Browser.Engine={name:"webkit",version:(Browser.Features.xpath)?420:419};}else{if(document.getBoxObjectFor!=null){Browser.Engine={name:"gecko",version:(document.getElementsByClassName)?19:18};
+}}}}Browser.Engine[Browser.Engine.name]=Browser.Engine[Browser.Engine.name+Browser.Engine.version]=true;if(window.orientation!=undefined){Browser.Platform.name="ipod";
+}Browser.Platform[Browser.Platform.name]=true;Browser.Request=function(){return $try(function(){return new XMLHttpRequest();},function(){return new ActiveXObject("MSXML2.XMLHTTP");
+});};Browser.Features.xhr=!!(Browser.Request());Browser.Plugins.Flash=(function(){var A=($try(function(){return navigator.plugins["Shockwave Flash"].description;
+},function(){return new ActiveXObject("ShockwaveFlash.ShockwaveFlash").GetVariable("$version");})||"0 r0").match(/\d+/g);return{version:parseInt(A[0]||0+"."+A[1]||0),build:parseInt(A[2]||0)};
+})();function $exec(B){if(!B){return B;}if(window.execScript){window.execScript(B);}else{var A=document.createElement("script");A.setAttribute("type","text/javascript");
+A.text=B;document.head.appendChild(A);document.head.removeChild(A);}return B;}Native.UID=1;var $uid=(Browser.Engine.trident)?function(A){return(A.uid||(A.uid=[Native.UID++]))[0];
+}:function(A){return A.uid||(A.uid=Native.UID++);};var Window=new Native({name:"Window",legacy:(Browser.Engine.trident)?null:window.Window,initialize:function(A){$uid(A);
+if(!A.Element){A.Element=$empty;if(Browser.Engine.webkit){A.document.createElement("iframe");}A.Element.prototype=(Browser.Engine.webkit)?window["[[DOMElement.prototype]]"]:{};
+}return $extend(A,Window.Prototype);},afterImplement:function(B,A){window[B]=Window.Prototype[B]=A;}});Window.Prototype={$family:{name:"window"}};new Window(window);
+var Document=new Native({name:"Document",legacy:(Browser.Engine.trident)?null:window.Document,initialize:function(A){$uid(A);A.head=A.getElementsByTagName("head")[0];
+A.html=A.getElementsByTagName("html")[0];A.window=A.defaultView||A.parentWindow;if(Browser.Engine.trident4){$try(function(){A.execCommand("BackgroundImageCache",false,true);
+});}return $extend(A,Document.Prototype);},afterImplement:function(B,A){document[B]=Document.Prototype[B]=A;}});Document.Prototype={$family:{name:"document"}};
+new Document(document);Array.implement({every:function(C,D){for(var B=0,A=this.length;B<A;B++){if(!C.call(D,this[B],B,this)){return false;}}return true;
+},filter:function(D,E){var C=[];for(var B=0,A=this.length;B<A;B++){if(D.call(E,this[B],B,this)){C.push(this[B]);}}return C;},clean:function(){return this.filter($defined);
+},indexOf:function(C,D){var A=this.length;for(var B=(D<0)?Math.max(0,A+D):D||0;B<A;B++){if(this[B]===C){return B;}}return -1;},map:function(D,E){var C=[];
+for(var B=0,A=this.length;B<A;B++){C[B]=D.call(E,this[B],B,this);}return C;},some:function(C,D){for(var B=0,A=this.length;B<A;B++){if(C.call(D,this[B],B,this)){return true;
+}}return false;},associate:function(C){var D={},B=Math.min(this.length,C.length);for(var A=0;A<B;A++){D[C[A]]=this[A];}return D;},link:function(C){var A={};
+for(var E=0,B=this.length;E<B;E++){for(var D in C){if(C[D](this[E])){A[D]=this[E];delete C[D];break;}}}return A;},contains:function(A,B){return this.indexOf(A,B)!=-1;
+},extend:function(C){for(var B=0,A=C.length;B<A;B++){this.push(C[B]);}return this;},getLast:function(){return(this.length)?this[this.length-1]:null;},getRandom:function(){return(this.length)?this[$random(0,this.length-1)]:null;
+},include:function(A){if(!this.contains(A)){this.push(A);}return this;},combine:function(C){for(var B=0,A=C.length;B<A;B++){this.include(C[B]);}return this;
+},erase:function(B){for(var A=this.length;A--;A){if(this[A]===B){this.splice(A,1);}}return this;},empty:function(){this.length=0;return this;},flatten:function(){var D=[];
+for(var B=0,A=this.length;B<A;B++){var C=$type(this[B]);if(!C){continue;}D=D.concat((C=="array"||C=="collection"||C=="arguments")?Array.flatten(this[B]):this[B]);
+}return D;},hexToRgb:function(B){if(this.length!=3){return null;}var A=this.map(function(C){if(C.length==1){C+=C;}return C.toInt(16);});return(B)?A:"rgb("+A+")";
+},rgbToHex:function(D){if(this.length<3){return null;}if(this.length==4&&this[3]==0&&!D){return"transparent";}var B=[];for(var A=0;A<3;A++){var C=(this[A]-0).toString(16);
+B.push((C.length==1)?"0"+C:C);}return(D)?B:"#"+B.join("");}});Function.implement({extend:function(A){for(var B in A){this[B]=A[B];}return this;},create:function(B){var A=this;
+B=B||{};return function(D){var C=B.arguments;C=(C!=undefined)?$splat(C):Array.slice(arguments,(B.event)?1:0);if(B.event){C=[D||window.event].extend(C);
+}var E=function(){return A.apply(B.bind||null,C);};if(B.delay){return setTimeout(E,B.delay);}if(B.periodical){return setInterval(E,B.periodical);}if(B.attempt){return $try(E);
+}return E();};},pass:function(A,B){return this.create({arguments:A,bind:B});},attempt:function(A,B){return this.create({arguments:A,bind:B,attempt:true})();
+},bind:function(B,A){return this.create({bind:B,arguments:A});},bindWithEvent:function(B,A){return this.create({bind:B,event:true,arguments:A});},delay:function(B,C,A){return this.create({delay:B,bind:C,arguments:A})();
+},periodical:function(A,C,B){return this.create({periodical:A,bind:C,arguments:B})();},run:function(A,B){return this.apply(B,$splat(A));}});Number.implement({limit:function(B,A){return Math.min(A,Math.max(B,this));
+},round:function(A){A=Math.pow(10,A||0);return Math.round(this*A)/A;},times:function(B,C){for(var A=0;A<this;A++){B.call(C,A,this);}},toFloat:function(){return parseFloat(this);
+},toInt:function(A){return parseInt(this,A||10);}});Number.alias("times","each");(function(B){var A={};B.each(function(C){if(!Number[C]){A[C]=function(){return Math[C].apply(null,[this].concat($A(arguments)));
+};}});Number.implement(A);})(["abs","acos","asin","atan","atan2","ceil","cos","exp","floor","log","max","min","pow","sin","sqrt","tan"]);String.implement({test:function(A,B){return((typeof A=="string")?new RegExp(A,B):A).test(this);
+},contains:function(A,B){return(B)?(B+this+B).indexOf(B+A+B)>-1:this.indexOf(A)>-1;},trim:function(){return this.replace(/^\s+|\s+$/g,"");},clean:function(){return this.replace(/\s+/g," ").trim();
+},camelCase:function(){return this.replace(/-\D/g,function(A){return A.charAt(1).toUpperCase();});},hyphenate:function(){return this.replace(/[A-Z]/g,function(A){return("-"+A.charAt(0).toLowerCase());
+});},capitalize:function(){return this.replace(/\b[a-z]/g,function(A){return A.toUpperCase();});},escapeRegExp:function(){return this.replace(/([-.*+?^${}()|[\]\/\\])/g,"\\$1");
+},toInt:function(A){return parseInt(this,A||10);},toFloat:function(){return parseFloat(this);},hexToRgb:function(B){var A=this.match(/^#?(\w{1,2})(\w{1,2})(\w{1,2})$/);
+return(A)?A.slice(1).hexToRgb(B):null;},rgbToHex:function(B){var A=this.match(/\d{1,3}/g);return(A)?A.rgbToHex(B):null;},stripScripts:function(B){var A="";
+var C=this.replace(/<script[^>]*>([\s\S]*?)<\/script>/gi,function(){A+=arguments[1]+"\n";return"";});if(B===true){$exec(A);}else{if($type(B)=="function"){B(A,C);
+}}return C;},substitute:function(A,B){return this.replace(B||(/\\?\{([^}]+)\}/g),function(D,C){if(D.charAt(0)=="\\"){return D.slice(1);}return(A[C]!=undefined)?A[C]:"";
+});}});Hash.implement({has:Object.prototype.hasOwnProperty,keyOf:function(B){for(var A in this){if(this.hasOwnProperty(A)&&this[A]===B){return A;}}return null;
+},hasValue:function(A){return(Hash.keyOf(this,A)!==null);},extend:function(A){Hash.each(A,function(C,B){Hash.set(this,B,C);},this);return this;},combine:function(A){Hash.each(A,function(C,B){Hash.include(this,B,C);
+},this);return this;},erase:function(A){if(this.hasOwnProperty(A)){delete this[A];}return this;},get:function(A){return(this.hasOwnProperty(A))?this[A]:null;
+},set:function(A,B){if(!this[A]||this.hasOwnProperty(A)){this[A]=B;}return this;},empty:function(){Hash.each(this,function(B,A){delete this[A];},this);
+return this;},include:function(B,C){var A=this[B];if(A==undefined){this[B]=C;}return this;},map:function(B,C){var A=new Hash;Hash.each(this,function(E,D){A.set(D,B.call(C,E,D,this));
+},this);return A;},filter:function(B,C){var A=new Hash;Hash.each(this,function(E,D){if(B.call(C,E,D,this)){A.set(D,E);}},this);return A;},every:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&!B.call(C,this[A],A)){return false;
+}}return true;},some:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&B.call(C,this[A],A)){return true;}}return false;},getKeys:function(){var A=[];
+Hash.each(this,function(C,B){A.push(B);});return A;},getValues:function(){var A=[];Hash.each(this,function(B){A.push(B);});return A;},toQueryString:function(A){var B=[];
+Hash.each(this,function(F,E){if(A){E=A+"["+E+"]";}var D;switch($type(F)){case"object":D=Hash.toQueryString(F,E);break;case"array":var C={};F.each(function(H,G){C[G]=H;
+});D=Hash.toQueryString(C,E);break;default:D=E+"="+encodeURIComponent(F);}if(F!=undefined){B.push(D);}});return B.join("&");}});Hash.alias({keyOf:"indexOf",hasValue:"contains"});
+var Event=new Native({name:"Event",initialize:function(A,F){F=F||window;var K=F.document;A=A||F.event;if(A.$extended){return A;}this.$extended=true;var J=A.type;
+var G=A.target||A.srcElement;while(G&&G.nodeType==3){G=G.parentNode;}if(J.test(/key/)){var B=A.which||A.keyCode;var M=Event.Keys.keyOf(B);if(J=="keydown"){var D=B-111;
+if(D>0&&D<13){M="f"+D;}}M=M||String.fromCharCode(B).toLowerCase();}else{if(J.match(/(click|mouse|menu)/i)){K=(!K.compatMode||K.compatMode=="CSS1Compat")?K.html:K.body;
+var I={x:A.pageX||A.clientX+K.scrollLeft,y:A.pageY||A.clientY+K.scrollTop};var C={x:(A.pageX)?A.pageX-F.pageXOffset:A.clientX,y:(A.pageY)?A.pageY-F.pageYOffset:A.clientY};
+if(J.match(/DOMMouseScroll|mousewheel/)){var H=(A.wheelDelta)?A.wheelDelta/120:-(A.detail||0)/3;}var E=(A.which==3)||(A.button==2);var L=null;if(J.match(/over|out/)){switch(J){case"mouseover":L=A.relatedTarget||A.fromElement;
+break;case"mouseout":L=A.relatedTarget||A.toElement;}if(!(function(){while(L&&L.nodeType==3){L=L.parentNode;}return true;}).create({attempt:Browser.Engine.gecko})()){L=false;
+}}}}return $extend(this,{event:A,type:J,page:I,client:C,rightClick:E,wheel:H,relatedTarget:L,target:G,code:B,key:M,shift:A.shiftKey,control:A.ctrlKey,alt:A.altKey,meta:A.metaKey});
+}});Event.Keys=new Hash({enter:13,up:38,down:40,left:37,right:39,esc:27,space:32,backspace:8,tab:9,"delete":46});Event.implement({stop:function(){return this.stopPropagation().preventDefault();
+},stopPropagation:function(){if(this.event.stopPropagation){this.event.stopPropagation();}else{this.event.cancelBubble=true;}return this;},preventDefault:function(){if(this.event.preventDefault){this.event.preventDefault();
+}else{this.event.returnValue=false;}return this;}});var Class=new Native({name:"Class",initialize:function(B){B=B||{};var A=function(E){for(var D in this){this[D]=$unlink(this[D]);
+}for(var F in Class.Mutators){if(!this[F]){continue;}Class.Mutators[F](this,this[F]);delete this[F];}this.constructor=A;if(E===$empty){return this;}var C=(this.initialize)?this.initialize.apply(this,arguments):this;
+if(this.options&&this.options.initialize){this.options.initialize.call(this);}return C;};$extend(A,this);A.constructor=Class;A.prototype=B;return A;}});
+Class.implement({implement:function(){Class.Mutators.Implements(this.prototype,Array.slice(arguments));return this;}});Class.Mutators={Implements:function(A,B){$splat(B).each(function(C){$extend(A,($type(C)=="class")?new C($empty):C);
+});},Extends:function(self,klass){var instance=new klass($empty);delete instance.parent;delete instance.parentOf;for(var key in instance){var current=self[key],previous=instance[key];
+if(current==undefined){self[key]=previous;continue;}var ctype=$type(current),ptype=$type(previous);if(ctype!=ptype){continue;}switch(ctype){case"function":if(!arguments.callee.caller){self[key]=eval("("+String(current).replace(/\bthis\.parent\(\s*(\))?/g,function(full,close){return"arguments.callee._parent_.call(this"+(close||", ");
+})+")");}self[key]._parent_=previous;break;case"object":self[key]=$merge(previous,current);}}self.parent=function(){return arguments.callee.caller._parent_.apply(this,arguments);
+};self.parentOf=function(descendant){return descendant._parent_.apply(this,Array.slice(arguments,1));};}};var Chain=new Class({chain:function(){this.$chain=(this.$chain||[]).extend(arguments);
+return this;},callChain:function(){return(this.$chain&&this.$chain.length)?this.$chain.shift().apply(this,arguments):false;},clearChain:function(){if(this.$chain){this.$chain.empty();
+}return this;}});var Events=new Class({addEvent:function(C,B,A){C=Events.removeOn(C);if(B!=$empty){this.$events=this.$events||{};this.$events[C]=this.$events[C]||[];
+this.$events[C].include(B);if(A){B.internal=true;}}return this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);}return this;},fireEvent:function(C,B,A){C=Events.removeOn(C);
+if(!this.$events||!this.$events[C]){return this;}this.$events[C].each(function(D){D.create({bind:this,delay:A,"arguments":B})();},this);return this;},removeEvent:function(B,A){B=Events.removeOn(B);
+if(!this.$events||!this.$events[B]){return this;}if(!A.internal){this.$events[B].erase(A);}return this;},removeEvents:function(C){for(var D in this.$events){if(C&&C!=D){continue;
+}var B=this.$events[D];for(var A=B.length;A--;A){this.removeEvent(D,B[A]);}}return this;}});Events.removeOn=function(A){return A.replace(/^on([A-Z])/,function(B,C){return C.toLowerCase();
+});};var Options=new Class({setOptions:function(){this.options=$merge.run([this.options].extend(arguments));if(!this.addEvent){return this;}for(var A in this.options){if($type(this.options[A])!="function"||!(/^on[A-Z]/).test(A)){continue;
+}this.addEvent(A,this.options[A]);delete this.options[A];}return this;}});Document.implement({newElement:function(A,B){if(Browser.Engine.trident&&B){["name","type","checked"].each(function(C){if(!B[C]){return ;
+}A+=" "+C+'="'+B[C]+'"';if(C!="checked"){delete B[C];}});A="<"+A+">";}return $.element(this.createElement(A)).set(B);},newTextNode:function(A){return this.createTextNode(A);
+},getDocument:function(){return this;},getWindow:function(){return this.defaultView||this.parentWindow;},purge:function(){var C=this.getElementsByTagName("*");
+for(var B=0,A=C.length;B<A;B++){Browser.freeMem(C[B]);}}});var Element=new Native({name:"Element",legacy:window.Element,initialize:function(A,B){var C=Element.Constructors.get(A);
+if(C){return C(B);}if(typeof A=="string"){return document.newElement(A,B);}return $(A).set(B);},afterImplement:function(A,B){if(!Array[A]){Elements.implement(A,Elements.multi(A));
+}Element.Prototype[A]=B;}});Element.Prototype={$family:{name:"element"}};Element.Constructors=new Hash;var IFrame=new Native({name:"IFrame",generics:false,initialize:function(){var E=Array.link(arguments,{properties:Object.type,iframe:$defined});
+var C=E.properties||{};var B=$(E.iframe)||false;var D=C.onload||$empty;delete C.onload;C.id=C.name=$pick(C.id,C.name,B.id,B.name,"IFrame_"+$time());B=new Element(B||"iframe",C);
+var A=function(){var F=$try(function(){return B.contentWindow.location.host;});if(F&&F==window.location.host){var H=new Window(B.contentWindow);var G=new Document(B.contentWindow.document);
+$extend(H.Element.prototype,Element.Prototype);}D.call(B.contentWindow,B.contentWindow.document);};(!window.frames[C.id])?B.addListener("load",A):A();return B;
+}});var Elements=new Native({initialize:function(F,B){B=$extend({ddup:true,cash:true},B);F=F||[];if(B.ddup||B.cash){var G={},E=[];for(var C=0,A=F.length;
+C<A;C++){var D=$.element(F[C],!B.cash);if(B.ddup){if(G[D.uid]){continue;}G[D.uid]=true;}E.push(D);}F=E;}return(B.cash)?$extend(F,this):F;}});Elements.implement({filter:function(A,B){if(!A){return this;
+}return new Elements(Array.filter(this,(typeof A=="string")?function(C){return C.match(A);}:A,B));}});Elements.multi=function(A){return function(){var B=[];
+var F=true;for(var D=0,C=this.length;D<C;D++){var E=this[D][A].apply(this[D],arguments);B.push(E);if(F){F=($type(E)=="element");}}return(F)?new Elements(B):B;
+};};Window.implement({$:function(B,C){if(B&&B.$family&&B.uid){return B;}var A=$type(B);return($[A])?$[A](B,C,this.document):null;},$$:function(A){if(arguments.length==1&&typeof A=="string"){return this.document.getElements(A);
+}var F=[];var C=Array.flatten(arguments);for(var D=0,B=C.length;D<B;D++){var E=C[D];switch($type(E)){case"element":E=[E];break;case"string":E=this.document.getElements(E,true);
+break;default:E=false;}if(E){F.extend(E);}}return new Elements(F);},getDocument:function(){return this.document;},getWindow:function(){return this;}});
+$.string=function(C,B,A){C=A.getElementById(C);return(C)?$.element(C,B):null;};$.element=function(A,D){$uid(A);if(!D&&!A.$family&&!(/^object|embed$/i).test(A.tagName)){var B=Element.Prototype;
+for(var C in B){A[C]=B[C];}}return A;};$.object=function(B,C,A){if(B.toElement){return $.element(B.toElement(A),C);}return null;};$.textnode=$.whitespace=$.window=$.document=$arguments(0);
+Native.implement([Element,Document],{getElement:function(A,B){return $(this.getElements(A,true)[0]||null,B);},getElements:function(A,D){A=A.split(",");
+var C=[];var B=(A.length>1);A.each(function(E){var F=this.getElementsByTagName(E.trim());(B)?C.extend(F):C=F;},this);return new Elements(C,{ddup:B,cash:!D});
+}});Element.Storage={get:function(A){return(this[A]||(this[A]={}));}};Element.Inserters=new Hash({before:function(B,A){if(A.parentNode){A.parentNode.insertBefore(B,A);
+}},after:function(B,A){if(!A.parentNode){return ;}var C=A.nextSibling;(C)?A.parentNode.insertBefore(B,C):A.parentNode.appendChild(B);},bottom:function(B,A){A.appendChild(B);
+},top:function(B,A){var C=A.firstChild;(C)?A.insertBefore(B,C):A.appendChild(B);}});Element.Inserters.inside=Element.Inserters.bottom;Element.Inserters.each(function(C,B){var A=B.capitalize();
+Element.implement("inject"+A,function(D){C(this,$(D,true));return this;});Element.implement("grab"+A,function(D){C($(D,true),this);return this;});});Element.implement({getDocument:function(){return this.ownerDocument;
+},getWindow:function(){return this.ownerDocument.getWindow();},getElementById:function(D,C){var B=this.ownerDocument.getElementById(D);if(!B){return null;
+}for(var A=B.parentNode;A!=this;A=A.parentNode){if(!A){return null;}}return $.element(B,C);},set:function(D,B){switch($type(D)){case"object":for(var C in D){this.set(C,D[C]);
+}break;case"string":var A=Element.Properties.get(D);(A&&A.set)?A.set.apply(this,Array.slice(arguments,1)):this.setProperty(D,B);}return this;},get:function(B){var A=Element.Properties.get(B);
+return(A&&A.get)?A.get.apply(this,Array.slice(arguments,1)):this.getProperty(B);},erase:function(B){var A=Element.Properties.get(B);(A&&A.erase)?A.erase.apply(this,Array.slice(arguments,1)):this.removeProperty(B);
+return this;},match:function(A){return(!A||Element.get(this,"tag")==A);},inject:function(B,A){Element.Inserters.get(A||"bottom")(this,$(B,true));return this;
+},wraps:function(B,A){B=$(B,true);return this.replaces(B).grab(B,A);},grab:function(B,A){Element.Inserters.get(A||"bottom")($(B,true),this);return this;
+},appendText:function(B,A){return this.grab(this.getDocument().newTextNode(B),A);},adopt:function(){Array.flatten(arguments).each(function(A){A=$(A,true);
+if(A){this.appendChild(A);}},this);return this;},dispose:function(){return(this.parentNode)?this.parentNode.removeChild(this):this;},clone:function(D,C){switch($type(this)){case"element":var H={};
+for(var G=0,E=this.attributes.length;G<E;G++){var B=this.attributes[G],L=B.nodeName.toLowerCase();if(Browser.Engine.trident&&(/input/i).test(this.tagName)&&(/width|height/).test(L)){continue;
+}var K=(L=="style"&&this.style)?this.style.cssText:B.nodeValue;if(!$chk(K)||L=="uid"||(L=="id"&&!C)){continue;}if(K!="inherit"&&["string","number"].contains($type(K))){H[L]=K;
+}}var J=new Element(this.nodeName.toLowerCase(),H);if(D!==false){for(var I=0,F=this.childNodes.length;I<F;I++){var A=Element.clone(this.childNodes[I],true,C);
+if(A){J.grab(A);}}}return J;case"textnode":return document.newTextNode(this.nodeValue);}return null;},replaces:function(A){A=$(A,true);A.parentNode.replaceChild(this,A);
+return this;},hasClass:function(A){return this.className.contains(A," ");},addClass:function(A){if(!this.hasClass(A)){this.className=(this.className+" "+A).clean();
+}return this;},removeClass:function(A){this.className=this.className.replace(new RegExp("(^|\\s)"+A+"(?:\\s|$)"),"$1").clean();return this;},toggleClass:function(A){return this.hasClass(A)?this.removeClass(A):this.addClass(A);
+},getComputedStyle:function(B){if(this.currentStyle){return this.currentStyle[B.camelCase()];}var A=this.getWindow().getComputedStyle(this,null);return(A)?A.getPropertyValue([B.hyphenate()]):null;
+},empty:function(){$A(this.childNodes).each(function(A){Browser.freeMem(A);Element.empty(A);Element.dispose(A);},this);return this;},destroy:function(){Browser.freeMem(this.empty().dispose());
+return null;},getSelected:function(){return new Elements($A(this.options).filter(function(A){return A.selected;}));},toQueryString:function(){var A=[];
+this.getElements("input, select, textarea").each(function(B){if(!B.name||B.disabled){return ;}var C=(B.tagName.toLowerCase()=="select")?Element.getSelected(B).map(function(D){return D.value;
+}):((B.type=="radio"||B.type=="checkbox")&&!B.checked)?null:B.value;$splat(C).each(function(D){if(D){A.push(B.name+"="+encodeURIComponent(D));}});});return A.join("&");
+},getProperty:function(C){var B=Element.Attributes,A=B.Props[C];var D=(A)?this[A]:this.getAttribute(C,2);return(B.Bools[C])?!!D:(A)?D:D||null;},getProperties:function(){var A=$A(arguments);
+return A.map(function(B){return this.getProperty(B);},this).associate(A);},setProperty:function(D,E){var C=Element.Attributes,B=C.Props[D],A=$defined(E);
+if(B&&C.Bools[D]){E=(E||!A)?true:false;}else{if(!A){return this.removeProperty(D);}}(B)?this[B]=E:this.setAttribute(D,E);return this;},setProperties:function(A){for(var B in A){this.setProperty(B,A[B]);
+}return this;},removeProperty:function(D){var C=Element.Attributes,B=C.Props[D],A=(B&&C.Bools[D]);(B)?this[B]=(A)?false:"":this.removeAttribute(D);return this;
+},removeProperties:function(){Array.each(arguments,this.removeProperty,this);return this;}});(function(){var A=function(D,B,I,C,F,H){var E=D[I||B];var G=[];
+while(E){if(E.nodeType==1&&(!C||Element.match(E,C))){G.push(E);if(!F){break;}}E=E[B];}return(F)?new Elements(G,{ddup:false,cash:!H}):$(G[0],H);};Element.implement({getPrevious:function(B,C){return A(this,"previousSibling",null,B,false,C);
+},getAllPrevious:function(B,C){return A(this,"previousSibling",null,B,true,C);},getNext:function(B,C){return A(this,"nextSibling",null,B,false,C);},getAllNext:function(B,C){return A(this,"nextSibling",null,B,true,C);
+},getFirst:function(B,C){return A(this,"nextSibling","firstChild",B,false,C);},getLast:function(B,C){return A(this,"previousSibling","lastChild",B,false,C);
+},getParent:function(B,C){return A(this,"parentNode",null,B,false,C);},getParents:function(B,C){return A(this,"parentNode",null,B,true,C);},getChildren:function(B,C){return A(this,"nextSibling","firstChild",B,true,C);
+},hasChild:function(B){B=$(B,true);return(!!B&&$A(this.getElementsByTagName(B.tagName)).contains(B));}});})();Element.Properties=new Hash;Element.Properties.style={set:function(A){this.style.cssText=A;
+},get:function(){return this.style.cssText;},erase:function(){this.style.cssText="";}};Element.Properties.tag={get:function(){return this.tagName.toLowerCase();
+}};Element.Properties.href={get:function(){return(!this.href)?null:this.href.replace(new RegExp("^"+document.location.protocol+"//"+document.location.host),"");
+}};Element.Properties.html={set:function(){return this.innerHTML=Array.flatten(arguments).join("");}};Native.implement([Element,Window,Document],{addListener:function(B,A){if(this.addEventListener){this.addEventListener(B,A,false);
+}else{this.attachEvent("on"+B,A);}return this;},removeListener:function(B,A){if(this.removeEventListener){this.removeEventListener(B,A,false);}else{this.detachEvent("on"+B,A);
+}return this;},retrieve:function(B,A){var D=Element.Storage.get(this.uid);var C=D[B];if($defined(A)&&!$defined(C)){C=D[B]=A;}return $pick(C);},store:function(B,A){var C=Element.Storage.get(this.uid);
+C[B]=A;return this;},eliminate:function(A){var B=Element.Storage.get(this.uid);delete B[A];return this;}});Element.Attributes=new Hash({Props:{html:"innerHTML","class":"className","for":"htmlFor",text:(Browser.Engine.trident)?"innerText":"textContent"},Bools:["compact","nowrap","ismap","declare","noshade","checked","disabled","readonly","multiple","selected","noresize","defer"],Camels:["value","accessKey","cellPadding","cellSpacing","colSpan","frameBorder","maxLength","readOnly","rowSpan","tabIndex","useMap"]});
+Browser.freeMem=function(A){if(!A){return ;}if(Browser.Engine.trident&&(/object/i).test(A.tagName)){for(var B in A){if(typeof A[B]=="function"){A[B]=$empty;
+}}Element.dispose(A);}if(A.uid&&A.removeEvents){A.removeEvents();}};(function(B){var C=B.Bools,A=B.Camels;B.Bools=C=C.associate(C);Hash.extend(Hash.combine(B.Props,C),A.associate(A.map(function(D){return D.toLowerCase();
+})));B.erase("Camels");})(Element.Attributes);window.addListener("unload",function(){window.removeListener("unload",arguments.callee);document.purge();
+if(Browser.Engine.trident){CollectGarbage();}});Element.Properties.events={set:function(A){this.addEvents(A);}};Native.implement([Element,Window,Document],{addEvent:function(E,G){var H=this.retrieve("events",{});
+H[E]=H[E]||{keys:[],values:[]};if(H[E].keys.contains(G)){return this;}H[E].keys.push(G);var F=E,A=Element.Events.get(E),C=G,I=this;if(A){if(A.onAdd){A.onAdd.call(this,G);
+}if(A.condition){C=function(J){if(A.condition.call(this,J)){return G.call(this,J);}return false;};}F=A.base||F;}var D=function(){return G.call(I);};var B=Element.NativeEvents[F]||0;
+if(B){if(B==2){D=function(J){J=new Event(J,I.getWindow());if(C.call(I,J)===false){J.stop();}};}this.addListener(F,D);}H[E].values.push(D);return this;},removeEvent:function(D,C){var B=this.retrieve("events");
+if(!B||!B[D]){return this;}var G=B[D].keys.indexOf(C);if(G==-1){return this;}var A=B[D].keys.splice(G,1)[0];var F=B[D].values.splice(G,1)[0];var E=Element.Events.get(D);
+if(E){if(E.onRemove){E.onRemove.call(this,C);}D=E.base||D;}return(Element.NativeEvents[D])?this.removeListener(D,F):this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);
+}return this;},removeEvents:function(B){var A=this.retrieve("events");if(!A){return this;}if(!B){for(var C in A){this.removeEvents(C);}A=null;}else{if(A[B]){while(A[B].keys[0]){this.removeEvent(B,A[B].keys[0]);
+}A[B]=null;}}return this;},fireEvent:function(D,B,A){var C=this.retrieve("events");if(!C||!C[D]){return this;}C[D].keys.each(function(E){E.create({bind:this,delay:A,"arguments":B})();
+},this);return this;},cloneEvents:function(D,A){D=$(D);var C=D.retrieve("events");if(!C){return this;}if(!A){for(var B in C){this.cloneEvents(D,B);}}else{if(C[A]){C[A].keys.each(function(E){this.addEvent(A,E);
+},this);}}return this;}});Element.NativeEvents={click:2,dblclick:2,mouseup:2,mousedown:2,contextmenu:2,mousewheel:2,DOMMouseScroll:2,mouseover:2,mouseout:2,mousemove:2,selectstart:2,selectend:2,keydown:2,keypress:2,keyup:2,focus:2,blur:2,change:2,reset:2,select:2,submit:2,load:1,unload:1,beforeunload:2,resize:1,move:1,DOMContentLoaded:1,readystatechange:1,error:1,abort:1,scroll:1};
+(function(){var A=function(B){var C=B.relatedTarget;if(C==undefined){return true;}if(C===false){return false;}return($type(this)!="document"&&C!=this&&C.prefix!="xul"&&!this.hasChild(C));
+};Element.Events=new Hash({mouseenter:{base:"mouseover",condition:A},mouseleave:{base:"mouseout",condition:A},mousewheel:{base:(Browser.Engine.gecko)?"DOMMouseScroll":"mousewheel"}});
+})();Element.Properties.styles={set:function(A){this.setStyles(A);}};Element.Properties.opacity={set:function(A,B){if(!B){if(A==0){if(this.style.visibility!="hidden"){this.style.visibility="hidden";
+}}else{if(this.style.visibility!="visible"){this.style.visibility="visible";}}}if(!this.currentStyle||!this.currentStyle.hasLayout){this.style.zoom=1;}if(Browser.Engine.trident){this.style.filter=(A==1)?"":"alpha(opacity="+A*100+")";
+}this.style.opacity=A;this.store("opacity",A);},get:function(){return this.retrieve("opacity",1);}};Element.implement({setOpacity:function(A){return this.set("opacity",A,true);
+},getOpacity:function(){return this.get("opacity");},setStyle:function(B,A){switch(B){case"opacity":return this.set("opacity",parseFloat(A));case"float":B=(Browser.Engine.trident)?"styleFloat":"cssFloat";
+}B=B.camelCase();if($type(A)!="string"){var C=(Element.Styles.get(B)||"@").split(" ");A=$splat(A).map(function(E,D){if(!C[D]){return"";}return($type(E)=="number")?C[D].replace("@",Math.round(E)):E;
+}).join(" ");}else{if(A==String(Number(A))){A=Math.round(A);}}this.style[B]=A;return this;},getStyle:function(G){switch(G){case"opacity":return this.get("opacity");
+case"float":G=(Browser.Engine.trident)?"styleFloat":"cssFloat";}G=G.camelCase();var A=this.style[G];if(!$chk(A)){A=[];for(var F in Element.ShortStyles){if(G!=F){continue;
+}for(var E in Element.ShortStyles[F]){A.push(this.getStyle(E));}return A.join(" ");}A=this.getComputedStyle(G);}if(A){A=String(A);var C=A.match(/rgba?\([\d\s,]+\)/);
+if(C){A=A.replace(C[0],C[0].rgbToHex());}}if(Browser.Engine.presto||(Browser.Engine.trident&&!$chk(parseInt(A)))){if(G.test(/^(height|width)$/)){var B=(G=="width")?["left","right"]:["top","bottom"],D=0;
+B.each(function(H){D+=this.getStyle("border-"+H+"-width").toInt()+this.getStyle("padding-"+H).toInt();},this);return this["offset"+G.capitalize()]-D+"px";
+}if(Browser.Engine.presto&&String(A).test("px")){return A;}if(G.test(/(border(.+)Width|margin|padding)/)){return"0px";}}return A;},setStyles:function(B){for(var A in B){this.setStyle(A,B[A]);
+}return this;},getStyles:function(){var A={};Array.each(arguments,function(B){A[B]=this.getStyle(B);},this);return A;}});Element.Styles=new Hash({left:"@px",top:"@px",bottom:"@px",right:"@px",width:"@px",height:"@px",maxWidth:"@px",maxHeight:"@px",minWidth:"@px",minHeight:"@px",backgroundColor:"rgb(@, @, @)",backgroundPosition:"@px @px",color:"rgb(@, @, @)",fontSize:"@px",letterSpacing:"@px",lineHeight:"@px",clip:"rect(@px @px @px @px)",margin:"@px @px @px @px",padding:"@px @px @px @px",border:"@px @ rgb(@, @, @) @px @ rgb(@, @, @) @px @ rgb(@, @, @)",borderWidth:"@px @px @px @px",borderStyle:"@ @ @ @",borderColor:"rgb(@, @, @) rgb(@, @, @) rgb(@, @, @) rgb(@, @, @)",zIndex:"@",zoom:"@",fontWeight:"@",textIndent:"@px",opacity:"@"});
+Element.ShortStyles={margin:{},padding:{},border:{},borderWidth:{},borderStyle:{},borderColor:{}};["Top","Right","Bottom","Left"].each(function(G){var F=Element.ShortStyles;
+var B=Element.Styles;["margin","padding"].each(function(H){var I=H+G;F[H][I]=B[I]="@px";});var E="border"+G;F.border[E]=B[E]="@px @ rgb(@, @, @)";var D=E+"Width",A=E+"Style",C=E+"Color";
+F[E]={};F.borderWidth[D]=F[E][D]=B[D]="@px";F.borderStyle[A]=F[E][A]=B[A]="@";F.borderColor[C]=F[E][C]=B[C]="rgb(@, @, @)";});(function(){Element.implement({scrollTo:function(H,I){if(B(this)){this.getWindow().scrollTo(H,I);
+}else{this.scrollLeft=H;this.scrollTop=I;}return this;},getSize:function(){if(B(this)){return this.getWindow().getSize();}return{x:this.offsetWidth,y:this.offsetHeight};
+},getScrollSize:function(){if(B(this)){return this.getWindow().getScrollSize();}return{x:this.scrollWidth,y:this.scrollHeight};},getScroll:function(){if(B(this)){return this.getWindow().getScroll();
+}return{x:this.scrollLeft,y:this.scrollTop};},getScrolls:function(){var I=this,H={x:0,y:0};while(I&&!B(I)){H.x+=I.scrollLeft;H.y+=I.scrollTop;I=I.parentNode;
+}return H;},getOffsetParent:function(){var H=this;if(B(H)){return null;}if(!Browser.Engine.trident){return H.offsetParent;}while((H=H.parentNode)&&!B(H)){if(D(H,"position")!="static"){return H;
+}}return null;},getOffsets:function(){var I=this,H={x:0,y:0};if(B(this)){return H;}while(I&&!B(I)){H.x+=I.offsetLeft;H.y+=I.offsetTop;if(Browser.Engine.gecko){if(!F(I)){H.x+=C(I);
+H.y+=G(I);}var J=I.parentNode;if(J&&D(J,"overflow")!="visible"){H.x+=C(J);H.y+=G(J);}}else{if(I!=this&&(Browser.Engine.trident||Browser.Engine.webkit)){H.x+=C(I);
+H.y+=G(I);}}I=I.offsetParent;if(Browser.Engine.trident){while(I&&!I.currentStyle.hasLayout){I=I.offsetParent;}}}if(Browser.Engine.gecko&&!F(this)){H.x-=C(this);
+H.y-=G(this);}return H;},getPosition:function(K){if(B(this)){return{x:0,y:0};}var L=this.getOffsets(),I=this.getScrolls();var H={x:L.x-I.x,y:L.y-I.y};var J=(K&&(K=$(K)))?K.getPosition():{x:0,y:0};
+return{x:H.x-J.x,y:H.y-J.y};},getCoordinates:function(J){if(B(this)){return this.getWindow().getCoordinates();}var H=this.getPosition(J),I=this.getSize();
+var K={left:H.x,top:H.y,width:I.x,height:I.y};K.right=K.left+K.width;K.bottom=K.top+K.height;return K;},computePosition:function(H){return{left:H.x-E(this,"margin-left"),top:H.y-E(this,"margin-top")};
+},position:function(H){return this.setStyles(this.computePosition(H));}});Native.implement([Document,Window],{getSize:function(){var I=this.getWindow();
+if(Browser.Engine.presto||Browser.Engine.webkit){return{x:I.innerWidth,y:I.innerHeight};}var H=A(this);return{x:H.clientWidth,y:H.clientHeight};},getScroll:function(){var I=this.getWindow();
+var H=A(this);return{x:I.pageXOffset||H.scrollLeft,y:I.pageYOffset||H.scrollTop};},getScrollSize:function(){var I=A(this);var H=this.getSize();return{x:Math.max(I.scrollWidth,H.x),y:Math.max(I.scrollHeight,H.y)};
+},getPosition:function(){return{x:0,y:0};},getCoordinates:function(){var H=this.getSize();return{top:0,left:0,bottom:H.y,right:H.x,height:H.y,width:H.x};
+}});var D=Element.getComputedStyle;function E(H,I){return D(H,I).toInt()||0;}function F(H){return D(H,"-moz-box-sizing")=="border-box";}function G(H){return E(H,"border-top-width");
+}function C(H){return E(H,"border-left-width");}function B(H){return(/^(?:body|html)$/i).test(H.tagName);}function A(H){var I=H.getDocument();return(!I.compatMode||I.compatMode=="CSS1Compat")?I.html:I.body;
+}})();Native.implement([Window,Document,Element],{getHeight:function(){return this.getSize().y;},getWidth:function(){return this.getSize().x;},getScrollTop:function(){return this.getScroll().y;
+},getScrollLeft:function(){return this.getScroll().x;},getScrollHeight:function(){return this.getScrollSize().y;},getScrollWidth:function(){return this.getScrollSize().x;
+},getTop:function(){return this.getPosition().y;},getLeft:function(){return this.getPosition().x;}});Native.implement([Document,Element],{getElements:function(H,G){H=H.split(",");
+var C,E={};for(var D=0,B=H.length;D<B;D++){var A=H[D],F=Selectors.Utils.search(this,A,E);if(D!=0&&F.item){F=$A(F);}C=(D==0)?F:(C.item)?$A(C).concat(F):C.concat(F);
+}return new Elements(C,{ddup:(H.length>1),cash:!G});}});Element.implement({match:function(B){if(!B){return true;}var D=Selectors.Utils.parseTagAndID(B);
+var A=D[0],E=D[1];if(!Selectors.Filters.byID(this,E)||!Selectors.Filters.byTag(this,A)){return false;}var C=Selectors.Utils.parseSelector(B);return(C)?Selectors.Utils.filter(this,C,{}):true;
+}});var Selectors={Cache:{nth:{},parsed:{}}};Selectors.RegExps={id:(/#([\w-]+)/),tag:(/^(\w+|\*)/),quick:(/^(\w+|\*)$/),splitter:(/\s*([+>~\s])\s*([a-zA-Z#.*:\[])/g),combined:(/\.([\w-]+)|\[(\w+)(?:([!*^$~|]?=)["']?(.*?)["']?)?\]|:([\w-]+)(?:\(["']?(.*?)?["']?\)|$)/g)};
+Selectors.Utils={chk:function(B,C){if(!C){return true;}var A=$uid(B);if(!C[A]){return C[A]=true;}return false;},parseNthArgument:function(F){if(Selectors.Cache.nth[F]){return Selectors.Cache.nth[F];
+}var C=F.match(/^([+-]?\d*)?([a-z]+)?([+-]?\d*)?$/);if(!C){return false;}var E=parseInt(C[1]);var B=(E||E===0)?E:1;var D=C[2]||false;var A=parseInt(C[3])||0;
+if(B!=0){A--;while(A<1){A+=B;}while(A>=B){A-=B;}}else{B=A;D="index";}switch(D){case"n":C={a:B,b:A,special:"n"};break;case"odd":C={a:2,b:0,special:"n"};
+break;case"even":C={a:2,b:1,special:"n"};break;case"first":C={a:0,special:"index"};break;case"last":C={special:"last-child"};break;case"only":C={special:"only-child"};
+break;default:C={a:(B-1),special:"index"};}return Selectors.Cache.nth[F]=C;},parseSelector:function(E){if(Selectors.Cache.parsed[E]){return Selectors.Cache.parsed[E];
+}var D,H={classes:[],pseudos:[],attributes:[]};while((D=Selectors.RegExps.combined.exec(E))){var I=D[1],G=D[2],F=D[3],B=D[4],C=D[5],J=D[6];if(I){H.classes.push(I);
+}else{if(C){var A=Selectors.Pseudo.get(C);if(A){H.pseudos.push({parser:A,argument:J});}else{H.attributes.push({name:C,operator:"=",value:J});}}else{if(G){H.attributes.push({name:G,operator:F,value:B});
+}}}}if(!H.classes.length){delete H.classes;}if(!H.attributes.length){delete H.attributes;}if(!H.pseudos.length){delete H.pseudos;}if(!H.classes&&!H.attributes&&!H.pseudos){H=null;
+}return Selectors.Cache.parsed[E]=H;},parseTagAndID:function(B){var A=B.match(Selectors.RegExps.tag);var C=B.match(Selectors.RegExps.id);return[(A)?A[1]:"*",(C)?C[1]:false];
+},filter:function(F,C,E){var D;if(C.classes){for(D=C.classes.length;D--;D){var G=C.classes[D];if(!Selectors.Filters.byClass(F,G)){return false;}}}if(C.attributes){for(D=C.attributes.length;
+D--;D){var B=C.attributes[D];if(!Selectors.Filters.byAttribute(F,B.name,B.operator,B.value)){return false;}}}if(C.pseudos){for(D=C.pseudos.length;D--;D){var A=C.pseudos[D];
+if(!Selectors.Filters.byPseudo(F,A.parser,A.argument,E)){return false;}}}return true;},getByTagAndID:function(B,A,D){if(D){var C=(B.getElementById)?B.getElementById(D,true):Element.getElementById(B,D,true);
+return(C&&Selectors.Filters.byTag(C,A))?[C]:[];}else{return B.getElementsByTagName(A);}},search:function(J,I,O){var B=[];var C=I.trim().replace(Selectors.RegExps.splitter,function(Z,Y,X){B.push(Y);
+return":)"+X;}).split(":)");var K,F,E,V;for(var U=0,Q=C.length;U<Q;U++){var T=C[U];if(U==0&&Selectors.RegExps.quick.test(T)){K=J.getElementsByTagName(T);
+continue;}var A=B[U-1];var L=Selectors.Utils.parseTagAndID(T);var W=L[0],M=L[1];if(U==0){K=Selectors.Utils.getByTagAndID(J,W,M);}else{var D={},H=[];for(var S=0,R=K.length;
+S<R;S++){H=Selectors.Getters[A](H,K[S],W,M,D);}K=H;}var G=Selectors.Utils.parseSelector(T);if(G){E=[];for(var P=0,N=K.length;P<N;P++){V=K[P];if(Selectors.Utils.filter(V,G,O)){E.push(V);
+}}K=E;}}return K;}};Selectors.Getters={" ":function(H,G,I,A,E){var D=Selectors.Utils.getByTagAndID(G,I,A);for(var C=0,B=D.length;C<B;C++){var F=D[C];if(Selectors.Utils.chk(F,E)){H.push(F);
+}}return H;},">":function(H,G,I,A,F){var C=Selectors.Utils.getByTagAndID(G,I,A);for(var E=0,D=C.length;E<D;E++){var B=C[E];if(B.parentNode==G&&Selectors.Utils.chk(B,F)){H.push(B);
+}}return H;},"+":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(Selectors.Utils.chk(B,D)&&Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
+}break;}}return C;},"~":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(!Selectors.Utils.chk(B,D)){break;}if(Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
+}}}return C;}};Selectors.Filters={byTag:function(B,A){return(A=="*"||(B.tagName&&B.tagName.toLowerCase()==A));},byID:function(A,B){return(!B||(A.id&&A.id==B));
+},byClass:function(B,A){return(B.className&&B.className.contains(A," "));},byPseudo:function(A,D,C,B){return D.call(A,C,B);},byAttribute:function(C,D,B,E){var A=Element.prototype.getProperty.call(C,D);
+if(!A){return false;}if(!B||E==undefined){return true;}switch(B){case"=":return(A==E);case"*=":return(A.contains(E));case"^=":return(A.substr(0,E.length)==E);
+case"$=":return(A.substr(A.length-E.length)==E);case"!=":return(A!=E);case"~=":return A.contains(E," ");case"|=":return A.contains(E,"-");}return false;
+}};Selectors.Pseudo=new Hash({empty:function(){return !(this.innerText||this.textContent||"").length;},not:function(A){return !Element.match(this,A);},contains:function(A){return(this.innerText||this.textContent||"").contains(A);
+},"first-child":function(){return Selectors.Pseudo.index.call(this,0);},"last-child":function(){var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
+}}return true;},"only-child":function(){var B=this;while((B=B.previousSibling)){if(B.nodeType==1){return false;}}var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
+}}return true;},"nth-child":function(G,E){G=(G==undefined)?"n":G;var C=Selectors.Utils.parseNthArgument(G);if(C.special!="n"){return Selectors.Pseudo[C.special].call(this,C.a,E);
+}var F=0;E.positions=E.positions||{};var D=$uid(this);if(!E.positions[D]){var B=this;while((B=B.previousSibling)){if(B.nodeType!=1){continue;}F++;var A=E.positions[$uid(B)];
+if(A!=undefined){F=A+F;break;}}E.positions[D]=F;}return(E.positions[D]%C.a==C.b);},index:function(A){var B=this,C=0;while((B=B.previousSibling)){if(B.nodeType==1&&++C>A){return false;
+}}return(C==A);},even:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n+1",A);},odd:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n",A);
+}});Element.Events.domready={onAdd:function(A){if(Browser.loaded){A.call(this);}}};(function(){var B=function(){if(Browser.loaded){return ;}Browser.loaded=true;
+window.fireEvent("domready");document.fireEvent("domready");};switch(Browser.Engine.name){case"webkit":(function(){(["loaded","complete"].contains(document.readyState))?B():arguments.callee.delay(50);
+})();break;case"trident":var A=document.createElement("div");(function(){($try(function(){A.doScroll("left");return $(A).inject(document.body).set("html","temp").dispose();
+}))?B():arguments.callee.delay(50);})();break;default:window.addEvent("load",B);document.addEvent("DOMContentLoaded",B);}})();var JSON=new Hash({encode:function(B){switch($type(B)){case"string":return'"'+B.replace(/[\x00-\x1f\\"]/g,JSON.$replaceChars)+'"';
+case"array":return"["+String(B.map(JSON.encode).filter($defined))+"]";case"object":case"hash":var A=[];Hash.each(B,function(E,D){var C=JSON.encode(E);if(C){A.push(JSON.encode(D)+":"+C);
+}});return"{"+A+"}";case"number":case"boolean":return String(B);case false:return"null";}return null;},$specialChars:{"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},$replaceChars:function(A){return JSON.$specialChars[A]||"\\u00"+Math.floor(A.charCodeAt()/16).toString(16)+(A.charCodeAt()%16).toString(16);
+},decode:function(string,secure){if($type(string)!="string"||!string.length){return null;}if(secure&&!(/^[,:{}\[\]0-9.\-+Eaeflnr-u \n\r\t]*$/).test(string.replace(/\\./g,"@").replace(/"[^"\\\n\r]*"/g,""))){return null;
+}return eval("("+string+")");}});Native.implement([Hash,Array,String,Number],{toJSON:function(){return JSON.encode(this);}});var Cookie=new Class({Implements:Options,options:{path:false,domain:false,duration:false,secure:false,document:document},initialize:function(B,A){this.key=B;
+this.setOptions(A);},write:function(B){B=encodeURIComponent(B);if(this.options.domain){B+="; domain="+this.options.domain;}if(this.options.path){B+="; path="+this.options.path;
+}if(this.options.duration){var A=new Date();A.setTime(A.getTime()+this.options.duration*24*60*60*1000);B+="; expires="+A.toGMTString();}if(this.options.secure){B+="; secure";
+}this.options.document.cookie=this.key+"="+B;return this;},read:function(){var A=this.options.document.cookie.match("(?:^|;)\\s*"+this.key.escapeRegExp()+"=([^;]*)");
+return(A)?decodeURIComponent(A[1]):null;},dispose:function(){new Cookie(this.key,$merge(this.options,{duration:-1})).write("");return this;}});Cookie.write=function(B,C,A){return new Cookie(B,A).write(C);
+};Cookie.read=function(A){return new Cookie(A).read();};Cookie.dispose=function(B,A){return new Cookie(B,A).dispose();};var Fx=new Class({Implements:[Chain,Events,Options],options:{fps:50,unit:false,duration:500,link:"ignore",transition:function(A){return -(Math.cos(Math.PI*A)-1)/2;
+}},initialize:function(A){this.subject=this.subject||this;this.setOptions(A);this.options.duration=Fx.Durations[this.options.duration]||this.options.duration.toInt();
+var B=this.options.wait;if(B===false){this.options.link="cancel";}},step:function(){var A=$time();if(A<this.time+this.options.duration){var B=this.options.transition((A-this.time)/this.options.duration);
+this.set(this.compute(this.from,this.to,B));}else{this.set(this.compute(this.from,this.to,1));this.complete();}},set:function(A){return A;},compute:function(C,B,A){return Fx.compute(C,B,A);
+},check:function(A){if(!this.timer){return true;}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));
+return false;}return false;},start:function(B,A){if(!this.check(arguments.callee,B,A)){return this;}this.from=B;this.to=A;this.time=0;this.startTimer();
+this.onStart();return this;},complete:function(){if(this.stopTimer()){this.onComplete();}return this;},cancel:function(){if(this.stopTimer()){this.onCancel();
+}return this;},onStart:function(){this.fireEvent("start",this.subject);},onComplete:function(){this.fireEvent("complete",this.subject);if(!this.callChain()){this.fireEvent("chainComplete",this.subject);
+}},onCancel:function(){this.fireEvent("cancel",this.subject).clearChain();},pause:function(){this.stopTimer();return this;},resume:function(){this.startTimer();
+return this;},stopTimer:function(){if(!this.timer){return false;}this.time=$time()-this.time;this.timer=$clear(this.timer);return true;},startTimer:function(){if(this.timer){return false;
+}this.time=$time()-this.time;this.timer=this.step.periodical(Math.round(1000/this.options.fps),this);return true;}});Fx.compute=function(C,B,A){return(B-C)*A+C;
+};Fx.Durations={"short":250,normal:500,"long":1000};Fx.CSS=new Class({Extends:Fx,prepare:function(D,E,B){B=$splat(B);var C=B[1];if(!$chk(C)){B[1]=B[0];
+B[0]=D.getStyle(E);}var A=B.map(this.parse);return{from:A[0],to:A[1]};},parse:function(A){A=$lambda(A)();A=(typeof A=="string")?A.split(" "):$splat(A);
+return A.map(function(C){C=String(C);var B=false;Fx.CSS.Parsers.each(function(F,E){if(B){return ;}var D=F.parse(C);if($chk(D)){B={value:D,parser:F};}});
+B=B||{value:C,parser:Fx.CSS.Parsers.String};return B;});},compute:function(D,C,B){var A=[];(Math.min(D.length,C.length)).times(function(E){A.push({value:D[E].parser.compute(D[E].value,C[E].value,B),parser:D[E].parser});
+});A.$family={name:"fx:css:value"};return A;},serve:function(C,B){if($type(C)!="fx:css:value"){C=this.parse(C);}var A=[];C.each(function(D){A=A.concat(D.parser.serve(D.value,B));
+});return A;},render:function(A,D,C,B){A.setStyle(D,this.serve(C,B));},search:function(A){if(Fx.CSS.Cache[A]){return Fx.CSS.Cache[A];}var B={};Array.each(document.styleSheets,function(E,D){var C=E.href;
+if(C&&C.contains("://")&&!C.contains(document.domain)){return ;}var F=E.rules||E.cssRules;Array.each(F,function(I,G){if(!I.style){return ;}var H=(I.selectorText)?I.selectorText.replace(/^\w+/,function(J){return J.toLowerCase();
+}):null;if(!H||!H.test("^"+A+"$")){return ;}Element.Styles.each(function(K,J){if(!I.style[J]||Element.ShortStyles[J]){return ;}K=String(I.style[J]);B[J]=(K.test(/^rgb/))?K.rgbToHex():K;
+});});});return Fx.CSS.Cache[A]=B;}});Fx.CSS.Cache={};Fx.CSS.Parsers=new Hash({Color:{parse:function(A){if(A.match(/^#[0-9a-f]{3,6}$/i)){return A.hexToRgb(true);
+}return((A=A.match(/(\d+),\s*(\d+),\s*(\d+)/)))?[A[1],A[2],A[3]]:false;},compute:function(C,B,A){return C.map(function(E,D){return Math.round(Fx.compute(C[D],B[D],A));
+});},serve:function(A){return A.map(Number);}},Number:{parse:parseFloat,compute:Fx.compute,serve:function(B,A){return(A)?B+A:B;}},String:{parse:$lambda(false),compute:$arguments(1),serve:$arguments(0)}});
+Fx.Tween=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(B,A){if(arguments.length==1){A=B;
+B=this.property||this.options.property;}this.render(this.element,B,A,this.options.unit);return this;},start:function(C,E,D){if(!this.check(arguments.callee,C,E,D)){return this;
+}var B=Array.flatten(arguments);this.property=this.options.property||B.shift();var A=this.prepare(this.element,this.property,B);return this.parent(A.from,A.to);
+}});Element.Properties.tween={set:function(A){var B=this.retrieve("tween");if(B){B.cancel();}return this.eliminate("tween").store("tween:options",$extend({link:"cancel"},A));
+},get:function(A){if(A||!this.retrieve("tween")){if(A||!this.retrieve("tween:options")){this.set("tween",A);}this.store("tween",new Fx.Tween(this,this.retrieve("tween:options")));
+}return this.retrieve("tween");}};Element.implement({tween:function(A,C,B){this.get("tween").start(arguments);return this;},fade:function(C){var E=this.get("tween"),D="opacity",A;
+C=$pick(C,"toggle");switch(C){case"in":E.start(D,1);break;case"out":E.start(D,0);break;case"show":E.set(D,1);break;case"hide":E.set(D,0);break;case"toggle":var B=this.retrieve("fade:flag",this.get("opacity")==1);
+E.start(D,(B)?0:1);this.store("fade:flag",!B);A=true;break;default:E.start(D,arguments);}if(!A){this.eliminate("fade:flag");}return this;},highlight:function(C,A){if(!A){A=this.retrieve("highlight:original",this.getStyle("background-color"));
+A=(A=="transparent")?"#fff":A;}var B=this.get("tween");B.start("background-color",C||"#ffff88",A).chain(function(){this.setStyle("background-color",this.retrieve("highlight:original"));
+B.callChain();}.bind(this));return this;}});Fx.Morph=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(A){if(typeof A=="string"){A=this.search(A);
+}for(var B in A){this.render(this.element,B,A[B],this.options.unit);}return this;},compute:function(E,D,C){var A={};for(var B in E){A[B]=this.parent(E[B],D[B],C);
+}return A;},start:function(B){if(!this.check(arguments.callee,B)){return this;}if(typeof B=="string"){B=this.search(B);}var E={},D={};for(var C in B){var A=this.prepare(this.element,C,B[C]);
+E[C]=A.from;D[C]=A.to;}return this.parent(E,D);}});Element.Properties.morph={set:function(A){var B=this.retrieve("morph");if(B){B.cancel();}return this.eliminate("morph").store("morph:options",$extend({link:"cancel"},A));
+},get:function(A){if(A||!this.retrieve("morph")){if(A||!this.retrieve("morph:options")){this.set("morph",A);}this.store("morph",new Fx.Morph(this,this.retrieve("morph:options")));
+}return this.retrieve("morph");}};Element.implement({morph:function(A){this.get("morph").start(A);return this;}});(function(){var A=Fx.prototype.initialize;
+Fx.prototype.initialize=function(B){A.call(this,B);var C=this.options.transition;if(typeof C=="string"&&(C=C.split(":"))){var D=Fx.Transitions;D=D[C[0]]||D[C[0].capitalize()];
+if(C[1]){D=D["ease"+C[1].capitalize()+(C[2]?C[2].capitalize():"")];}this.options.transition=D;}};})();Fx.Transition=function(B,A){A=$splat(A);return $extend(B,{easeIn:function(C){return B(C,A);
+},easeOut:function(C){return 1-B(1-C,A);},easeInOut:function(C){return(C<=0.5)?B(2*C,A)/2:(2-B(2*(1-C),A))/2;}});};Fx.Transitions=new Hash({linear:$arguments(0)});
+Fx.Transitions.extend=function(A){for(var B in A){Fx.Transitions[B]=new Fx.Transition(A[B]);}};Fx.Transitions.extend({Pow:function(B,A){return Math.pow(B,A[0]||6);
+},Expo:function(A){return Math.pow(2,8*(A-1));},Circ:function(A){return 1-Math.sin(Math.acos(A));},Sine:function(A){return 1-Math.sin((1-A)*Math.PI/2);
+},Back:function(B,A){A=A[0]||1.618;return Math.pow(B,2)*((A+1)*B-A);},Bounce:function(D){var C;for(var B=0,A=1;1;B+=A,A/=2){if(D>=(7-4*B)/11){C=-Math.pow((11-6*B-11*D)/4,2)+A*A;
+break;}}return C;},Elastic:function(B,A){return Math.pow(2,10*--B)*Math.cos(20*B*Math.PI*(A[0]||1)/3);}});["Quad","Cubic","Quart","Quint"].each(function(B,A){Fx.Transitions[B]=new Fx.Transition(function(C){return Math.pow(C,[A+2]);
+});});var Request=new Class({Implements:[Chain,Events,Options],options:{url:"",data:"",headers:{"X-Requested-With":"XMLHttpRequest",Accept:"text/javascript, text/html, application/xml, text/xml, */*"},async:true,format:false,method:"post",link:"ignore",isSuccess:null,emulation:true,urlEncoded:true,encoding:"utf-8",evalScripts:false,evalResponse:false},initialize:function(A){this.xhr=new Browser.Request();
+this.setOptions(A);this.options.isSuccess=this.options.isSuccess||this.isSuccess;this.headers=new Hash(this.options.headers);},onStateChange:function(){if(this.xhr.readyState!=4||!this.running){return ;
+}this.running=false;this.status=0;$try(function(){this.status=this.xhr.status;}.bind(this));if(this.options.isSuccess.call(this,this.status)){this.response={text:this.xhr.responseText,xml:this.xhr.responseXML};
+this.success(this.response.text,this.response.xml);}else{this.response={text:null,xml:null};this.failure();}this.xhr.onreadystatechange=$empty;},isSuccess:function(){return((this.status>=200)&&(this.status<300));
+},processScripts:function(A){if(this.options.evalResponse||(/(ecma|java)script/).test(this.getHeader("Content-type"))){return $exec(A);}return A.stripScripts(this.options.evalScripts);
+},success:function(B,A){this.onSuccess(this.processScripts(B),A);},onSuccess:function(){this.fireEvent("complete",arguments).fireEvent("success",arguments).callChain();
+},failure:function(){this.onFailure();},onFailure:function(){this.fireEvent("complete").fireEvent("failure",this.xhr);},setHeader:function(A,B){this.headers.set(A,B);
+return this;},getHeader:function(A){return $try(function(){return this.xhr.getResponseHeader(A);}.bind(this));},check:function(A){if(!this.running){return true;
+}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));return false;}return false;
+},send:function(I){if(!this.check(arguments.callee,I)){return this;}this.running=true;var G=$type(I);if(G=="string"||G=="element"){I={data:I};}var D=this.options;
+I=$extend({data:D.data,url:D.url,method:D.method},I);var E=I.data,B=I.url,A=I.method;switch($type(E)){case"element":E=$(E).toQueryString();break;case"object":case"hash":E=Hash.toQueryString(E);
+}if(this.options.format){var H="format="+this.options.format;E=(E)?H+"&"+E:H;}if(this.options.emulation&&["put","delete"].contains(A)){var F="_method="+A;
+E=(E)?F+"&"+E:F;A="post";}if(this.options.urlEncoded&&A=="post"){var C=(this.options.encoding)?"; charset="+this.options.encoding:"";this.headers.set("Content-type","application/x-www-form-urlencoded"+C);
+}if(E&&A=="get"){B=B+(B.contains("?")?"&":"?")+E;E=null;}this.xhr.open(A.toUpperCase(),B,this.options.async);this.xhr.onreadystatechange=this.onStateChange.bind(this);
+this.headers.each(function(K,J){if(!$try(function(){this.xhr.setRequestHeader(J,K);return true;}.bind(this))){this.fireEvent("exception",[J,K]);}},this);
+this.fireEvent("request");this.xhr.send(E);if(!this.options.async){this.onStateChange();}return this;},cancel:function(){if(!this.running){return this;
+}this.running=false;this.xhr.abort();this.xhr.onreadystatechange=$empty;this.xhr=new Browser.Request();this.fireEvent("cancel");return this;}});(function(){var A={};
+["get","post","put","delete","GET","POST","PUT","DELETE"].each(function(B){A[B]=function(){var C=Array.link(arguments,{url:String.type,data:$defined});
+return this.send($extend(C,{method:B.toLowerCase()}));};});Request.implement(A);})();Element.Properties.send={set:function(A){var B=this.retrieve("send");
+if(B){B.cancel();}return this.eliminate("send").store("send:options",$extend({data:this,link:"cancel",method:this.get("method")||"post",url:this.get("action")},A));
+},get:function(A){if(A||!this.retrieve("send")){if(A||!this.retrieve("send:options")){this.set("send",A);}this.store("send",new Request(this.retrieve("send:options")));
+}return this.retrieve("send");}};Element.implement({send:function(A){var B=this.get("send");B.send({data:this,url:A||B.options.url});return this;}});Request.HTML=new Class({Extends:Request,options:{update:false,evalScripts:true,filter:false},processHTML:function(C){var B=C.match(/<body[^>]*>([\s\S]*?)<\/body>/i);
+C=(B)?B[1]:C;var A=new Element("div");return $try(function(){var D="<root>"+C+"</root>",G;if(Browser.Engine.trident){G=new ActiveXObject("Microsoft.XMLDOM");
+G.async=false;G.loadXML(D);}else{G=new DOMParser().parseFromString(D,"text/xml");}D=G.getElementsByTagName("root")[0];for(var F=0,E=D.childNodes.length;
+F<E;F++){var H=Element.clone(D.childNodes[F],true,true);if(H){A.grab(H);}}return A;})||A.set("html",C);},success:function(D){var C=this.options,B=this.response;
+B.html=D.stripScripts(function(E){B.javascript=E;});var A=this.processHTML(B.html);B.tree=A.childNodes;B.elements=A.getElements("*");if(C.filter){B.tree=B.elements.filter(C.filter);
+}if(C.update){$(C.update).empty().adopt(B.tree);}if(C.evalScripts){$exec(B.javascript);}this.onSuccess(B.tree,B.elements,B.html,B.javascript);}});Element.Properties.load={set:function(A){var B=this.retrieve("load");
+if(B){send.cancel();}return this.eliminate("load").store("load:options",$extend({data:this,link:"cancel",update:this,method:"get"},A));},get:function(A){if(A||!this.retrieve("load")){if(A||!this.retrieve("load:options")){this.set("load",A);
+}this.store("load",new Request.HTML(this.retrieve("load:options")));}return this.retrieve("load");}};Element.implement({load:function(){this.get("load").send(Array.link(arguments,{data:Object.type,url:String.type}));
+return this;}});Request.JSON=new Class({Extends:Request,options:{secure:true},initialize:function(A){this.parent(A);this.headers.extend({Accept:"application/json","X-Request":"JSON"});
+},success:function(A){this.response.json=JSON.decode(A,this.options.secure);this.onSuccess(this.response.json,A);}});
\ No newline at end of file

=== added file 'loggerhead/static/javascript/mootools-1.2-more.js'
--- loggerhead/static/javascript/mootools-1.2-more.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/mootools-1.2-more.js	2008-06-18 07:49:45 +0000
@@ -0,0 +1,97 @@
+//MooTools More, <http://mootools.net/more>. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
+
+Fx.Slide=new Class({Extends:Fx,options:{mode:"vertical"},initialize:function(B,A){this.addEvent("complete",function(){this.open=(this.wrapper["offset"+this.layout.capitalize()]!=0);
+if(this.open&&Browser.Engine.webkit419){this.element.dispose().inject(this.wrapper);}},true);this.element=this.subject=$(B);this.parent(A);var C=this.element.retrieve("wrapper");
+this.wrapper=C||new Element("div",{styles:$extend(this.element.getStyles("margin","position"),{overflow:"hidden"})}).wraps(this.element);this.element.store("wrapper",this.wrapper).setStyle("margin",0);
+this.now=[];this.open=true;},vertical:function(){this.margin="margin-top";this.layout="height";this.offset=this.element.offsetHeight;},horizontal:function(){this.margin="margin-left";
+this.layout="width";this.offset=this.element.offsetWidth;},set:function(A){this.element.setStyle(this.margin,A[0]);this.wrapper.setStyle(this.layout,A[1]);
+return this;},compute:function(E,D,C){var B=[];var A=2;A.times(function(F){B[F]=Fx.compute(E[F],D[F],C);});return B;},start:function(B,E){if(!this.check(arguments.callee,B,E)){return this;
+}this[E||this.options.mode]();var D=this.element.getStyle(this.margin).toInt();var C=this.wrapper.getStyle(this.layout).toInt();var A=[[D,C],[0,this.offset]];
+var G=[[D,C],[-this.offset,0]];var F;switch(B){case"in":F=A;break;case"out":F=G;break;case"toggle":F=(this.wrapper["offset"+this.layout.capitalize()]==0)?A:G;
+}return this.parent(F[0],F[1]);},slideIn:function(A){return this.start("in",A);},slideOut:function(A){return this.start("out",A);},hide:function(A){this[A||this.options.mode]();
+this.open=false;return this.set([-this.offset,0]);},show:function(A){this[A||this.options.mode]();this.open=true;return this.set([0,this.offset]);},toggle:function(A){return this.start("toggle",A);
+}});Element.Properties.slide={set:function(B){var A=this.retrieve("slide");if(A){A.cancel();}return this.eliminate("slide").store("slide:options",$extend({link:"cancel"},B));
+},get:function(A){if(A||!this.retrieve("slide")){if(A||!this.retrieve("slide:options")){this.set("slide",A);}this.store("slide",new Fx.Slide(this,this.retrieve("slide:options")));
+}return this.retrieve("slide");}};Element.implement({slide:function(D,E){D=D||"toggle";var B=this.get("slide"),A;switch(D){case"hide":B.hide(E);break;case"show":B.show(E);
+break;case"toggle":var C=this.retrieve("slide:flag",B.open);B[(C)?"slideOut":"slideIn"](E);this.store("slide:flag",!C);A=true;break;default:B.start(D,E);
+}if(!A){this.eliminate("slide:flag");}return this;}});Fx.Elements=new Class({Extends:Fx.CSS,initialize:function(B,A){this.elements=this.subject=$$(B);this.parent(A);
+},compute:function(G,H,I){var C={};for(var D in G){var A=G[D],E=H[D],F=C[D]={};for(var B in A){F[B]=this.parent(A[B],E[B],I);}}return C;},set:function(B){for(var C in B){var A=B[C];
+for(var D in A){this.render(this.elements[C],D,A[D],this.options.unit);}}return this;},start:function(C){if(!this.check(arguments.callee,C)){return this;
+}var H={},I={};for(var D in C){var F=C[D],A=H[D]={},G=I[D]={};for(var B in F){var E=this.prepare(this.elements[D],B,F[B]);A[B]=E.from;G[B]=E.to;}}return this.parent(H,I);
+}});var Drag=new Class({Implements:[Events,Options],options:{snap:6,unit:"px",grid:false,style:true,limit:false,handle:false,invert:false,preventDefault:false,modifiers:{x:"left",y:"top"}},initialize:function(){var B=Array.link(arguments,{options:Object.type,element:$defined});
+this.element=$(B.element);this.document=this.element.getDocument();this.setOptions(B.options||{});var A=$type(this.options.handle);this.handles=(A=="array"||A=="collection")?$$(this.options.handle):$(this.options.handle)||this.element;
+this.mouse={now:{},pos:{}};this.value={start:{},now:{}};this.selection=(Browser.Engine.trident)?"selectstart":"mousedown";this.bound={start:this.start.bind(this),check:this.check.bind(this),drag:this.drag.bind(this),stop:this.stop.bind(this),cancel:this.cancel.bind(this),eventStop:$lambda(false)};
+this.attach();},attach:function(){this.handles.addEvent("mousedown",this.bound.start);return this;},detach:function(){this.handles.removeEvent("mousedown",this.bound.start);
+return this;},start:function(C){if(this.options.preventDefault){C.preventDefault();}this.fireEvent("beforeStart",this.element);this.mouse.start=C.page;
+var A=this.options.limit;this.limit={x:[],y:[]};for(var D in this.options.modifiers){if(!this.options.modifiers[D]){continue;}if(this.options.style){this.value.now[D]=this.element.getStyle(this.options.modifiers[D]).toInt();
+}else{this.value.now[D]=this.element[this.options.modifiers[D]];}if(this.options.invert){this.value.now[D]*=-1;}this.mouse.pos[D]=C.page[D]-this.value.now[D];
+if(A&&A[D]){for(var B=2;B--;B){if($chk(A[D][B])){this.limit[D][B]=$lambda(A[D][B])();}}}}if($type(this.options.grid)=="number"){this.options.grid={x:this.options.grid,y:this.options.grid};
+}this.document.addEvents({mousemove:this.bound.check,mouseup:this.bound.cancel});this.document.addEvent(this.selection,this.bound.eventStop);},check:function(A){if(this.options.preventDefault){A.preventDefault();
+}var B=Math.round(Math.sqrt(Math.pow(A.page.x-this.mouse.start.x,2)+Math.pow(A.page.y-this.mouse.start.y,2)));if(B>this.options.snap){this.cancel();this.document.addEvents({mousemove:this.bound.drag,mouseup:this.bound.stop});
+this.fireEvent("start",this.element).fireEvent("snap",this.element);}},drag:function(A){if(this.options.preventDefault){A.preventDefault();}this.mouse.now=A.page;
+for(var B in this.options.modifiers){if(!this.options.modifiers[B]){continue;}this.value.now[B]=this.mouse.now[B]-this.mouse.pos[B];if(this.options.invert){this.value.now[B]*=-1;
+}if(this.options.limit&&this.limit[B]){if($chk(this.limit[B][1])&&(this.value.now[B]>this.limit[B][1])){this.value.now[B]=this.limit[B][1];}else{if($chk(this.limit[B][0])&&(this.value.now[B]<this.limit[B][0])){this.value.now[B]=this.limit[B][0];
+}}}if(this.options.grid[B]){this.value.now[B]-=(this.value.now[B]%this.options.grid[B]);}if(this.options.style){this.element.setStyle(this.options.modifiers[B],this.value.now[B]+this.options.unit);
+}else{this.element[this.options.modifiers[B]]=this.value.now[B];}}this.fireEvent("drag",this.element);},cancel:function(A){this.document.removeEvent("mousemove",this.bound.check);
+this.document.removeEvent("mouseup",this.bound.cancel);if(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.fireEvent("cancel",this.element);
+}},stop:function(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.document.removeEvent("mousemove",this.bound.drag);this.document.removeEvent("mouseup",this.bound.stop);
+if(A){this.fireEvent("complete",this.element);}}});Element.implement({makeResizable:function(A){return new Drag(this,$merge({modifiers:{x:"width",y:"height"}},A));
+}});Hash.Cookie=new Class({Extends:Cookie,options:{autoSave:true},initialize:function(B,A){this.parent(B,A);this.load();},save:function(){var A=JSON.encode(this.hash);
+if(!A||A.length>4096){return false;}if(A=="{}"){this.dispose();}else{this.write(A);}return true;},load:function(){this.hash=new Hash(JSON.decode(this.read(),true));
+return this;}});Hash.Cookie.implement((function(){var A={};Hash.each(Hash.prototype,function(C,B){A[B]=function(){var D=C.apply(this.hash,arguments);if(this.options.autoSave){this.save();
+}return D;};});return A;})());var Color=new Native({initialize:function(B,C){if(arguments.length>=3){C="rgb";B=Array.slice(arguments,0,3);}else{if(typeof B=="string"){if(B.match(/rgb/)){B=B.rgbToHex().hexToRgb(true);
+}else{if(B.match(/hsb/)){B=B.hsbToRgb();}else{B=B.hexToRgb(true);}}}}C=C||"rgb";switch(C){case"hsb":var A=B;B=B.hsbToRgb();B.hsb=A;break;case"hex":B=B.hexToRgb(true);
+break;}B.rgb=B.slice(0,3);B.hsb=B.hsb||B.rgbToHsb();B.hex=B.rgbToHex();return $extend(B,this);}});Color.implement({mix:function(){var A=Array.slice(arguments);
+var C=($type(A.getLast())=="number")?A.pop():50;var B=this.slice();A.each(function(D){D=new Color(D);for(var E=0;E<3;E++){B[E]=Math.round((B[E]/100*(100-C))+(D[E]/100*C));
+}});return new Color(B,"rgb");},invert:function(){return new Color(this.map(function(A){return 255-A;}));},setHue:function(A){return new Color([A,this.hsb[1],this.hsb[2]],"hsb");
+},setSaturation:function(A){return new Color([this.hsb[0],A,this.hsb[2]],"hsb");},setBrightness:function(A){return new Color([this.hsb[0],this.hsb[1],A],"hsb");
+}});function $RGB(C,B,A){return new Color([C,B,A],"rgb");}function $HSB(C,B,A){return new Color([C,B,A],"hsb");}function $HEX(A){return new Color(A,"hex");
+}Array.implement({rgbToHsb:function(){var B=this[0],C=this[1],J=this[2];var G,F,H;var I=Math.max(B,C,J),E=Math.min(B,C,J);var K=I-E;H=I/255;F=(I!=0)?K/I:0;
+if(F==0){G=0;}else{var D=(I-B)/K;var A=(I-C)/K;var L=(I-J)/K;if(B==I){G=L-A;}else{if(C==I){G=2+D-L;}else{G=4+A-D;}}G/=6;if(G<0){G++;}}return[Math.round(G*360),Math.round(F*100),Math.round(H*100)];
+},hsbToRgb:function(){var C=Math.round(this[2]/100*255);if(this[1]==0){return[C,C,C];}else{var A=this[0]%360;var E=A%60;var F=Math.round((this[2]*(100-this[1]))/10000*255);
+var D=Math.round((this[2]*(6000-this[1]*E))/600000*255);var B=Math.round((this[2]*(6000-this[1]*(60-E)))/600000*255);switch(Math.floor(A/60)){case 0:return[C,B,F];
+case 1:return[D,C,F];case 2:return[F,C,B];case 3:return[F,D,C];case 4:return[B,F,C];case 5:return[C,F,D];}}return false;}});String.implement({rgbToHsb:function(){var A=this.match(/\d{1,3}/g);
+return(A)?hsb.rgbToHsb():null;},hsbToRgb:function(){var A=this.match(/\d{1,3}/g);return(A)?A.hsbToRgb():null;}});var Group=new Class({initialize:function(){this.instances=Array.flatten(arguments);
+this.events={};this.checker={};},addEvent:function(B,A){this.checker[B]=this.checker[B]||{};this.events[B]=this.events[B]||[];if(this.events[B].contains(A)){return false;
+}else{this.events[B].push(A);}this.instances.each(function(C,D){C.addEvent(B,this.check.bind(this,[B,C,D]));},this);return this;},check:function(C,A,B){this.checker[C][B]=true;
+var D=this.instances.every(function(F,E){return this.checker[C][E]||false;},this);if(!D){return ;}this.checker[C]={};this.events[C].each(function(E){E.call(this,this.instances,A);
+},this);}});var Asset=new Hash({javascript:function(F,D){D=$extend({onload:$empty,document:document,check:$lambda(true)},D);var B=new Element("script",{src:F,type:"text/javascript"});
+var E=D.onload.bind(B),A=D.check,G=D.document;delete D.onload;delete D.check;delete D.document;B.addEvents({load:E,readystatechange:function(){if(["loaded","complete"].contains(this.readyState)){E();
+}}}).setProperties(D);if(Browser.Engine.webkit419){var C=(function(){if(!$try(A)){return ;}$clear(C);E();}).periodical(50);}return B.inject(G.head);},css:function(B,A){return new Element("link",$merge({rel:"stylesheet",media:"screen",type:"text/css",href:B},A)).inject(document.head);
+},image:function(C,B){B=$merge({onload:$empty,onabort:$empty,onerror:$empty},B);var D=new Image();var A=$(D)||new Element("img");["load","abort","error"].each(function(E){var F="on"+E;
+var G=B[F];delete B[F];D[F]=function(){if(!D){return ;}if(!A.parentNode){A.width=D.width;A.height=D.height;}D=D.onload=D.onabort=D.onerror=null;G.delay(1,A,A);
+A.fireEvent(E,A,1);};});D.src=A.src=C;if(D&&D.complete){D.onload.delay(1);}return A.setProperties(B);},images:function(D,C){C=$merge({onComplete:$empty,onProgress:$empty},C);
+if(!D.push){D=[D];}var A=[];var B=0;D.each(function(F){var E=new Asset.image(F,{onload:function(){C.onProgress.call(this,B,D.indexOf(F));B++;if(B==D.length){C.onComplete();
+}}});A.push(E);});return new Elements(A);}});var Tips=new Class({Implements:[Events,Options],options:{onShow:function(A){A.setStyle("visibility","visible");
+},onHide:function(A){A.setStyle("visibility","hidden");},showDelay:100,hideDelay:100,className:null,offsets:{x:16,y:16},fixed:false},initialize:function(){var C=Array.link(arguments,{options:Object.type,elements:$defined});
+this.setOptions(C.options||null);this.tip=new Element("div").inject(document.body);if(this.options.className){this.tip.addClass(this.options.className);
+}var B=new Element("div",{"class":"tip-top"}).inject(this.tip);this.container=new Element("div",{"class":"tip"}).inject(this.tip);var A=new Element("div",{"class":"tip-bottom"}).inject(this.tip);
+this.tip.setStyles({position:"absolute",top:0,left:0,visibility:"hidden"});if(C.elements){this.attach(C.elements);}},attach:function(A){$$(A).each(function(D){var G=D.retrieve("tip:title",D.get("title"));
+var F=D.retrieve("tip:text",D.get("rel")||D.get("href"));var E=D.retrieve("tip:enter",this.elementEnter.bindWithEvent(this,D));var C=D.retrieve("tip:leave",this.elementLeave.bindWithEvent(this,D));
+D.addEvents({mouseenter:E,mouseleave:C});if(!this.options.fixed){var B=D.retrieve("tip:move",this.elementMove.bindWithEvent(this,D));D.addEvent("mousemove",B);
+}D.store("tip:native",D.get("title"));D.erase("title");},this);return this;},detach:function(A){$$(A).each(function(C){C.removeEvent("mouseenter",C.retrieve("tip:enter")||$empty);
+C.removeEvent("mouseleave",C.retrieve("tip:leave")||$empty);C.removeEvent("mousemove",C.retrieve("tip:move")||$empty);C.eliminate("tip:enter").eliminate("tip:leave").eliminate("tip:move");
+var B=C.retrieve("tip:native");if(B){C.set("title",B);}});return this;},elementEnter:function(B,A){$A(this.container.childNodes).each(Element.dispose);
+var D=A.retrieve("tip:title");if(D){this.titleElement=new Element("div",{"class":"tip-title"}).inject(this.container);this.fill(this.titleElement,D);}var C=A.retrieve("tip:text");
+if(C){this.textElement=new Element("div",{"class":"tip-text"}).inject(this.container);this.fill(this.textElement,C);}this.timer=$clear(this.timer);this.timer=this.show.delay(this.options.showDelay,this);
+this.position((!this.options.fixed)?B:{page:A.getPosition()});},elementLeave:function(A){$clear(this.timer);this.timer=this.hide.delay(this.options.hideDelay,this);
+},elementMove:function(A){this.position(A);},position:function(D){var B=window.getSize(),A=window.getScroll();var E={x:this.tip.offsetWidth,y:this.tip.offsetHeight};
+var C={x:"left",y:"top"};for(var F in C){var G=D.page[F]+this.options.offsets[F];if((G+E[F]-A[F])>B[F]){G=D.page[F]-this.options.offsets[F]-E[F];}this.tip.setStyle(C[F],G);
+}},fill:function(A,B){(typeof B=="string")?A.set("html",B):A.adopt(B);},show:function(){this.fireEvent("show",this.tip);},hide:function(){this.fireEvent("hide",this.tip);
+}});var Slider=new Class({Implements:[Events,Options],options:{onTick:function(A){if(this.options.snap){A=this.toPosition(this.step);}this.knob.setStyle(this.property,A);
+},snap:false,offset:0,range:false,wheel:false,steps:100,mode:"horizontal"},initialize:function(E,A,D){this.setOptions(D);this.element=$(E);this.knob=$(A);
+this.previousChange=this.previousEnd=this.step=-1;this.element.addEvent("mousedown",this.clickedElement.bind(this));if(this.options.wheel){this.element.addEvent("mousewheel",this.scrolledElement.bindWithEvent(this));
+}var F,B={},C={x:false,y:false};switch(this.options.mode){case"vertical":this.axis="y";this.property="top";F="offsetHeight";break;case"horizontal":this.axis="x";
+this.property="left";F="offsetWidth";}this.half=this.knob[F]/2;this.full=this.element[F]-this.knob[F]+(this.options.offset*2);this.min=$chk(this.options.range[0])?this.options.range[0]:0;
+this.max=$chk(this.options.range[1])?this.options.range[1]:this.options.steps;this.range=this.max-this.min;this.steps=this.options.steps||this.full;this.stepSize=Math.abs(this.range)/this.steps;
+this.stepWidth=this.stepSize*this.full/Math.abs(this.range);this.knob.setStyle("position","relative").setStyle(this.property,-this.options.offset);C[this.axis]=this.property;
+B[this.axis]=[-this.options.offset,this.full-this.options.offset];this.drag=new Drag(this.knob,{snap:0,limit:B,modifiers:C,onDrag:this.draggedKnob.bind(this),onStart:this.draggedKnob.bind(this),onComplete:function(){this.draggedKnob();
+this.end();}.bind(this)});if(this.options.snap){this.drag.options.grid=Math.ceil(this.stepWidth);this.drag.options.limit[this.axis][1]=this.full;}},set:function(A){if(!((this.range>0)^(A<this.min))){A=this.min;
+}if(!((this.range>0)^(A>this.max))){A=this.max;}this.step=Math.round(A);this.checkStep();this.end();this.fireEvent("tick",this.toPosition(this.step));return this;
+},clickedElement:function(C){var B=this.range<0?-1:1;var A=C.page[this.axis]-this.element.getPosition()[this.axis]-this.half;A=A.limit(-this.options.offset,this.full-this.options.offset);
+this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();this.end();this.fireEvent("tick",A);},scrolledElement:function(A){var B=(this.options.mode=="horizontal")?(A.wheel<0):(A.wheel>0);
+this.set(B?this.step-this.stepSize:this.step+this.stepSize);A.stop();},draggedKnob:function(){var B=this.range<0?-1:1;var A=this.drag.value.now[this.axis];
+A=A.limit(-this.options.offset,this.full-this.options.offset);this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();},checkStep:function(){if(this.previousChange!=this.step){this.previousChange=this.step;
+this.fireEvent("change",this.step);}},end:function(){if(this.previousEnd!==this.step){this.previousEnd=this.step;this.fireEvent("complete",this.step+"");
+}},toStep:function(A){var B=(A+this.options.offset)*this.stepSize/this.full*this.steps;return this.options.steps?Math.round(B-=B%this.stepSize):B;},toPosition:function(A){return(this.full*Math.abs(this.min-A))/(this.steps*this.stepSize)-this.options.offset;
+}});
\ No newline at end of file

=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2008-06-18 08:42:36 +0000
+++ loggerhead/templates/annotate.pt	2008-06-23 19:22:49 +0000
@@ -6,60 +6,53 @@
            tal:content="string:${branch/friendly_name} : contents of ${path}
                         at revision ${change/revno}">
     </title>
+    <metal:block fill-slot="header_extras">
+        <link rel="stylesheet" type="text/css" media="all"
+              tal:attributes="href python:branch.static_url('/static/css/annotate.css')"/>
+    </metal:block>
   </head>
 
   <body>
 
     <h1 metal:fill-slot="heading">
-      <span class="branch-name" tal:content="branch/friendly_name"></span>
-      :
-      <span class="annotate-path" tal:content="path"></span>
-      (revision <tal:revno content="change/revno"></tal:revno>)
+        <tal:block content="branch/friendly_name"></tal:block>
+        <span>: <span tal:content="path"></span> (revision <tal:revno content="change/revno"></tal:revno>)</span>
     </h1>
 
     <div metal:fill-slot="content">
-      <div class="links">
-        <div>
-          <b>&#8594;</b>
-          <a tal:attributes="href python:url(['/files', change.revno], clear=1)">browse files</a>
-        </div>
-        <div>
-          <b>&#8594;</b>
-          <a tal:attributes="href python:url(['/revision'], clear=1, start_revid=change.revno)">view revision</a>
-        </div>
-        <div>
-          <b>&#8594;</b>
-          <a tal:attributes="href python:url(['/changes'], clear=1, start_revid=change.revno, filter_file_id=file_id)">view changes to this file</a>
-        </div>
-        <div>
-          <b>&#8594;</b>
-          <a tal:attributes="href python:url(['/download', change.revno, file_id, filename])">download file</a>
-        </div>
-      </div>
+        <ul id="submenuTabs">
+            <li id="inicio">
+                <a tal:attributes="href python:url(['/files', change.revno], clear=1)">browse files</a>
+            </li>
+            <li>
+                <a tal:attributes="href python:url(['/revision'], clear=1, start_revid=change.revno)">view revision</a>
+            </li>
+            <li>
+                <a tal:attributes="href python:url(['/changes'], clear=1, start_revid=change.revno, filter_file_id=file_id)">view changes to this file</a>
+            </li>
+            <li id="final">
+                <a tal:attributes="href python:url(['/download', change.revno, file_id, filename])">download file</a>
+            </li>
+        </ul>
 
       <div class="annotate">
-        <table>
-          <tr>
-            <th class="lineno"> Line# </th>
-            <th class="revision"> Revision </th>
-            <th class="text"> Contents </th>
+        <table id="logentries">
+          <tr class="logheader">
+            <td class="annoLineTit">Line</td>
+            <td class="annoRevTit">Revision</td>            
+            <td class="annoContTit">Contents</td>                    
           </tr>
 
-          <tr tal:repeat="line contents"
-              tal:attributes="class string:parity${line/parity}">
-            <td tal:attributes="class string:lineno ${line/status}">
-              <a tal:attributes="name string:L${line/lineno}"
-                 tal:content="line/lineno"></a>
-            </td>
-            <td tal:attributes="class string:revno ${line/status}">
+          <tr tal:repeat="line contents" 
+              tal:attributes="class string:blueRow${line/parity}">
+            <td class="annoLine" tal:content="line/lineno">1</td>
+            <td class="annoRev">
               <a tal:condition="python:line.status=='changed'"
                  tal:content="python:util.trunc(line.change.revno)"
                  tal:attributes="href python:url(['/revision'], clear=1, start_revid=line.change.revno, filter_file_id=file_id);
                                  title python:'%s by %s, on %s (%s)'%(line.change.revno, util.hide_email(line.change.author), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
             </td>
-            <td tal:attributes="class string:text ${line/status}"
-                tal:content="line/text">
-            </td>
+            <td class="annoCont" tal:content="line/text"></td>
           </tr>
         </table>
       </div>

=== modified file 'loggerhead/templates/atom.pt'
--- loggerhead/templates/atom.pt	2008-06-11 04:41:08 +0000
+++ loggerhead/templates/atom.pt	2008-06-26 20:42:15 +0000
@@ -4,7 +4,7 @@
     bazaar changes for <tal:branch-name content="branch/friendly_name">branch name</tal:branch-name>
   </title>
   <updated tal:content="updated">${updated}</updated>
-  <id tal:content="python:branch.url(['atom'])">url</id>
+  <id tal:content="python:branch.url(['/atom'])">url</id>
   <link rel="self" tal:attributes="href python:branch.url([''])" />
 
   <entry tal:repeat="entry changes">
@@ -14,7 +14,7 @@
     <updated tal:content="entry/date/isoformat">
     Z
     </updated>
-    <id tal:content="python:branch.url(['revision', entry.revno])">
+    <id tal:content="python:branch.url(['/revision', entry.revno])">
       ID
     </id>
     <author>
@@ -26,6 +26,6 @@
       comment
     </content>
     <link rel="alternate"
-          tal:attributes="href python:branch.url(['revision', entry.revno])" />
+          tal:attributes="href python:branch.url(['/revision', entry.revno])" />
   </entry>
 </feed>

=== modified file 'loggerhead/templates/browse.pt'
--- loggerhead/templates/browse.pt	2008-06-18 04:16:21 +0000
+++ loggerhead/templates/browse.pt	2008-07-01 03:28:31 +0000
@@ -45,7 +45,7 @@
               </th>
               <th />
             </tr>
-            <tal:block repeat="view project/views">
+            <tal:block repeat="view python:views_by_project[project]">
               <tr>
                 <td class="name">
                   <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name)"
@@ -58,7 +58,7 @@
                   ${view.description}
                 </td>
                 <td class="last-update"
-                    tal:content="python:view.history.has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'"></td>
+                    tal:content="python:view.get_history().has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'"></td>
                 <td class="feed">
                   <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name + '/atom')"
                      title="atom feed">

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2008-06-20 02:20:05 +0000
+++ loggerhead/templates/changelog.pt	2008-07-22 00:40:03 +0000
@@ -3,28 +3,19 @@
   <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
     <head>
       <title metal:fill-slot="title"
-             tal:content="string:${branch/friendly_name} : changes">
-        ${branch.friendly_name} : changes
-      </title>
+             tal:content="string:${branch/friendly_name} : changes"></title>
       <metal:block fill-slot="header_extras">
         <link rel="alternate" type="application/atom+xml"
               tal:attributes="href python:url(['/atom']);
-                              title string:RSS feed for ${branch/friendly_name}"
-              />
-
-        <script type="text/javascript"
-                tal:attributes="src python:branch.static_url('/static/javascript/collapse.js')">
-        </script>
+                              title string:RSS feed for ${branch/friendly_name}" />
       </metal:block>
     </head>
 
     <body>
+        <tal:block metal:fill-slot="heading">
+        <h1><tal:block content="branch/friendly_name"></tal:block></h1>
+        </tal:block>
 
-      <h1 style="margin-bottom: 1em" metal:fill-slot="heading">
-        <span class="branch-name" tal:content="branch/friendly_name">
-          ${branch.friendly_name}
-        </span>
-        : changes
         <tal:block condition="filter_file_id">
           to
           <span class="filename"
@@ -37,10 +28,9 @@
         <tal:block condition="query">
           matching <tal:block content="query" />
         </tal:block>
-      </h1>
-
-      <div metal:fill-slot="content">
-
+
+       <div metal:fill-slot="content">
+           <!-- Something nicer-looking should be done with search -->
         <p tal:condition="search_failed">
           Sorry, no results found for your search.
         </p>
@@ -49,143 +39,122 @@
           No revisions!
         </p>
 
-        <p tal:condition="changes"
-           class="changelog">
-          <tal:b content="structure python:collapse_all_button('cl', branch)" />
-        </p>
-
-        <table class="log-entries"
+        <p class="fr revnolink">Revision <a tal:attributes="href #
+                                                            title python:'Show revision '+history.get_revno(revid)" 
+                                            tal:content="python:history.get_revno(revid)"></a> to 
+                                         <a tal:attributes="href # 
+                                                            title 'Show revision '+history.get_revno(navigation.last_in_page_revid)"
+                                            tal:content="python:history.get_revno(navigation.last_in_page_revid)"></a></p>
+        <p class="expand" id="expand_all"><a tal:attributes="href string:javascript:toggle_expand_all('open')">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+                  alt="expand all" /> expand all</a>
+        </p>
+        <p class="expand" id="collapse_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all('close')">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+                  alt="collapse all" /> collapse all</a>
+        </p>
+        <!-- Table -->        
+        <table id="logentries"
                tal:define="subcolspan python:4-bool(all_same_author)">
-          <tr class="log-header">
-            <th class="revision-number">
-              Rev
-            </th>
-            <th>
-            </th>
-            <th class="summary">
-              Summary
-            </th>
-            <th tal:condition="not:all_same_author"
-                class="author">
-              Committer
-            </th>
-            <th class="date" colspan="2">
-              Date
-            </th>
-          </tr>
-          <tal:block tal:repeat="entry changes">
-            <a tal:attributes="name string:entry-${entry/revno}" />
-            <tr tal:attributes="class string:revision-header parity${entry/parity}">
-              <td class="revision-number">
-                <a tal:attributes="title python:'Show revision '+entry.revno;
-                                   href  python:url(['/revision', entry.revno])"
-                   tal:content="python:util.trunc(entry.revno)">
-                  text
-                </a>
-              </td>
-              <td class="expand-button" tal:define="name entry/revno"
-                  tal:content="structure python:collapse_button('cl', entry.revno, branch)">
-              </td>
-              <td class="summary">
-                <a tal:attributes="title python:'Show revision '+entry.revno;
-                                   href  python:url(['/revision', entry.revno])"
-                   tal:content="entry/short_comment">
-                  text
-                </a>
-              </td>
-              <td tal:condition="not:all_same_author"
-                  tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
-                  class="author"></td>
-              <td class="date">
-                  <span tal:attributes="title python:util.date_time(entry.date)"
-                        tal:content="python:util._approximatedate(entry.date)"></span>
-              </td>
-              <td class="inventory-link">
-                <a tal:attributes="href python:branch.url(['/files', entry.revno]);
-                                   title string:Files at revision ${entry/revno}">
-                  files
-                </a>
-              </td>
+            <tr class="logheader">
+                <td class="revisionnumber">Rev</td>
+                <td class="expandcell">&nbsp;</td>
+                <td class="summarycell">Summary</td>
+                <td class="authorcell">Author</td>
+                <td class="datecell">Date</td>
+                <td class="diffcell">Diff</td>
+                <td class="downloadcell">Files</td>
             </tr>
-
-            <tr tal:attributes="class string:revision-details-block parity${entry/parity}">
-              <td colspan="2">
-              </td>
-              <td tal:attributes="colspan subcolspan">
-                <table tal:attributes="class string:revision-details hidden-details collapse-cl-${entry/revno}-content">
-                  <tr tal:repeat="merge_point entry/merge_points">
-                    <th class="children">
-                      <tal:block condition="repeat/merge_point/start">
-                        merged in:
-                      </tal:block>
-                    </th>
-                    <td class="children">
-                      <a title="Show history"
-                         tal:attributes="href python:url(['/changes'], start_revid=merge_point.revno)"
-                         tal:content="python:revno_with_nick(merge_point)">
-                        class="revlink">
-                        ${text}
-                      </a>
-                    </td>
-                  </tr>
-                  <tr tal:repeat="parent python:entry.parents[1:]">
-                    <th class="parents">
-                      <tal:block condition="repeat/parent/start">
-                        merged from:
-                      </tal:block>
-                    </th>
-                    <td class="parents">
-                      <a title="Show history"
-                         tal:attributes="href python:url(['/changes'], start_revid=parent.revno)"
-                         tal:content="python:revno_with_nick(parent)">
-                        class="revlink">
-                        ${text}
-                      </a>
-                    </td>
-                  </tr>
-                  <tr tal:condition="all_same_author">
-                    <th class="author">
-                      committed by:
-                    </th>
-                    <td class="author" tal:content="python:util.hide_email(entry.author)">
-                      ${util.hide_email(entry.author)}
-                    </td>
-                  </tr>
-                  <tr>
-                    <th class="description">
-                      description:
-                    </th>
-                    <td class="description">
-                      <tal:block repeat="line entry/comment_clean"
-                                 content="structure string:${line}&lt;br /&gt;" />
-                    </td>
-                  </tr>
-                  <tal:block content="structure python:file_change_summary(url, entry, modified_file_link_log)" />
-                </table>
-              </td>
+            <tal:block tal:repeat="entry changes">
+            <a tal:attributes="name string:entry-${entry/revno}"/>
+                <tr tal:attributes="class string:blueRow${entry/parity} revision_log">
+                <td class="revnro revnolink"><a tal:attributes="title python:'Show revision '+entry.revno;
+                                                                href  python:url(['/revision', entry.revno], clear=1)"
+                                                tal:content="python:util.trunc(entry.revno)"></a>
+                </td>            
+                <td class="expcell">
+                    <div class="expand_revisioninfo">
+                        <!-- So, this is interesting. I'm using "alt" to have the correct URL for the image of the expanded icon
+                             and "title" tag for the contracted URL of the image. This is a bit of a hack, but it's better than
+                             other approaches I tried  :)  -->
+                        <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
+                                             alt python:branch.static_url('/static/images/treeExpanded.png');
+                                             title python:branch.static_url('/static/images/treeCollapsed.png')" 
+                             class="expand_icon" />
+                    </div>
+                </td>
+                <td class="summcell"><div tal:attributes="class string:short_description">
+                                        <a tal:attributes="title python:'Show revision '+entry.revno;
+                                                           href  python:url(['/revision', entry.revno], clear=1);
+                                                           class string:link"
+                                           tal:content="entry/short_comment"></a>
+                                     </div>
+                                     <div tal:attributes="class string:long_description;
+                                                          style string:display:none">
+                                        <a tal:attributes="title python:'Show revision '+entry.revno;
+                                                           href  python:url(['/revision', entry.revno], clear=1);
+                                                           class string:link"
+                                           tal:content="entry/comment"></a>
+                                     </div>
+                                <div class="revisioninfo" style="display:none;">
+                                    <ul class="expandrev">
+               	                        <li class="mergefrom" tal:repeat="parent python:entry.parents[1:]">
+                                            <span class="revnolink">
+                                                <a tal:attributes="href python:url(['/changes', parent.revno])"
+                                                   tal:content="parent/revno"></a>
+                                            </span>
+                                            <a tal:attributes="href python:url(['/changes'], start_revid=parent.revno)"
+                                               tal:content="python:'(' + parent.branch_nick + ')'"
+                                                title="Show history" class="link"></a>
+                                        </li>
+               	                        <li class="mergefrom" tal:repeat="merge_point entry/merge_points">
+                                            <a tal:attributes="href python:url(['/changes'], start_revid=merge_point.revno)"
+                                               tal:content="python:revno_with_nick(merge_point)"
+                                               title="Show history" class="link"></a>
+                                        </li>
+                                        <li class="committerli" tal:content="python:util.hide_email(entry.author)"></li>
+                                        <tal:block content="structure python:file_change_summary(url, entry, modified_file_link_log)" />
+                                    </ul>
+                                </div>
+                </td>
+                <td tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
+                    class="autcell"></td>
+                <td class="date">
+                    <span tal:attributes="title python:util.date_time(entry.date)"
+                          tal:content="python:util._approximatedate(entry.date)"></span>
+                </td>
+                <td class="diffr"><a tal:attributes="title python:'Show diff at revision '+entry.revno;
+                                                     href python:url(['/revision', entry.revno], clear=1)">
+                                  <img tal:attributes="src python:branch.static_url('/static/images/ico_diff.gif')" alt="Diff" /></a></td>
+                <td class="downr"><a tal:attributes="href python:branch.url(['/files', entry.revno]);
+                                                     title string:Files at revision ${entry/revno}">
+                                   <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
+                                                        alt string:Files" /></a>
+                </td>
             </tr>
           </tal:block>
         </table>
 
-        <div tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
-             class="bar">
-          <table>
-            <tr>
-              <td class="buttons">
-                <a tal:condition="navigation/prev_page_revid"
-                   tal:attributes="href navigation/prev_page_url">
-                  &lt;&lt; page
-                </a>
-	      </td>
- 	      <td class="rbuttons" align="right">
-                <a tal:condition="navigation/next_page_revid"
-                   tal:attributes="href navigation/next_page_url">
-                  page &gt;&gt;
-                </a>
- 	      </td>
- 	    </tr>
-          </table>
-        </div>
+        <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
+            id="pages">
+            <li tal:condition="navigation/prev_page_revid" 
+                class="previous">
+                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
+            </li>
+            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+                        so some magic has to be done to just show the previous and next N page numbers
+
+            <li class="active">1</li>
+            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+            <li><a href="#"
+                   tal:content="page_number"></a></li>
+               </tal:block>-->
+            <li tal:condition="navigation/next_page_revid"
+                class="next">
+                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
+            </li>
+        </ul>
+
       </div>
     </body>
   </html>

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2008-06-20 02:13:34 +0000
+++ loggerhead/templates/inventory.pt	2008-06-20 22:41:12 +0000
@@ -2,31 +2,27 @@
 <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
   <head>
     <title metal:fill-slot="title"
-           tal:content="string:${branch/friendly_name} : files for revision ${change/revno}">
-      ${branch.friendly_name} : files for revision ${change.revno}
-    </title>
+           tal:content="string:${branch/friendly_name} : files for revision ${change/revno}"></title>
+    <metal:block fill-slot="header_extras">
+        <link rel="stylesheet" type="text/css" media="all"
+              tal:attributes="href python:branch.static_url('/static/css/files.css')"/>
+    </metal:block>
   </head>
   <body>
 
     <h1 metal:fill-slot="heading">
-      <span class="branch-name" tal:content="branch/friendly_name">
-        ${branch.friendly_name}
-      </span>
-      : files for revision
-      <tal:revno content="change/revno">
-        ${change.revno}
-      </tal:revno>
+      <tal:block content="branch/friendly_name"></tal:block><span>: files for revision <tal:revno content="change/revno"></tal:revno></span>
     </h1>
 
     <div metal:fill-slot="content">
-      <div class="links">
-        <div> <b>&#8594;</b> <a tal:attributes="href python:url(['/revision', change.revno], clear=1, start_revid=change.revno)">
-	    view revision </a>
-        </div>
-        <div> <b>&#8594;</b> <a tal:attributes="href python:url(['/changes', change.revno], clear=1, start_revid=change.revno)">
-	    view branch changes </a>
-        </div>
-      </div>
+        <ul id="submenuTabs">
+            <li id="inicio">
+                <a tal:attributes="href python:url(['/revision', change.revno], clear=1, start_revid=change.revno)">view revision</a>
+            </li>
+            <li id="final">
+                <a tal:attributes="href python:url(['/changes', change.revno], clear=1, start_revid=change.revno)">view branch changes</a>
+            </li>
+        </ul>
 
       <tal:revision-info replace="structure python:revisioninfo(url, branch, change)" />
 
@@ -34,101 +30,116 @@
         <b>folder:</b> <span class="folder" tal:content="path"> ${path} </span>
       </div>
 
-      <table class="inventory" width="100%">
-        <tr class="header">
-          <th class="permissions">
-            Permissions
-          </th>
-          <th>
-            <a tal:attributes="href python:url(['/files', revid], sort='filename')">Filename</a>
-          </th>
-          <th>
-            Latest Rev
-          </th>
-          <th>
-            <a tal:attributes="href python:url(['/files', revid], sort='date')">Last Changed</a>
-          </th>
-          <th>
-            <a tal:attributes="href python:url(['/files', revid], sort='size')">Size</a>
-          </th>
-          <th>
-          </th>
-          <th>
-          </th>
-        </tr>
-
-        <tr class="parity1" tal:condition="python:updir">
-          <td class="permissions">drwxr-xr-x</td>
-          <td class="filename directory">
-            <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)">
-              (up)
-            </a>
-          </td>
-          <td>
-          </td>
-          <td>
-          </td>
-          <td>
-          </td>
-          <td>
-          </td>
-        </tr>
-
-        <tr tal:repeat="file filelist"
-            tal:attributes="class string:parity${file/parity}">
-          <td class="permissions" tal:content="python:util.fake_permissions(file.kind, file.executable)">
-            ${}
-          </td>
-          <td tal:attributes="class string:filename ${file/kind}">
-            <a tal:condition="python:file.kind=='directory'"
-               tal:attributes="href python:url(['/files', change.revno], file_id=file.file_id)"
-               tal:content="string:${file/filename}/">
-              ${file.filename}/
-            </a>
-            <span tal:condition="python:file.kind=='symlink'"
-                  tal:content="string:${file/filename}@">
-              ${file.filename}@
-            </span>
-            <a tal:condition="python:file.kind=='file'"
-               tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id);
-                               title string:Annotate ${file/filename}"
-               tal:content="string:${file/filename}">
-              ${file.filename}
-            </a>
-          </td>
-          <td class="revision">
-            <a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
-                               title string:Show revision ${file/change/revno}"
-               tal:content="python:util.trunc(file.change.revno, 15)">
-              ${text}
-            </a>
-          </td>
-          <td class="date"
-              tal:content="python:util.date_time(file.change.date)">
-            ${}
-          </td>
-          <td class="size">
-            <span tal:condition="python:file.kind=='file'"
-                  tal:content="python:util.human_size(file.size)">
-              ${util.human_size(file.size)}
-            </span>
-          </td>
-          <td class="changes-link">
-            <a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
-                               title string:Changes affecting ${file/filename}">
-              changes
-            </a>
-          </td>
-          <td class="download-link">
-            <a tal:condition="python:file.kind=='file'"
-               tal:attributes="href python:url(['/download', file.revid, file.file_id, file.filename]);
-                               title string:Download ${file/filename} at revision ${file/change/revno}">
-              download
-            </a>
-          </td>
-        </tr>
+      <table id="logentries">
+          <tr class="logheader">
+            <td class="revisionnumber">.</td>
+            <td class="summarycell"><a href="#">Filename</a></td>            
+            <td class="datecell">Latest Rev</td>
+            <td class="datecell"><a href="#">Last Changed</a></td>
+            <td class="timedate"><a href="#">Size</a></td>
+            <td class="expandcell">.</td>
+            <td class="expandcell">.</td>            
+          </tr>
+
+          <tr class="blueRow0" tal:condition="python:updir">
+              <td class="revnro">
+                  <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)">
+                  <img tal:attributes="src python:branch.static_url('/static/images/ico_folder.gif')" alt="Go up one directory" /></a>
+              </td>
+              <td class="summcell" colspan="6">
+                  <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)" class="link">Up</a>
+              </td>
+          </tr>
+          
+          <!-- Show this if it's a directory --> 
+          <tal:block repeat="file filelist">
+          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='directory'">
+              <td class="revnro">
+                  <a tal:attributes="href python:url(['/files', change.revno], file_id=file.file_id)">
+                      <img tal:attributes="src python:branch.static_url('/static/images/ico_folder.gif');
+                                           title string:Go to ${file/filename}" />
+                  </a>
+
+               </td>
+               <td class="autcell"><a tal:attributes="href python:url(['/files', change.revno], file_id=file.file_id)" 
+                                      tal:content="file/filename" class="link"></a>
+               </td>
+               <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
+                                                   title string:Show revision ${file/change/revno}"
+                                   tal:content="file/change/revno"></a>
+               </td>
+               <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+               <td class="timedate2">.</td>
+               <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
+                                                   title string:Show revision ${file/change/revno}">
+                                    <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
+                                   </a>
+            </td>
+              <td class="expcell">.</td>
+          </tr>
+          
+          <!-- Show this if it's a symlink --> 
+          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='symlink'">
+              <td class="revnro">
+                  <a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)">
+                      <img tal:attributes="src python:branch.static_url('/static/images/ico_flecha.gif')" alt="Symlink" />
+                  </a>
+
+               </td>
+               <td class="autcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)" 
+                                      tal:content="file/filename" class="link"></a>
+               </td>
+               <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
+                                                   title string:Show revision ${file/change/revno}"
+                                   tal:content="file/change/revno"></a>
+               </td>
+               <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+               <td class="timedate2">.</td>
+               <td class="expcell"><a tal:attributes="href python:url(['/changes'], start_revid=start_revid, filter_file_id=file.file_id);
+                                                      title string:Show revision ${file/change/revno}">
+                                        <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif');
+                                                             title string:Show revision ${file/change/revno}" />
+                                   </a>
+            </td>
+              <td class="expcell">.</td>
+          </tr>
+
+          <!-- Show this if it's a regular file --> 
+          <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='file'">
+            <td class="revnro">
+                  <a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)">
+                      <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
+                                           title string:Annotate ${file/filename}"
+                           tal:condition="python:file.executable is False" />
+                      <!-- Show a different icon id the file executable -->
+                      <img tal:attributes="src python:branch.static_url('/static/images/ico_file_modify.gif'); 
+                                           title string:Annotate ${file/filename}"
+                           tal:condition="python:file.executable is True" alt="File" />
+                  </a>
+
+            </td>
+            <td class="autcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id)"
+                                   tal:content="file/filename" class="link"></a></td>
+            <td class="date"><a tal:attributes="href python:url(['/revision', file.change.revno], filter_file_id=file.file_id);
+                                                title string:Show revision ${file/change/revno}"
+                                tal:content="file/change/revno"></a>
+            </td>
+            <td class="date" tal:content="python:util.date_time(file.change.date)"></td>
+            <td class="timedate2" tal:content="python:util.human_size(file.size)"></td>
+            <td class="expcell"><a tal:attributes="href python:url(['/annotate', change.revno], file_id=file.file_id);
+                                                   title string:Annotate ${file/filename}">
+                                    <img tal:attributes="src python:branch.static_url('/static/images/ico_planilla.gif')" alt="Diff" />
+                                   </a>
+            </td>
+            <td class="expcell">
+               <a tal:attributes="href python:url(['/download', file.revid, file.file_id, file.filename]);
+                                  title string:Download ${file/filename} at revision ${file/change/revno}">
+                 <img tal:attributes="src python:branch.static_url('/static/images/ico_file_download.gif')" alt="Download File" />
+               </a>
+            </td>
+         </tr>
+        </tal:block>
       </table>
     </div>
-
   </body>
 </html>

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2008-06-16 11:38:05 +0000
+++ loggerhead/templates/macros.pt	2008-07-22 00:40:03 +0000
@@ -7,60 +7,53 @@
     <title metal:define-slot="title">
       Title.
     </title>
-
     <link rel="stylesheet"
-          tal:attributes="href python:branch.static_url('/static/css/zptstyle.css')" />
-
+          tal:attributes="href python:branch.static_url('/static/css/global.css')" />
+    <script type="text/javascript"
+            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-core.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-more.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src python:branch.static_url('/static/javascript/custom.js')"></script>
+      <script language="javascript">
+          var global_path = <tal:block content="python:'\''+branch.url('/')+'\''" />;
+      </script>
     <metal:block metal:define-slot="header_extras" />
   </head>
 
-  <body tal:attributes="onload onload|nothing">
-
-    <div class="bar" tal:condition="navigation|nothing">
-      <form tal:attributes="action python:branch.url('/changes', start_revid=getattr(navigation, 'start_revid', None), file_id=getattr(navigation, 'file_id', None))">
-        <table>
-          <tr>
-            <td>
-              <span class="buttons">
-                <a tal:attributes="href python:url('/changes', clear=1)"> changes </a>
-                <a tal:attributes="href python:url('/files', clear=1)"> files </a>
-                <span class="search">
-                  search: <input type="text" name="q" />
-                </span>
-              </span>
-            </td>
-            <td align="right" tal:condition="navigation/revid_list|nothing">
-              <span tal:condition="navigation/feed" class="rbuttons feed">
-                <a tal:attributes="href python:url(['/atom'])">
-                  <img tal:attributes="src python:branch.static_url('/static/images/feed-icon-16x16.gif')" />
-                </a>
-              </span>
-              <span class="navbuttons">
-                <a tal:condition="navigation/prev_page_revid"
-                   tal:attributes="href navigation/prev_page_url"
-                   title="Previous page">
-                  &#171;
-                </a>
-                <tal:arrow condition="not:navigation/prev_page_revid">
-                  &#171;
-                </tal:arrow>
-                revision <tal:b content="python:history.get_revno(revid)" />
-                (<tal:b condition="python:navigation.pagesize > 1">page </tal:b>
-                <tal:b content="navigation/page_position" /> / <tal:b content="navigation/page_count" />)
-                <a tal:condition="navigation/next_page_revid"
-                   tal:attributes="href navigation/next_page_url"
-                   title="Next page">
-                  &#187;
-                </a>
-                <tal:arrow condition="not:navigation/next_page_revid">
-                  &#187;
-                </tal:arrow>
-              </span>
-            </td>
-          </tr>
-        </table>
-      </form>
+<body>
+	<div id="topline"></div>
+    <div id="locationbar" xml:lang="en" lang="en" dir="ltr">
+        <strong id="yourlocation">Your location:</strong>
+        <ul id="menuroot">
+	        <li lpm:mid="root" class="item"><a href="https://launchpad.net/" class="breadcrumb container" id="homebreadcrumb"><em><span>Home</span></em></a></li>
+        </ul>      
     </div>
+    <!-- Loggerhead Content Area -->
+    <ul id="menuTabs">
+        <form tal:attributes="action python:branch.url('/changes', start_revid=getattr(navigation, 'start_revid', None), 
+                                                                   file_id=getattr(navigation, 'file_id', None))">
+      	<div id="finderBox">
+            <span class="search">
+                search: <input type="text" name="q" id="q" autocomplete="off" onblur="hide_search();" />
+            </span>
+            <div><a tal:attributes="href python:url(['/atom']);
+                                    title string:RSS feed for ${branch/friendly_name}">
+                 <img tal:attributes="src python:branch.static_url('/static/images/ico_rss.gif')"  alt="RSS" /></a>
+            </div>
+        </div>
+        </form>
+        <li><a tal:attributes="href python:url('/changes', clear=1);
+                               title string:Changes;
+                               id string:on">Changes</a></li>
+        <li><a tal:attributes="href  python:url('/files', clear=1);
+                               title string:Files">Files</a></li>
+        <li><a tal:attributes="href string:#;
+                               title string:Help">Help</a></li>       
+      </ul>
+      <div id="loggerheadCont">
+    
+     <div id="search_terms"></div>
 
     <h1 metal:define-slot="heading">
       Heading
@@ -70,17 +63,7 @@
       Content.
     </div>
 
-    <div class="footer">
-      <span class="banner">
-        <a href="http://www.bazaar-vcs.org/">
-          <img tal:attributes="src python:branch.static_url('/static/images/bazaar-banner.png')" />
-        </a>
-      </span>
-      <span class="banner">
-        <a href="http://www.lag.net/loggerhead/">
-          <img tal:attributes="src python:branch.static_url('/static/images/loggerhead-banner.png')" />
-        </a>
-      </span>
+    <p class="fl">Launchpad runs <a href="#" class="link">Loggerhead</a> on <a href="#" class="link">Bazaar</a> branches</p>
     </div>
   </body>
 </html>

=== modified file 'loggerhead/templates/modified-file-link-log.pt'
--- loggerhead/templates/modified-file-link-log.pt	2008-06-19 23:02:48 +0000
+++ loggerhead/templates/modified-file-link-log.pt	2008-06-20 17:28:20 +0000
@@ -1,6 +1,6 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<a tal:attributes="href python:'javascript:diff_url(\'' + url(['/revision', entry.revno]) + '#' + item.filename + '\')';
-                   title string:Annotate ${item/filename}"
-   tal:content="item/filename" class="filename">
-  item/filename
-</a>
+<li class="files"><a tal:attributes="href python:'javascript:diff_url(\'' + url(['/revision', entry.revno], clear=1) + '#' + item.filename + '\')';
+                                     title string:Annotate ${item/filename}"
+                     tal:content="item/filename"
+                     class="link"></a>
+</li>

=== modified file 'loggerhead/templates/modified-file-link-rev.pt'
--- loggerhead/templates/modified-file-link-rev.pt	2008-06-11 00:02:50 +0000
+++ loggerhead/templates/modified-file-link-rev.pt	2008-06-19 21:39:15 +0000
@@ -1,14 +1,7 @@
 <tal:block>
-  <a class="collapse-style-sbs-content filename"
+<li class="files"><a 
      tal:attributes="href  string:#${item/filename}-s;
                      title string:Jump to ${item/filename} below"
      tal:content="item/filename" >
-    item/filename
-  </a>
-  <a class="collapse-style-unified-content filename"
-     tal:attributes="href  string:#${item/filename}-u;
-                     title string:Jump to ${item/filename} below"
-     tal:content="item/filename" >
-    item/filename
-  </a>
+</a></li>
 </tal:block>

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2008-06-20 02:20:05 +0000
+++ loggerhead/templates/revision.pt	2008-06-27 21:01:30 +0000
@@ -4,291 +4,147 @@
     <head>
       <title metal:fill-slot="title"
              tal:content="string:${branch/friendly_name} : revision ${change/revno}">
-        ${branch.friendly_name} : revision ${change.revno}
       </title>
 
       <metal:block fill-slot="header_extras">
-        <script type="text/javascript"
-                tal:attributes="src python:branch.static_url('/static/javascript/collapse.js')">
-        </script>
+        <link rel="stylesheet" type="text/css" media="all"
+              tal:attributes="href python:branch.static_url('/static/css/diff.css')"/>
       </metal:block>
     </head>
 
     <body>
 
-      <h1 metal:fill-slot="heading">
-        <span class="branch-name" tal:content="branch/friendly_name">
-          ${branch.friendly_name}
-        </span>
-        : revision
-        <tal:revno content="change/revno">
-          ${change.revno}
-        </tal:revno>
+      <tal:block metal:fill-slot="heading">
+        <h1><tal:block content="branch/friendly_name" /><span>: <tal:revno content="change/revno"></tal:revno>
         <tal:compare-to condition="python:compare_revid is not None">
-          (compared to revision <tal:b content="python:history.get_revno(compare_revid)" />)
-        </tal:compare-to>
-      </h1>
+          (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
+          </tal:compare-to>
+        </span></h1>
+        <ul id="submenuTabs">
+            <li id="inicio"><a tal:attributes="href python:url(['/files', change.revno]); 
+                                               title string:browse files at revision ${change/revno}"
+                               tal:content="string:browse files at revision ${change/revno}"></a></li>
+            <li tal:condition="python:remember != change.revno">
+                <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None); 
+                                   title string:Compare with another revision"
+                   tal:content="string:Compare with another revision"></a></li>       
+            <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
+                <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
+                compare with revision <tal:b content="python:history.get_revno(remember)" />
+                </a>
+            </li>
+            <li id="final"><a tal:attributes="href python:url(['/changes', change.revno]); 
+                                  title string:view history from revision ${change/revno}"
+                  tal:content="string:view history from revision ${change/revno}"></a></li>
+        </ul>
 
-      <div metal:fill-slot="content">
-        <div class="links">
-          <div>
-            <b>&#8594;</b>
-            <a tal:attributes="href python:url(['/files', change.revno])">
-              browse files at revision <tal:b content="change/revno" />
-            </a>
-          </div>
-          <div>
-            <b>&#8594;</b>
-            <a tal:attributes="href python:url(['/changes'], start_revid=change.revno)">
-              view history from revision <tal:b content="change/revno" />
-            </a>
-          </div>
-          <div tal:condition="python:compare_revid is not None" >
-            <b>&#8594;</b>
-            <a tal:attributes="href python:branch.url(['/bundle', change.revno, history.get_revno(compare_revid), 'bundle.txt'])">
-                download bundle from <tal:b content="python:history.get_revno(compare_revid)" /> to <tal:b content="change/revno" />
-            </a>
-          </div>
-          <div tal:condition="python:(remember is not None) and (compare_revid is None) and remember != revid" >
-            <b>&#8594;</b>
-            <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
-              compare with revision <tal:b content="python:history.get_revno(remember)" />
-            </a>
-          </div>
-          <div  tal:condition="python:remember != revid">
-            <b>&#8594;</b>
-            <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None)">
-              compare with another revision
-            </a>
-          </div>
-          <tal:we-are-comparing condition="python:compare_revid is not None">
-            <div>
-              <b>&#8594;</b>
+        <tal:we-are-comparing condition="python:compare_revid is not None">
+        <ul id="submenuTabs">
+          <li id="inicio">
               <a tal:attributes="href python:url([ '/revision', history.get_revno(compare_revid) ], remember=change.revno, compare_revid=change.revno)">
                 reverse the comparison (<tal:b content="change/revno" /> to <tal:b content="python:history.get_revno(compare_revid)" />)
               </a>
-            </div>
-            <div>
-              <b>&#8594;</b>
+          </li>
+          <li id="final">
               <a tal:attributes="href python:url(['/revision', change.revno], remember=None, compare_revid=None)">
                 stop comparing with revision <tal:b content="python:history.get_revno(compare_revid)" />
               </a>
-            </div>
-          </tal:we-are-comparing>
-        </div>
-
+          </li>
+        </ul>
+        </tal:we-are-comparing>
+        
         <tal:revision-info replace="structure python:revisioninfo(url, branch, change, modified_file_link_rev)" />
-
-        <table class="diff-option-buttons">
-          <tr>
-            <td>
-              <tal:b content="structure python:collapse_all_button('file', branch, normal='table-row')" />
-            </td>
-
-            <td class="spacey">
-              <a href="javascript:show_sbs()"
-                 class="hide-all collapse-style-sbs-show"
-                 title="collapse">
-                <img tal:attributes="src python:branch.static_url('/static/images/nav-small-out.gif')"
-                     width="22" height="10" class="collapse-triangle" />
-                show side by side
-              </a>
-              <a href="javascript:show_unified()"
-                 class="hide-all collapse-style-unified-show"
-                 title="expand">
-                <img tal:attributes="src python:branch.static_url('/static/images/nav-small-in.gif')"
-                     width="22" height="10" class="collapse-triangle" />
-                show unified diff
-              </a>
-            </td>
-
-            <td class="diff-key-block diff-insert">
-            </td>
-            <td class="label">
-              added
-            </td>
-            <td class="diff-key-block diff-delete">
-            </td>
-            <td class="label">
-              removed
-            </td>
-          </tr>
-        </table>
-
+        <p class="expand" id="expand_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('open')">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+                  alt="expand all" /> expand all</a>
+        </p>
+        <p class="expand" id="collapse_all"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('close')">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+                  alt="collapse all" /> collapse all</a>
+        </p>
+        <!-- Table -->        
+        <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/newCode.gif')" alt="added" /> added</p>
+        <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/deleteCode.gif')" alt="removed" /> removed</p>
+        <div class="clear"><!-- --></div>
+
+      </tal:block>
+
+      <div metal:fill-slot="content">
         <div class="diff"
              tal:condition="change/changes/modified"
              tal:define="uniqs python:{}">
           <!-- ! side-by-side diff -->
-          <table class="diff-block collapse-style-sbs-content">
-            <tal:block repeat="item change/changes/modified">
+          <tal:block repeat="item change/changes/modified">
+
               <tal:u define="u python:util.uniq(uniqs, item.file_id)">
-                <tr>
-                  <th class="filename" colspan="4">
-                    <tal:b content="structure python:collapse_button('file', u, branch, normal='table-row')" />
-                    <a tal:attributes="href  python:url(['/annotate', change.revno], file_id=item.file_id);
-                                       name  string:${item/filename}-s;
-                                       title string:Annotate ${item/filename}"
-                       tal:content="item/filename">
-                      ${item.filename}
-                    </a>
-                  </th>
-                </tr>
-
-                <tal:block repeat="chunk item/sbs_chunks">
-                  <tr tal:attributes="class string:diff-chunk collapse-file-${u}-content">
-                    <th class="lineno">
-                      old
-                    </th>
-                    <th>
-                    </th>
-                    <th class="lineno">
-                      new
-                    </th>
-                    <th>
-                    </th>
-                  </tr>
-                  <tr tal:repeat="line chunk/diff"
-                      tal:attributes="class string:diff-chunk collapse-file-${u}-content">
+                      <div class="diffBox"><img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
+                                                                title python:branch.static_url('/static/images/treeCollapsed.png');
+                                                                alt python:branch.static_url('/static/images/treeExpanded.png')"
+                                                                class="expand_diff" />
+                                           <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
+                                                              id string:${item/filename}-s;
+                                                              title string:Annotate ${item/filename}"
+                                              tal:content="item/filename"></a></div>
+               <div id="psuedotable" class="diffinfo">
+               <tal:block repeat="chunk item/sbs_chunks">
+                 <tal:block repeat="line chunk/diff">
+                    <div id="pseudorow">
                     <tal:block condition="line/old_lineno">
-                      <td class="lineno"
-                          tal:content="line/old_lineno">
-                        ${line.old_lineno}
-                      </td>
-                      <td tal:attributes="class string:diff-${line/old_type}"
-                          tal:content="line/old_line">
-                        ${line.old_line}
-                      </td>
+                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
+                        <div tal:attributes="class string:lineCode ${line/old_type}">
+                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
+                        </div>
                     </tal:block>
+
                     <tal:block condition="not:line/old_lineno">
-                      <td class="lineno-skip"
-                          tal:content="line/old_lineno">
-                        ${line.old_lineno}
-                      </td>
-                      <td tal:attributes="class string:diff-${line/old_type}-skip"
-                          tal:content="line/old_line">
-                        ${line.old_line}
-                      </td>
+                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
+                        <div tal:attributes="class string:lineCode ${line/old_type}">
+                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
+                        </div>
                     </tal:block>
+
                     <tal:block condition="line/new_lineno">
-                      <td class="lineno"
-                          tal:content="line/new_lineno">
-                        ${line.new_lineno}
-                      </td>
-                      <td tal:attributes="class string:diff-${line/new_type}"
-                          tal:content="line/new_line">
-                        ${line.new_line}
-                      </td>
+                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
+                        <div tal:attributes="class string:lineCode ${line/new_type}">
+                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
+                        </div>
                     </tal:block>
+
                     <tal:block condition="not:line/new_lineno">
-                      <td class="lineno-skip"
-                          tal:content="line/new_lineno">
-                        ${line.new_lineno}
-                      </td>
-                      <td tal:attributes="class string:diff-${line/new_type}-skip"
-                          tal:content="line/new_line">
-                        ${line.new_line}
-                      </td>
+                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
+                        <div tal:attributes="class string:lineCode ${line/new_type}">
+                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
+                        </div>
                     </tal:block>
-                  </tr>
-                  <tr tal:attributes="class string:diff-chunk-spacing collapse-file-${u}-content">
-                    <td colspan="4">
-                      &nbsp;
-                    </td>
-                  </tr>
-                </tal:block>
-                <tr class="diff-spacing">
-                  <td colspan="4">
-                    &nbsp;
-                  </td>
-                </tr>
-              </tal:u>
-            </tal:block>
-          </table>
-
-          <!-- ! unified diff -->
-          <table class="diff-block collapse-style-unified-content">
-            <tal:block repeat="item change/changes/modified">
-              <tal:u define="u python:util.uniq(uniqs, item.file_id)">
-                <tr>
-                  <th class="filename" colspan="4">
-                    <tal:b content="structure python:collapse_button('file', u, branch, normal='table-row')" />
-                    <a tal:attributes="href  python:url(['/annotate', change.revno], file_id=item.file_id);
-                                       name  string:${item/filename}-u;
-                                       title string:Annotate ${item/filename}"
-                       tal:content="item/filename">
-                      ${item.filename}
-                    </a>
-                  </th>
-                </tr>
-
-                <tal:block repeat="chunk item/chunks">
-                  <tr tal:attributes="class string:diff-chunk collapse-file-${u}-content">
-                    <th class="lineno">
-                      old
-                    </th>
-                    <th class="lineno">
-                      new
-                    </th>
-                    <th>
-                    </th>
-                    <th>
-                    </th>
-                  </tr>
-                  <tr tal:repeat="line chunk/diff"
-                      tal:attributes="class string:diff-chunk collapse-file-${u}-content">
-                    <td class="lineno"
-                        tal:content="line/old_lineno">
-                      ${line.old_lineno}
-                    </td>
-                    <td class="lineno"
-                        tal:content="line/new_lineno">
-                      ${line.new_lineno}
-                    </td>
-                    <td tal:attributes="class string:diff-${line/type} text"
-                        tal:content="line/line">
-                      ${line.line}
-                    </td>
-                    <td>
-                    </td>
-                  </tr>
-                  <tr tal:attributes="class string:diff-chunk-spacing collapse-file-${u}-content">
-                    <td colspan="4">
-                      &nbsp;
-                    </td>
-                  </tr>
-                </tal:block>
-                <tr class="diff-spacing">
-                  <td colspan="4">
-                    &nbsp;
-                  </td>
-                </tr>
-              </tal:u>
-            </tal:block>
-          </table>
-        </div>
-
-        <div tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
-             class="bar">
-          <table>
-            <tr>
-              <td class="buttons">
-                <a tal:condition="navigation/prev_page_revid"
-                   tal:attributes="href navigation/prev_page_url">
-                  &lt; revision
-                  <tal:r content="python:history.get_revno(navigation.prev_page_revid)" />
-                </a>
-	      </td>
- 	      <td class="rbuttons" align="right">
-                <a tal:condition="navigation/next_page_revid"
-                   tal:attributes="href navigation/next_page_url">
-                  revision
-                  <tal:r content="python:history.get_revno(navigation.next_page_revid)" />
-                  &gt;
-                </a>
- 	      </td>
- 	    </tr>
-          </table>
-        </div>
+                    <div class="clear"><!-- --></div>
+                    </div>
+                   </tal:block>
+                 </tal:block>
+                 </div>
+              </tal:u>
+            </tal:block>
+        </div>
+
+        <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
+            id="pages">
+            <li tal:condition="navigation/prev_page_revid" 
+                class="previous">
+                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
+            </li>
+            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+                        so some magic has to be done to just show the previous and next N page numbers
+
+            <li class="active">1</li>
+            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+            <li><a href="#"
+                   tal:content="page_number"></a></li>
+               </tal:block>-->
+            <li tal:condition="navigation/next_page_revid"
+                class="next">
+                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
+            </li>
+        </ul>
+
       </div>
     </body>
   </html>

=== modified file 'loggerhead/templates/revisionfilechanges.pt'
--- loggerhead/templates/revisionfilechanges.pt	2007-09-05 18:40:01 +0000
+++ loggerhead/templates/revisionfilechanges.pt	2008-06-30 14:28:38 +0000
@@ -1,67 +1,54 @@
 <tal:block>
-  <tr tal:repeat="added entry/changes/added">
-    <th class="files">
-      <tal:block condition="repeat/added/start">
-        files added:
-      </tal:block>
-    </th>
-    <td class="files"
+<ul tal:repeat="added entry/changes/added">
+    <tal:block condition="repeat/added/start">
+        <li class="desc">files added:</li>
+    </tal:block>
+    <li class="files"
         tal:define="filename python:added[0];
                     file_id  python:added[1]">
-      <a tal:attributes="href  python:url(['/annotate', entry.revid], file_id=file_id);
-                         title string:Annotate ${filename}"
-         tal:content="filename" class="filename">
-        filename
-      </a>
-    </td>
-  </tr>
-  <tr tal:repeat="removed entry/changes/removed">
-    <th class="files">
-      <tal:block condition="repeat/removed/start">
-        files removed:
-      </tal:block>
-    </th>
-    <td class="files"
+        <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
+                           title string:Annotate ${filename}"
+           tal:content="filename" class="link"></a>
+    </li>
+</ul>
+
+<ul tal:repeat="removed entry/changes/removed">
+    <tal:block condition="repeat/removed/start">
+        <li class="desc">files removed:</li>
+    </tal:block>
+    <li class="files"
         tal:define="filename python:removed[0];
                     file_id  python:removed[1]">
-      <a tal:attributes="href  python:url(['/annotate', entry.revid], file_id=file_id);
-                         title string:Annotate ${filename}"
-         tal:content="filename" class="filename">
-        filename
-      </a>
-    </td>
-  </tr>
-  <tr tal:repeat="renamed entry/changes/renamed">
-    <th class="files">
-      <tal:block condition="repeat/renamed/start">
-        files renamed:
-      </tal:block>
-    </th>
-    <td class="files"
+      <tal:block content="filename" />
+    </li>
+</ul>
+
+<ul tal:repeat="renamed entry/changes/renamed">
+    <tal:block condition="repeat/renamed/start">
+        <li class="desc">files renamed:</li>
+    </tal:block>
+    <li class="files"
         tal:define="old_filename python:renamed[0];
                     new_filename python:renamed[1];
                     file_id      python:renamed[2]">
-      <a tal:attributes="href  python:url(['/annotate', entry.revid], file_id=file_id);
+      <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
                          title string:Annotate ${old_filename}"
          tal:content="old_filename" class="filename">
         old_filename
       </a>
       =>
-      <a tal:attributes="href  python:url(['/annotate', entry.revid], file_id=file_id);
+      <a tal:attributes="href  python:url(['/annotate', entry.revno], file_id=file_id);
                          title string:Annotate ${new_filename}"
          tal:content="new_filename">
         new_filename
       </a>
-    </td>
-  </tr>
-  <tr tal:repeat="item entry/changes/modified" class="filename">
-    <th class="files">
-      <tal:block condition="repeat/item/start">
-        files modified:
-      </tal:block>
-    </th>
-    <td class="files">
-        <tal:b content="structure python:modified_file_link(url, entry, item)" />
-    </td>
-  </tr>
+    </li>
+</ul>
+
+<ul tal:repeat="item entry/changes/modified">
+    <tal:block condition="repeat/item/start">
+        <li class="desc">files modified:</li>
+    </tal:block>
+    <tal:b content="structure python:modified_file_link(url, entry, item)" />
+</ul>
 </tal:block>

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2008-06-20 02:13:34 +0000
+++ loggerhead/templates/revisioninfo.pt	2008-06-20 17:28:20 +0000
@@ -1,89 +1,23 @@
-<div class="revision-info">
-  <table>
-    <tr>
-      <th class="author">
-        committed by:
-      </th>
-      <td class="author"
-          tal:content="python:util.hide_email(change.author)">
-        author@email
-      </td>
-    </tr>
-    <tr>
-      <th class="date">
-        date:
-      </th>
-      <td class="date"
-          tal:content="python:util.date_time(change.date)">
-        date
-      </td>
-    </tr>
-
-    <tr tal:repeat="merge_point change/merge_points">
-      <th class="children">
-        <tal:block condition="repeat/merge_point/start">
-          merged in:
-        </tal:block>
-      </th>
-      <td class="children">
-        <a title="Show history"
-           tal:attributes="title string:Show revision ${merge_point/revno};
-                                        href python:url(['/revision', merge_point.revno], clear=1,
-                                                        start_revid=merge_point.revid)"
-           tal:content="python:revno_with_nick(merge_point)">
-          ${text}
-        </a>
-      </td>
-    </tr>
-
-    <tr tal:repeat="parent python:change.parents[1:]">
-      <th class="parents">
-        <tal:block condition="repeat/parent/start">
-          merged from:
-        </tal:block>
-      </th>
-      <td class="parents">
-        <a title="Show history"
-           tal:attributes="title string:Show revision ${parent/revno};
-                           href python:url(['/revision', parent.revno], clear=1, start_revid=parent.revno)"
-           tal:content="python:revno_with_nick(parent)">
-          class="revlink">
-          ${text}
-        </a>
-      </td>
-    </tr>
-
-    <tr>
-      <th class="description">
-        description:
-      </th>
-      <td class="description">
-        <span tal:repeat="line change/comment_clean">
-          <tal:line replace="structure line" />
-          <br />
-        </span>
-      </td>
-    </tr>
-
-    <tr>
-      <th class="revid">
-        revision id:
-      </th>
-      <td class="revid">
-          <span tal:content="python:change.revid">
-              revid
-        </span>
-      </td>
-    </tr>
-
-    <tal:block condition="nocall:modified_file_link">
-      <tr class="divider">
-        <th>
-        </th>
-        <td>
-        </td>
-      </tr>
-      <tal:block content="structure python:file_change_summary(url, change, modified_file_link)" />
-    </tal:block>
-  </table>
+<div id="infoContainer" class="revision-info">
+    <div id="infTxt">
+        <div class="comiter" tal:content="python:util.hide_email(change.author)"></div>
+        <div class="timer" tal:content="python:util.date_time(change.date)"></div>
+        <div class="mfrom" tal:repeat="parent python:change.parents[1:]">
+            <a tal:attributes="title string:Merged From ${parent/revno};
+                               href python:url(['/revision', parent.revno], clear=1)"
+               tal:content="python:revno_with_nick(parent)"></a>
+        </div>
+        <div class="mfrom" tal:repeat="merge_point change/merge_points">
+            <a tal:attributes="title string:Merged In ${merge_point/revno};
+                               href python:url(['/revision', merge_point/revno], clear=1)"
+               tal:content="python:revno_with_nick(merge_point)"></a>
+        </div>
+        <div class="revid" tal:content="string:RevisionID: ${change/revid}"></div>
+        <div class="information" tal:content="change/comment"></div>
+    </div>
+    <ul id="list-files">
+        <tal:block condition="nocall:modified_file_link">
+        <tal:block content="structure python:file_change_summary(url, change, modified_file_link)" /></tal:block>
+    </ul>
+    <div class="clear"><!-- --></div>
 </div>

=== added file 'loggerhead/templates/search.pt'
--- loggerhead/templates/search.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/search.pt	2008-07-17 04:12:49 +0000
@@ -0,0 +1,8 @@
+<ul style="list-style:none; list-style-display:inline; padding:2px; max-height:450px;">
+<tal:block repeat="term terms" condition="python: len(terms) > 0">
+    <li><a tal:attributes="href python:url(['/changes'], q=term)" tal:content="term"></a></li>
+</tal:block>
+<tal:block condition="python: len(terms) == 0">
+    <li>No results found.</li>
+</tal:block>
+</ul>

=== modified file 'loggerhead/tests/test_filechangecache.py'
--- loggerhead/tests/test_filechangecache.py	2007-09-10 12:51:42 +0000
+++ loggerhead/tests/test_filechangecache.py	2008-06-25 07:03:06 +0000
@@ -5,12 +5,12 @@
 
 from loggerhead.changecache import FileChangeCache
 
-class MockEntry:
+class MockEntry(object):
     def __init__(self, revid):
         self.revid = revid
 
 
-class MockHistory:
+class MockHistory(object):
     def __init__(self):
         self.fetched_revids = set()
     def get_file_changes_uncached(self, entries):

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2008-06-18 12:27:04 +0000
+++ loggerhead/tests/test_simple.py	2008-07-01 04:01:31 +0000
@@ -51,11 +51,8 @@
             folder = '%(branch)s'
     """
 
-    def makeHistory(self):
-        return History.from_folder(self.bzrbranch)
-
     def setUpLoggerhead(self):
-        app = TestApp(BranchWSGIApp(self.bzrbranch).app)
+        app = TestApp(BranchWSGIApp(self.branch).app)
         return app
 
     def tearDown(self):

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2008-06-20 02:20:05 +0000
+++ loggerhead/util.py	2008-07-22 00:40:03 +0000
@@ -27,13 +27,9 @@
 import datetime
 import logging
 import re
-import sha
 import struct
-import sys
 import threading
 import time
-import traceback
-
 
 log = logging.getLogger("loggerhead.controllers")
 
@@ -142,28 +138,12 @@
         return out
 
 
-def clean_revid(revid):
-    if revid == 'missing':
-        return revid
-    return sha.new(revid).hexdigest()
-
-
-def obfuscate(text):
-    return ''.join([ '&#%d;' % ord(c) for c in text ])
-
-
 def trunc(text, limit=10):
     if len(text) <= limit:
         return text
     return text[:limit] + '...'
 
 
-def to_utf8(s):
-    if isinstance(s, unicode):
-        return s.encode('utf-8')
-    return s
-
-
 STANDARD_PATTERN = re.compile(r'^(.*?)\s*<(.*?)>\s*$')
 EMAIL_PATTERN = re.compile(r'[-\w\d\+_!%\.]+@[-\w\d\+_!%\.]+')
 
@@ -187,40 +167,6 @@
     return '%s at %s' % (username, domains[0])
 
 
-def triple_factors(min_value=1):
-    factors = (1, 3)
-    index = 0
-    n = 1
-    while True:
-        if n >= min_value:
-            yield n * factors[index]
-        index += 1
-        if index >= len(factors):
-            index = 0
-            n *= 10
-
-
-def scan_range(pos, max, pagesize=1):
-    """
-    given a position in a maximum range, return a list of negative and positive
-    jump factors for an hgweb-style triple-factor geometric scan.
-
-    for example, with pos=20 and max=500, the range would be:
-    [ -10, -3, -1, 1, 3, 10, 30, 100, 300 ]
-
-    i admit this is a very strange way of jumping through revisions.  i didn't
-    invent it. :)
-    """
-    out = []
-    for n in triple_factors(pagesize + 1):
-        if n > max:
-            return out
-        if pos + n < max:
-            out.append(n)
-        if pos - n >= 0:
-            out.insert(0, -n)
-
-
 # only do this if unicode turns out to be a problem
 #_BADCHARS_RE = re.compile(ur'[\u007f-\uffff]')
 
@@ -235,10 +181,29 @@
     s = s.replace(' ', '&nbsp;')
     return s
 
-
-
 NONBREAKING_SPACE = u'\N{NO-BREAK SPACE}'
 
+def fill_div(s):
+    """
+    CSS is stupid. In some cases we need to replace an empty value with
+    a non breaking space (&nbsp;). There has to be a better way of doing this.
+
+    return: the same value recieved if not empty, and a NONBREAKING_SPACE 
+            if not 
+    """
+    if type(s) is int and s is None:
+        return '&nbsp;'
+    elif type(s) is int and s is not None:
+        return s
+    elif type(s) is types.NoneType:
+        return '&nbsp;'
+    elif len(s) is 0:
+        return '&nbsp;'
+    else:
+        return s
+
+
+
 def fixed_width(s):
     """
     expand tabs and turn spaces into "non-breaking spaces", so browsers won't
@@ -266,15 +231,6 @@
     return '-rw-r--r--'
 
 
-def if_present(format, value):
-    """
-    format a value using a format string, if the value exists and is not None.
-    """
-    if value is None:
-        return ''
-    return format % value
-
-
 def b64(s):
     s = base64.encodestring(s).replace('\n', '')
     while (len(s) > 0) and (s[-1] == '='):
@@ -354,13 +310,14 @@
             return None
         return navigation.revid_list[navigation.position + offset]
 
+    navigation.last_in_page_revid = get_offset(navigation.pagesize - 1)
     navigation.prev_page_revid = get_offset(-1 * navigation.pagesize)
     navigation.next_page_revid = get_offset(1 * navigation.pagesize)
-    prev_page_revno = navigation.branch.history.get_revno(
+    prev_page_revno = navigation.history.get_revno(
             navigation.prev_page_revid)
-    next_page_revno = navigation.branch.history.get_revno(
+    next_page_revno = navigation.history.get_revno(
             navigation.next_page_revid)
-    start_revno = navigation.branch._history.get_revno(navigation.start_revid)
+    start_revno = navigation.history.get_revno(navigation.start_revid)
 
     params = { 'filter_file_id': navigation.filter_file_id }
     if getattr(navigation, 'query', None) is not None:
@@ -377,11 +334,6 @@
             [navigation.scan_url, next_page_revno], **params)
 
 
-def log_exception(log):
-    for line in ''.join(traceback.format_exception(*sys.exc_info())).split('\n'):
-        log.debug(line)
-
-
 def decorator(unbound):
     def new_decorator(f):
         g = unbound(f)
@@ -412,22 +364,6 @@
 
 
 @decorator
-def strip_whitespace(f):
-    def _f(*a, **kw):
-        out = f(*a, **kw)
-        orig_len = len(out)
-        out = re.sub(r'\n\s+', '\n', out)
-        out = re.sub(r'[ \t]+', ' ', out)
-        out = re.sub(r'\s+\n', '\n', out)
-        new_len = len(out)
-        log.debug('Saved %sB (%d%%) by stripping whitespace.',
-                  human_size(orig_len - new_len),
-                  round(100.0 - float(new_len) * 100.0 / float(orig_len)))
-        return out
-    return _f
-
-
-@decorator
 def lsprof(f):
     def _f(*a, **kw):
         from loggerhead.lsprof import profile

=== added file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	1970-01-01 00:00:00 +0000
+++ loggerhead/wholehistory.py	2008-07-01 02:24:16 +0000
@@ -0,0 +1,63 @@
+# Cache the whole history data needed by loggerhead about a branch.
+
+import logging
+import time
+
+from bzrlib.revision import is_null, NULL_REVISION
+from bzrlib.tsort import merge_sort
+
+
+def _strip_NULL_ghosts(revision_graph):
+    """
+    Copied over from bzrlib meant as a temporary workaround for
+    deprecated methods.
+    """
+    # Filter ghosts, and null:
+    if NULL_REVISION in revision_graph:
+        del revision_graph[NULL_REVISION]
+    for key, parents in revision_graph.items():
+        revision_graph[key] = tuple(parent for parent in parents if parent
+            in revision_graph)
+    return revision_graph
+
+
+def compute_whole_history_data(branch):
+    z = time.time()
+
+    last_revid = branch.last_revision()
+
+    log = logging.getLogger('loggerhead.%s' % (branch.nick,))
+
+    graph = branch.repository.get_graph()
+    parent_map = dict(((key, value) for key, value in
+         graph.iter_ancestry([last_revid]) if value is not None))
+
+    _revision_graph = _strip_NULL_ghosts(parent_map)
+    _full_history = []
+    _revision_info = {}
+    _revno_revid = {}
+    if is_null(last_revid):
+        _merge_sort = []
+    else:
+        _merge_sort = merge_sort(
+            _revision_graph, last_revid, generate_revno=True)
+
+    for (seq, revid, merge_depth, revno, end_of_merge) in _merge_sort:
+        _full_history.append(revid)
+        revno_str = '.'.join(str(n) for n in revno)
+        _revno_revid[revno_str] = revid
+        _revision_info[revid] = (
+            seq, revid, merge_depth, revno_str, end_of_merge)
+
+    _where_merged = {}
+
+    for revid in _revision_graph.keys():
+        if _revision_info[revid][2] == 0:
+            continue
+        for parent in _revision_graph[revid]:
+            _where_merged.setdefault(parent, set()).add(revid)
+
+    log.info('built revision graph cache: %r secs' % (time.time() - z,))
+
+    return (_revision_graph, _full_history, _revision_info,
+            _revno_revid, _merge_sort, _where_merged)

=== modified file 'serve-branches.py'
--- serve-branches.py	2008-06-23 02:23:46 +0000
+++ serve-branches.py	2008-06-24 23:20:59 +0000
@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import logging
 import sys
 
 from paste import httpserver
@@ -7,6 +8,10 @@
 
 from loggerhead.apps.filesystem import BranchesFromFileSystemRoot
 
+
+logging.basicConfig()
+logging.getLogger().setLevel(logging.DEBUG)
+
 if len(sys.argv) > 1:
     path = sys.argv[1]
 else:

=== modified file 'start-loggerhead.py'
--- start-loggerhead.py	2008-06-23 01:40:28 +0000
+++ start-loggerhead.py	2008-07-22 00:40:03 +0000
@@ -50,9 +50,9 @@
     access_log.setLevel(logging.INFO)
     access_log.setFormatter(f)
 
+    logging.getLogger('').setLevel(logging.DEBUG)
     logging.getLogger('').addHandler(debug_log)
-    logging.getLogger('turbogears.access').addHandler(access_log)
-    logging.getLogger('turbogears.controllers').setLevel(logging.INFO)
+    logging.getLogger('wsgi').addHandler(access_log)
 
     if foreground:
         logging.getLogger('').addHandler(stdout_log)

